# coding: utf-8

# flake8: noqa
"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 5.0.3 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


if __import__("typing").TYPE_CHECKING:
    # import models into model package
    from poodle_async_full.models.aiplacement_courseassist_explain_text_response import AiplacementCourseassistExplainTextResponse
    from poodle_async_full.models.aiplacement_courseassist_summarise_text_response import AiplacementCourseassistSummariseTextResponse
    from poodle_async_full.models.aiplacement_editor_generate_image_response import AiplacementEditorGenerateImageResponse
    from poodle_async_full.models.aiplacement_editor_generate_text_response import AiplacementEditorGenerateTextResponse
    from poodle_async_full.models.auth_email_get_signup_settings_response import AuthEmailGetSignupSettingsResponse
    from poodle_async_full.models.auth_email_get_signup_settings_response_profilefields_inner import AuthEmailGetSignupSettingsResponseProfilefieldsInner
    from poodle_async_full.models.auth_email_get_signup_settings_response_warnings_inner import AuthEmailGetSignupSettingsResponseWarningsInner
    from poodle_async_full.models.auth_email_signup_user_parameters import AuthEmailSignupUserParameters
    from poodle_async_full.models.auth_email_signup_user_parameters_customprofilefields_inner import AuthEmailSignupUserParametersCustomprofilefieldsInner
    from poodle_async_full.models.auth_email_signup_user_response import AuthEmailSignupUserResponse
    from poodle_async_full.models.block_accessreview_get_module_data_response_inner import BlockAccessreviewGetModuleDataResponseInner
    from poodle_async_full.models.block_accessreview_get_section_data_response_inner import BlockAccessreviewGetSectionDataResponseInner
    from poodle_async_full.models.block_recentlyaccesseditems_get_recent_items_response_inner import BlockRecentlyaccesseditemsGetRecentItemsResponseInner
    from poodle_async_full.models.block_starredcourses_get_starred_courses_response_inner import BlockStarredcoursesGetStarredCoursesResponseInner
    from poodle_async_full.models.core_ai_delete_provider_instance_response import CoreAiDeleteProviderInstanceResponse
    from poodle_async_full.models.core_ai_get_policy_status_response import CoreAiGetPolicyStatusResponse
    from poodle_async_full.models.core_ai_set_policy_status_response import CoreAiSetPolicyStatusResponse
    from poodle_async_full.models.core_ai_set_provider_status_response import CoreAiSetProviderStatusResponse
    from poodle_async_full.models.core_auth_confirm_user_parameters import CoreAuthConfirmUserParameters
    from poodle_async_full.models.core_auth_confirm_user_response import CoreAuthConfirmUserResponse
    from poodle_async_full.models.core_auth_is_age_digital_consent_verification_enabled_response import CoreAuthIsAgeDigitalConsentVerificationEnabledResponse
    from poodle_async_full.models.core_auth_is_minor_parameters import CoreAuthIsMinorParameters
    from poodle_async_full.models.core_auth_is_minor_response import CoreAuthIsMinorResponse
    from poodle_async_full.models.core_auth_request_password_reset_parameters import CoreAuthRequestPasswordResetParameters
    from poodle_async_full.models.core_auth_request_password_reset_response import CoreAuthRequestPasswordResetResponse
    from poodle_async_full.models.core_auth_resend_confirmation_email_parameters import CoreAuthResendConfirmationEmailParameters
    from poodle_async_full.models.core_auth_resend_confirmation_email_response import CoreAuthResendConfirmationEmailResponse
    from poodle_async_full.models.core_backup_get_async_backup_links_backup_response import CoreBackupGetAsyncBackupLinksBackupResponse
    from poodle_async_full.models.core_backup_get_async_backup_links_restore_response import CoreBackupGetAsyncBackupLinksRestoreResponse
    from poodle_async_full.models.core_backup_get_async_backup_progress_response_inner import CoreBackupGetAsyncBackupProgressResponseInner
    from poodle_async_full.models.core_backup_get_copy_progress_parameters_copies_inner import CoreBackupGetCopyProgressParametersCopiesInner
    from poodle_async_full.models.core_backup_get_copy_progress_response_inner import CoreBackupGetCopyProgressResponseInner
    from poodle_async_full.models.core_badges_disable_badges_response import CoreBadgesDisableBadgesResponse
    from poodle_async_full.models.core_badges_enable_badges_response import CoreBadgesEnableBadgesResponse
    from poodle_async_full.models.core_badges_enable_badges_response_result_inner import CoreBadgesEnableBadgesResponseResultInner
    from poodle_async_full.models.core_badges_get_badge_response import CoreBadgesGetBadgeResponse
    from poodle_async_full.models.core_badges_get_badge_response_badge import CoreBadgesGetBadgeResponseBadge
    from poodle_async_full.models.core_badges_get_badge_response_badge_alignment_inner import CoreBadgesGetBadgeResponseBadgeAlignmentInner
    from poodle_async_full.models.core_badges_get_user_badge_by_hash_response import CoreBadgesGetUserBadgeByHashResponse
    from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner import CoreBadgesGetUserBadgeByHashResponseBadgeInner
    from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner_endorsement import CoreBadgesGetUserBadgeByHashResponseBadgeInnerEndorsement
    from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner_relatedbadges_inner import CoreBadgesGetUserBadgeByHashResponseBadgeInnerRelatedbadgesInner
    from poodle_async_full.models.core_badges_get_user_badges_response import CoreBadgesGetUserBadgesResponse
    from poodle_async_full.models.core_block_fetch_addable_blocks_response_inner import CoreBlockFetchAddableBlocksResponseInner
    from poodle_async_full.models.core_block_get_course_blocks_response import CoreBlockGetCourseBlocksResponse
    from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner import CoreBlockGetCourseBlocksResponseBlocksInner
    from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_configs_inner import CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner
    from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents import CoreBlockGetCourseBlocksResponseBlocksInnerContents
    from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
    from poodle_async_full.models.core_block_get_dashboard_blocks_response import CoreBlockGetDashboardBlocksResponse
    from poodle_async_full.models.core_blog_add_entry_parameters_options_inner import CoreBlogAddEntryParametersOptionsInner
    from poodle_async_full.models.core_blog_add_entry_response import CoreBlogAddEntryResponse
    from poodle_async_full.models.core_blog_delete_entry_response import CoreBlogDeleteEntryResponse
    from poodle_async_full.models.core_blog_get_access_information_response import CoreBlogGetAccessInformationResponse
    from poodle_async_full.models.core_blog_get_entries_parameters import CoreBlogGetEntriesParameters
    from poodle_async_full.models.core_blog_get_entries_parameters_filters_inner import CoreBlogGetEntriesParametersFiltersInner
    from poodle_async_full.models.core_blog_get_entries_response import CoreBlogGetEntriesResponse
    from poodle_async_full.models.core_blog_get_entries_response_entries_inner import CoreBlogGetEntriesResponseEntriesInner
    from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
    from poodle_async_full.models.core_blog_get_entries_response_entries_inner_tags_inner import CoreBlogGetEntriesResponseEntriesInnerTagsInner
    from poodle_async_full.models.core_blog_prepare_entry_for_edition_response import CoreBlogPrepareEntryForEditionResponse
    from poodle_async_full.models.core_blog_prepare_entry_for_edition_response_areas_inner import CoreBlogPrepareEntryForEditionResponseAreasInner
    from poodle_async_full.models.core_blog_prepare_entry_for_edition_response_areas_inner_options_inner import CoreBlogPrepareEntryForEditionResponseAreasInnerOptionsInner
    from poodle_async_full.models.core_blog_update_entry_response import CoreBlogUpdateEntryResponse
    from poodle_async_full.models.core_blog_view_entries_parameters import CoreBlogViewEntriesParameters
    from poodle_async_full.models.core_blog_view_entries_parameters_filters_inner import CoreBlogViewEntriesParametersFiltersInner
    from poodle_async_full.models.core_blog_view_entries_response import CoreBlogViewEntriesResponse
    from poodle_async_full.models.core_calendar_create_calendar_events_parameters_events_inner import CoreCalendarCreateCalendarEventsParametersEventsInner
    from poodle_async_full.models.core_calendar_create_calendar_events_response import CoreCalendarCreateCalendarEventsResponse
    from poodle_async_full.models.core_calendar_create_calendar_events_response_events_inner import CoreCalendarCreateCalendarEventsResponseEventsInner
    from poodle_async_full.models.core_calendar_delete_calendar_events_parameters_events_inner import CoreCalendarDeleteCalendarEventsParametersEventsInner
    from poodle_async_full.models.core_calendar_delete_subscription_response import CoreCalendarDeleteSubscriptionResponse
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response import CoreCalendarGetActionEventsByCourseResponse
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner import CoreCalendarGetActionEventsByCourseResponseEventsInner
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_action import CoreCalendarGetActionEventsByCourseResponseEventsInnerAction
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_category import CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_icon import CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon
    from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_subscription import CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription
    from poodle_async_full.models.core_calendar_get_action_events_by_courses_response import CoreCalendarGetActionEventsByCoursesResponse
    from poodle_async_full.models.core_calendar_get_action_events_by_courses_response_groupedbycourse_inner import CoreCalendarGetActionEventsByCoursesResponseGroupedbycourseInner
    from poodle_async_full.models.core_calendar_get_action_events_by_timesort_response import CoreCalendarGetActionEventsByTimesortResponse
    from poodle_async_full.models.core_calendar_get_allowed_event_types_response import CoreCalendarGetAllowedEventTypesResponse
    from poodle_async_full.models.core_calendar_get_calendar_access_information_response import CoreCalendarGetCalendarAccessInformationResponse
    from poodle_async_full.models.core_calendar_get_calendar_day_view_response import CoreCalendarGetCalendarDayViewResponse
    from poodle_async_full.models.core_calendar_get_calendar_day_view_response_date import CoreCalendarGetCalendarDayViewResponseDate
    from poodle_async_full.models.core_calendar_get_calendar_day_view_response_events_inner import CoreCalendarGetCalendarDayViewResponseEventsInner
    from poodle_async_full.models.core_calendar_get_calendar_event_by_id_response import CoreCalendarGetCalendarEventByIdResponse
    from poodle_async_full.models.core_calendar_get_calendar_events_parameters_events import CoreCalendarGetCalendarEventsParametersEvents
    from poodle_async_full.models.core_calendar_get_calendar_events_parameters_options import CoreCalendarGetCalendarEventsParametersOptions
    from poodle_async_full.models.core_calendar_get_calendar_events_response import CoreCalendarGetCalendarEventsResponse
    from poodle_async_full.models.core_calendar_get_calendar_events_response_events_inner import CoreCalendarGetCalendarEventsResponseEventsInner
    from poodle_async_full.models.core_calendar_get_calendar_export_token_response import CoreCalendarGetCalendarExportTokenResponse
    from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response import CoreCalendarGetCalendarMonthlyViewResponse
    from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_daynames_inner import CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner
    from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_weeks_inner import CoreCalendarGetCalendarMonthlyViewResponseWeeksInner
    from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_weeks_inner_days_inner import CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner
    from poodle_async_full.models.core_calendar_get_calendar_upcoming_view_response import CoreCalendarGetCalendarUpcomingViewResponse
    from poodle_async_full.models.core_calendar_get_timestamps_parameters_data_inner import CoreCalendarGetTimestampsParametersDataInner
    from poodle_async_full.models.core_calendar_get_timestamps_response import CoreCalendarGetTimestampsResponse
    from poodle_async_full.models.core_calendar_get_timestamps_response_timestamps_inner import CoreCalendarGetTimestampsResponseTimestampsInner
    from poodle_async_full.models.core_calendar_submit_create_update_form_response import CoreCalendarSubmitCreateUpdateFormResponse
    from poodle_async_full.models.core_calendar_update_event_start_day_response import CoreCalendarUpdateEventStartDayResponse
    from poodle_async_full.models.core_change_editmode_response import CoreChangeEditmodeResponse
    from poodle_async_full.models.core_check_get_result_admintree_response import CoreCheckGetResultAdmintreeResponse
    from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner import CoreCohortAddCohortMembersParametersMembersInner
    from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner_cohorttype import CoreCohortAddCohortMembersParametersMembersInnerCohorttype
    from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner_usertype import CoreCohortAddCohortMembersParametersMembersInnerUsertype
    from poodle_async_full.models.core_cohort_add_cohort_members_response import CoreCohortAddCohortMembersResponse
    from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner import CoreCohortCreateCohortsParametersCohortsInner
    from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner_categorytype import CoreCohortCreateCohortsParametersCohortsInnerCategorytype
    from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner_customfields_inner import CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner
    from poodle_async_full.models.core_cohort_create_cohorts_response_inner import CoreCohortCreateCohortsResponseInner
    from poodle_async_full.models.core_cohort_delete_cohort_members_parameters_members_inner import CoreCohortDeleteCohortMembersParametersMembersInner
    from poodle_async_full.models.core_cohort_get_cohort_members_response_inner import CoreCohortGetCohortMembersResponseInner
    from poodle_async_full.models.core_cohort_get_cohorts_response_inner import CoreCohortGetCohortsResponseInner
    from poodle_async_full.models.core_cohort_get_cohorts_response_inner_customfields_inner import CoreCohortGetCohortsResponseInnerCustomfieldsInner
    from poodle_async_full.models.core_cohort_search_cohorts_parameters_context import CoreCohortSearchCohortsParametersContext
    from poodle_async_full.models.core_cohort_search_cohorts_response import CoreCohortSearchCohortsResponse
    from poodle_async_full.models.core_cohort_update_cohorts_parameters_cohorts_inner import CoreCohortUpdateCohortsParametersCohortsInner
    from poodle_async_full.models.core_comment_add_comments_parameters_comments_inner import CoreCommentAddCommentsParametersCommentsInner
    from poodle_async_full.models.core_comment_add_comments_response_inner import CoreCommentAddCommentsResponseInner
    from poodle_async_full.models.core_comment_get_comments_response import CoreCommentGetCommentsResponse
    from poodle_async_full.models.core_competency_count_competencies_parameters_filters_inner import CoreCompetencyCountCompetenciesParametersFiltersInner
    from poodle_async_full.models.core_competency_create_competency_framework_parameters_competencyframework import CoreCompetencyCreateCompetencyFrameworkParametersCompetencyframework
    from poodle_async_full.models.core_competency_create_competency_framework_response import CoreCompetencyCreateCompetencyFrameworkResponse
    from poodle_async_full.models.core_competency_create_competency_parameters_competency import CoreCompetencyCreateCompetencyParametersCompetency
    from poodle_async_full.models.core_competency_create_competency_response import CoreCompetencyCreateCompetencyResponse
    from poodle_async_full.models.core_competency_create_plan_parameters_plan import CoreCompetencyCreatePlanParametersPlan
    from poodle_async_full.models.core_competency_create_plan_response import CoreCompetencyCreatePlanResponse
    from poodle_async_full.models.core_competency_create_plan_response_commentarea import CoreCompetencyCreatePlanResponseCommentarea
    from poodle_async_full.models.core_competency_create_plan_response_reviewer import CoreCompetencyCreatePlanResponseReviewer
    from poodle_async_full.models.core_competency_create_plan_response_template import CoreCompetencyCreatePlanResponseTemplate
    from poodle_async_full.models.core_competency_create_template_parameters_template import CoreCompetencyCreateTemplateParametersTemplate
    from poodle_async_full.models.core_competency_create_template_response import CoreCompetencyCreateTemplateResponse
    from poodle_async_full.models.core_competency_create_user_evidence_competency_response import CoreCompetencyCreateUserEvidenceCompetencyResponse
    from poodle_async_full.models.core_competency_duplicate_competency_framework_response import CoreCompetencyDuplicateCompetencyFrameworkResponse
    from poodle_async_full.models.core_competency_duplicate_template_response import CoreCompetencyDuplicateTemplateResponse
    from poodle_async_full.models.core_competency_get_scale_values_response_inner import CoreCompetencyGetScaleValuesResponseInner
    from poodle_async_full.models.core_competency_grade_competency_in_course_response import CoreCompetencyGradeCompetencyInCourseResponse
    from poodle_async_full.models.core_competency_grade_competency_in_plan_response import CoreCompetencyGradeCompetencyInPlanResponse
    from poodle_async_full.models.core_competency_grade_competency_response import CoreCompetencyGradeCompetencyResponse
    from poodle_async_full.models.core_competency_list_competencies_in_template_response_inner import CoreCompetencyListCompetenciesInTemplateResponseInner
    from poodle_async_full.models.core_competency_list_competency_frameworks_response_inner import CoreCompetencyListCompetencyFrameworksResponseInner
    from poodle_async_full.models.core_competency_list_course_competencies_response_inner import CoreCompetencyListCourseCompetenciesResponseInner
    from poodle_async_full.models.core_competency_list_course_competencies_response_inner_coursecompetency import CoreCompetencyListCourseCompetenciesResponseInnerCoursecompetency
    from poodle_async_full.models.core_competency_list_course_module_competencies_response_inner import CoreCompetencyListCourseModuleCompetenciesResponseInner
    from poodle_async_full.models.core_competency_list_course_module_competencies_response_inner_coursemodulecompetency import CoreCompetencyListCourseModuleCompetenciesResponseInnerCoursemodulecompetency
    from poodle_async_full.models.core_competency_list_plan_competencies_response_inner import CoreCompetencyListPlanCompetenciesResponseInner
    from poodle_async_full.models.core_competency_list_plan_competencies_response_inner_usercompetency import CoreCompetencyListPlanCompetenciesResponseInnerUsercompetency
    from poodle_async_full.models.core_competency_list_plan_competencies_response_inner_usercompetencyplan import CoreCompetencyListPlanCompetenciesResponseInnerUsercompetencyplan
    from poodle_async_full.models.core_competency_list_user_plans_response_inner import CoreCompetencyListUserPlansResponseInner
    from poodle_async_full.models.core_competency_read_competency_framework_response import CoreCompetencyReadCompetencyFrameworkResponse
    from poodle_async_full.models.core_competency_read_competency_response import CoreCompetencyReadCompetencyResponse
    from poodle_async_full.models.core_competency_read_plan_response import CoreCompetencyReadPlanResponse
    from poodle_async_full.models.core_competency_read_template_response import CoreCompetencyReadTemplateResponse
    from poodle_async_full.models.core_competency_read_user_evidence_response import CoreCompetencyReadUserEvidenceResponse
    from poodle_async_full.models.core_competency_read_user_evidence_response_files_inner import CoreCompetencyReadUserEvidenceResponseFilesInner
    from poodle_async_full.models.core_competency_update_competency_framework_parameters_competencyframework import CoreCompetencyUpdateCompetencyFrameworkParametersCompetencyframework
    from poodle_async_full.models.core_competency_update_competency_parameters_competency import CoreCompetencyUpdateCompetencyParametersCompetency
    from poodle_async_full.models.core_competency_update_course_competency_settings_parameters_settings import CoreCompetencyUpdateCourseCompetencySettingsParametersSettings
    from poodle_async_full.models.core_competency_update_plan_parameters_plan import CoreCompetencyUpdatePlanParametersPlan
    from poodle_async_full.models.core_competency_update_plan_response import CoreCompetencyUpdatePlanResponse
    from poodle_async_full.models.core_competency_update_template_parameters_template import CoreCompetencyUpdateTemplateParametersTemplate
    from poodle_async_full.models.core_completion_get_activities_completion_status_response import CoreCompletionGetActivitiesCompletionStatusResponse
    from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner
    from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner_details_inner import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner
    from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner_details_inner_rulevalue import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInnerRulevalue
    from poodle_async_full.models.core_completion_get_course_completion_status_response import CoreCompletionGetCourseCompletionStatusResponse
    from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus import CoreCompletionGetCourseCompletionStatusResponseCompletionstatus
    from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus_completions_inner import CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInner
    from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus_completions_inner_details import CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInnerDetails
    from poodle_async_full.models.core_completion_mark_course_self_completed_response import CoreCompletionMarkCourseSelfCompletedResponse
    from poodle_async_full.models.core_completion_override_activity_completion_status_response import CoreCompletionOverrideActivityCompletionStatusResponse
    from poodle_async_full.models.core_completion_update_activity_completion_status_manually_response import CoreCompletionUpdateActivityCompletionStatusManuallyResponse
    from poodle_async_full.models.core_contentbank_copy_content_response import CoreContentbankCopyContentResponse
    from poodle_async_full.models.core_contentbank_delete_content_response import CoreContentbankDeleteContentResponse
    from poodle_async_full.models.core_contentbank_rename_content_response import CoreContentbankRenameContentResponse
    from poodle_async_full.models.core_contentbank_set_content_visibility_response import CoreContentbankSetContentVisibilityResponse
    from poodle_async_full.models.core_course_add_content_item_to_user_favourites_response import CoreCourseAddContentItemToUserFavouritesResponse
    from poodle_async_full.models.core_course_check_updates_parameters_tocheck_inner import CoreCourseCheckUpdatesParametersTocheckInner
    from poodle_async_full.models.core_course_check_updates_response import CoreCourseCheckUpdatesResponse
    from poodle_async_full.models.core_course_check_updates_response_instances_inner import CoreCourseCheckUpdatesResponseInstancesInner
    from poodle_async_full.models.core_course_check_updates_response_instances_inner_updates_inner import CoreCourseCheckUpdatesResponseInstancesInnerUpdatesInner
    from poodle_async_full.models.core_course_create_categories_parameters_categories_inner import CoreCourseCreateCategoriesParametersCategoriesInner
    from poodle_async_full.models.core_course_create_categories_response_inner import CoreCourseCreateCategoriesResponseInner
    from poodle_async_full.models.core_course_create_courses_parameters_courses_inner import CoreCourseCreateCoursesParametersCoursesInner
    from poodle_async_full.models.core_course_create_courses_parameters_courses_inner_courseformatoptions_inner import CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner
    from poodle_async_full.models.core_course_create_courses_response_inner import CoreCourseCreateCoursesResponseInner
    from poodle_async_full.models.core_course_delete_categories_parameters_categories_inner import CoreCourseDeleteCategoriesParametersCategoriesInner
    from poodle_async_full.models.core_course_delete_courses_response import CoreCourseDeleteCoursesResponse
    from poodle_async_full.models.core_course_duplicate_course_parameters_options_inner import CoreCourseDuplicateCourseParametersOptionsInner
    from poodle_async_full.models.core_course_duplicate_course_response import CoreCourseDuplicateCourseResponse
    from poodle_async_full.models.core_course_get_activity_chooser_footer_response import CoreCourseGetActivityChooserFooterResponse
    from poodle_async_full.models.core_course_get_categories_parameters_criteria_inner import CoreCourseGetCategoriesParametersCriteriaInner
    from poodle_async_full.models.core_course_get_categories_response_inner import CoreCourseGetCategoriesResponseInner
    from poodle_async_full.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner
    from poodle_async_full.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
    from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner
    from poodle_async_full.models.core_course_get_course_content_items_response import CoreCourseGetCourseContentItemsResponse
    from poodle_async_full.models.core_course_get_course_content_items_response_content_items_inner import CoreCourseGetCourseContentItemsResponseContentItemsInner
    from poodle_async_full.models.core_course_get_course_module_by_instance_response import CoreCourseGetCourseModuleByInstanceResponse
    from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm import CoreCourseGetCourseModuleByInstanceResponseCm
    from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm_advancedgrading_inner import CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner
    from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm_outcomes_inner import CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner
    from poodle_async_full.models.core_course_get_course_module_response import CoreCourseGetCourseModuleResponse
    from poodle_async_full.models.core_course_get_courses_by_field_response import CoreCourseGetCoursesByFieldResponse
    from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner import CoreCourseGetCoursesByFieldResponseCoursesInner
    from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_contacts_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner
    from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_courseformatoptions_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerCourseformatoptionsInner
    from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_filters_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerFiltersInner
    from poodle_async_full.models.core_course_get_courses_parameters_options import CoreCourseGetCoursesParametersOptions
    from poodle_async_full.models.core_course_get_courses_response_inner import CoreCourseGetCoursesResponseInner
    from poodle_async_full.models.core_course_get_courses_response_inner_customfields_inner import CoreCourseGetCoursesResponseInnerCustomfieldsInner
    from poodle_async_full.models.core_course_get_enrolled_courses_by_timeline_classification_response import CoreCourseGetEnrolledCoursesByTimelineClassificationResponse
    from poodle_async_full.models.core_course_get_enrolled_courses_with_action_events_by_timeline_classification_response import CoreCourseGetEnrolledCoursesWithActionEventsByTimelineClassificationResponse
    from poodle_async_full.models.core_course_get_enrolled_users_by_cmid_response import CoreCourseGetEnrolledUsersByCmidResponse
    from poodle_async_full.models.core_course_get_enrolled_users_by_cmid_response_users_inner import CoreCourseGetEnrolledUsersByCmidResponseUsersInner
    from poodle_async_full.models.core_course_get_updates_since_response import CoreCourseGetUpdatesSinceResponse
    from poodle_async_full.models.core_course_get_user_administration_options_response import CoreCourseGetUserAdministrationOptionsResponse
    from poodle_async_full.models.core_course_get_user_administration_options_response_courses_inner import CoreCourseGetUserAdministrationOptionsResponseCoursesInner
    from poodle_async_full.models.core_course_get_user_administration_options_response_courses_inner_options_inner import CoreCourseGetUserAdministrationOptionsResponseCoursesInnerOptionsInner
    from poodle_async_full.models.core_course_get_user_navigation_options_response import CoreCourseGetUserNavigationOptionsResponse
    from poodle_async_full.models.core_course_import_course_parameters_options_inner import CoreCourseImportCourseParametersOptionsInner
    from poodle_async_full.models.core_course_remove_content_item_from_user_favourites_response import CoreCourseRemoveContentItemFromUserFavouritesResponse
    from poodle_async_full.models.core_course_search_courses_response import CoreCourseSearchCoursesResponse
    from poodle_async_full.models.core_course_search_courses_response_courses_inner import CoreCourseSearchCoursesResponseCoursesInner
    from poodle_async_full.models.core_course_set_favourite_courses_parameters_courses_inner import CoreCourseSetFavouriteCoursesParametersCoursesInner
    from poodle_async_full.models.core_course_set_favourite_courses_response import CoreCourseSetFavouriteCoursesResponse
    from poodle_async_full.models.core_course_toggle_activity_recommendation_response import CoreCourseToggleActivityRecommendationResponse
    from poodle_async_full.models.core_course_update_categories_parameters_categories_inner import CoreCourseUpdateCategoriesParametersCategoriesInner
    from poodle_async_full.models.core_course_update_courses_parameters_courses_inner import CoreCourseUpdateCoursesParametersCoursesInner
    from poodle_async_full.models.core_course_update_courses_response import CoreCourseUpdateCoursesResponse
    from poodle_async_full.models.core_course_view_course_response import CoreCourseViewCourseResponse
    from poodle_async_full.models.core_courseformat_file_handlers_response_inner import CoreCourseformatFileHandlersResponseInner
    from poodle_async_full.models.core_customfield_reload_template_response import CoreCustomfieldReloadTemplateResponse
    from poodle_async_full.models.core_customfield_reload_template_response_categories_inner import CoreCustomfieldReloadTemplateResponseCategoriesInner
    from poodle_async_full.models.core_customfield_reload_template_response_categories_inner_fields_inner import CoreCustomfieldReloadTemplateResponseCategoriesInnerFieldsInner
    from poodle_async_full.models.core_dynamic_tabs_get_content_response import CoreDynamicTabsGetContentResponse
    from poodle_async_full.models.core_enrol_get_course_enrolment_methods_response_inner import CoreEnrolGetCourseEnrolmentMethodsResponseInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_parameters_options_inner import CoreEnrolGetEnrolledUsersParametersOptionsInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner import CoreEnrolGetEnrolledUsersResponseInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_customfields_inner import CoreEnrolGetEnrolledUsersResponseInnerCustomfieldsInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_enrolledcourses_inner import CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_groups_inner import CoreEnrolGetEnrolledUsersResponseInnerGroupsInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_preferences_inner import CoreEnrolGetEnrolledUsersResponseInnerPreferencesInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_roles_inner import CoreEnrolGetEnrolledUsersResponseInnerRolesInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_parameters_coursecapabilities_inner import CoreEnrolGetEnrolledUsersWithCapabilityParametersCoursecapabilitiesInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner_customfields_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerCustomfieldsInner
    from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner_groups_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner
    from poodle_async_full.models.core_enrol_get_potential_users_response_inner import CoreEnrolGetPotentialUsersResponseInner
    from poodle_async_full.models.core_enrol_get_potential_users_response_inner_customfields_inner import CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner
    from poodle_async_full.models.core_enrol_get_potential_users_response_inner_preferences_inner import CoreEnrolGetPotentialUsersResponseInnerPreferencesInner
    from poodle_async_full.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner
    from poodle_async_full.models.core_enrol_submit_user_enrolment_form_response import CoreEnrolSubmitUserEnrolmentFormResponse
    from poodle_async_full.models.core_enrol_unenrol_user_enrolment_response import CoreEnrolUnenrolUserEnrolmentResponse
    from poodle_async_full.models.core_enrol_unenrol_user_enrolment_response_errors_inner import CoreEnrolUnenrolUserEnrolmentResponseErrorsInner
    from poodle_async_full.models.core_fetch_notifications_parameters import CoreFetchNotificationsParameters
    from poodle_async_full.models.core_fetch_notifications_response_inner import CoreFetchNotificationsResponseInner
    from poodle_async_full.models.core_fetch_notifications_response_inner_variables import CoreFetchNotificationsResponseInnerVariables
    from poodle_async_full.models.core_files_delete_draft_files_parameters_files_inner import CoreFilesDeleteDraftFilesParametersFilesInner
    from poodle_async_full.models.core_files_delete_draft_files_response import CoreFilesDeleteDraftFilesResponse
    from poodle_async_full.models.core_files_get_files_response import CoreFilesGetFilesResponse
    from poodle_async_full.models.core_files_get_files_response_files_inner import CoreFilesGetFilesResponseFilesInner
    from poodle_async_full.models.core_files_get_files_response_parents_inner import CoreFilesGetFilesResponseParentsInner
    from poodle_async_full.models.core_files_get_unused_draft_itemid_response import CoreFilesGetUnusedDraftItemidResponse
    from poodle_async_full.models.core_files_upload_response import CoreFilesUploadResponse
    from poodle_async_full.models.core_filters_get_all_states_response import CoreFiltersGetAllStatesResponse
    from poodle_async_full.models.core_filters_get_all_states_response_filters_inner import CoreFiltersGetAllStatesResponseFiltersInner
    from poodle_async_full.models.core_filters_get_available_in_context_parameters_contexts_inner import CoreFiltersGetAvailableInContextParametersContextsInner
    from poodle_async_full.models.core_filters_get_available_in_context_response import CoreFiltersGetAvailableInContextResponse
    from poodle_async_full.models.core_filters_get_available_in_context_response_filters_inner import CoreFiltersGetAvailableInContextResponseFiltersInner
    from poodle_async_full.models.core_form_dynamic_form_response import CoreFormDynamicFormResponse
    from poodle_async_full.models.core_form_get_filetypes_browser_data_parameters import CoreFormGetFiletypesBrowserDataParameters
    from poodle_async_full.models.core_form_get_filetypes_browser_data_response import CoreFormGetFiletypesBrowserDataResponse
    from poodle_async_full.models.core_form_get_filetypes_browser_data_response_groups_inner import CoreFormGetFiletypesBrowserDataResponseGroupsInner
    from poodle_async_full.models.core_form_get_filetypes_browser_data_response_groups_inner_types_inner import CoreFormGetFiletypesBrowserDataResponseGroupsInnerTypesInner
    from poodle_async_full.models.core_get_component_strings_parameters import CoreGetComponentStringsParameters
    from poodle_async_full.models.core_get_component_strings_response_inner import CoreGetComponentStringsResponseInner
    from poodle_async_full.models.core_get_fragment_parameters_args_inner import CoreGetFragmentParametersArgsInner
    from poodle_async_full.models.core_get_fragment_response import CoreGetFragmentResponse
    from poodle_async_full.models.core_get_string_parameters import CoreGetStringParameters
    from poodle_async_full.models.core_get_string_parameters_stringparams_inner import CoreGetStringParametersStringparamsInner
    from poodle_async_full.models.core_get_strings_parameters import CoreGetStringsParameters
    from poodle_async_full.models.core_get_strings_parameters_strings_inner import CoreGetStringsParametersStringsInner
    from poodle_async_full.models.core_get_strings_parameters_strings_inner_stringparams_inner import CoreGetStringsParametersStringsInnerStringparamsInner
    from poodle_async_full.models.core_get_strings_response_inner import CoreGetStringsResponseInner
    from poodle_async_full.models.core_get_user_dates_parameters_timestamps_inner import CoreGetUserDatesParametersTimestampsInner
    from poodle_async_full.models.core_get_user_dates_response import CoreGetUserDatesResponse
    from poodle_async_full.models.core_grades_create_gradecategories_parameters_categories_inner import CoreGradesCreateGradecategoriesParametersCategoriesInner
    from poodle_async_full.models.core_grades_create_gradecategories_parameters_categories_inner_options import CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions
    from poodle_async_full.models.core_grades_create_gradecategories_response import CoreGradesCreateGradecategoriesResponse
    from poodle_async_full.models.core_grades_get_enrolled_users_for_selector_response import CoreGradesGetEnrolledUsersForSelectorResponse
    from poodle_async_full.models.core_grades_get_feedback_response import CoreGradesGetFeedbackResponse
    from poodle_async_full.models.core_grades_get_gradable_users_response import CoreGradesGetGradableUsersResponse
    from poodle_async_full.models.core_grades_get_gradeitems_response import CoreGradesGetGradeitemsResponse
    from poodle_async_full.models.core_grades_get_gradeitems_response_grade_items_inner import CoreGradesGetGradeitemsResponseGradeItemsInner
    from poodle_async_full.models.core_grades_get_groups_for_selector_response import CoreGradesGetGroupsForSelectorResponse
    from poodle_async_full.models.core_grades_get_groups_for_selector_response_groups_inner import CoreGradesGetGroupsForSelectorResponseGroupsInner
    from poodle_async_full.models.core_grades_grader_gradingpanel_point_fetch_response import CoreGradesGraderGradingpanelPointFetchResponse
    from poodle_async_full.models.core_grades_grader_gradingpanel_point_fetch_response_grade import CoreGradesGraderGradingpanelPointFetchResponseGrade
    from poodle_async_full.models.core_grades_grader_gradingpanel_point_store_response import CoreGradesGraderGradingpanelPointStoreResponse
    from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response import CoreGradesGraderGradingpanelScaleFetchResponse
    from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response_grade import CoreGradesGraderGradingpanelScaleFetchResponseGrade
    from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response_grade_options_inner import CoreGradesGraderGradingpanelScaleFetchResponseGradeOptionsInner
    from poodle_async_full.models.core_grades_grader_gradingpanel_scale_store_response import CoreGradesGraderGradingpanelScaleStoreResponse
    from poodle_async_full.models.core_grades_update_grades_parameters_grades_inner import CoreGradesUpdateGradesParametersGradesInner
    from poodle_async_full.models.core_grades_update_grades_parameters_itemdetails import CoreGradesUpdateGradesParametersItemdetails
    from poodle_async_full.models.core_grading_get_definitions_response import CoreGradingGetDefinitionsResponse
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner import CoreGradingGetDefinitionsResponseAreasInner
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide_guide_comments_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCommentsInner
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide_guide_criteria_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCriteriaInner
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric_rubric_criteria_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInner
    from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric_rubric_criteria_inner_levels_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInnerLevelsInner
    from poodle_async_full.models.core_grading_get_gradingform_instances_response import CoreGradingGetGradingformInstancesResponse
    from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner import CoreGradingGetGradingformInstancesResponseInstancesInner
    from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_guide import CoreGradingGetGradingformInstancesResponseInstancesInnerGuide
    from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_guide_criteria_inner import CoreGradingGetGradingformInstancesResponseInstancesInnerGuideCriteriaInner
    from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_rubric import CoreGradingGetGradingformInstancesResponseInstancesInnerRubric
    from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_rubric_criteria_inner import CoreGradingGetGradingformInstancesResponseInstancesInnerRubricCriteriaInner
    from poodle_async_full.models.core_group_add_group_members_parameters_members_inner import CoreGroupAddGroupMembersParametersMembersInner
    from poodle_async_full.models.core_group_assign_grouping_parameters_assignments_inner import CoreGroupAssignGroupingParametersAssignmentsInner
    from poodle_async_full.models.core_group_create_groupings_parameters_groupings_inner import CoreGroupCreateGroupingsParametersGroupingsInner
    from poodle_async_full.models.core_group_create_groupings_response_inner import CoreGroupCreateGroupingsResponseInner
    from poodle_async_full.models.core_group_create_groups_parameters_groups_inner import CoreGroupCreateGroupsParametersGroupsInner
    from poodle_async_full.models.core_group_create_groups_response_inner import CoreGroupCreateGroupsResponseInner
    from poodle_async_full.models.core_group_get_activity_allowed_groups_response import CoreGroupGetActivityAllowedGroupsResponse
    from poodle_async_full.models.core_group_get_activity_allowed_groups_response_groups_inner import CoreGroupGetActivityAllowedGroupsResponseGroupsInner
    from poodle_async_full.models.core_group_get_activity_groupmode_response import CoreGroupGetActivityGroupmodeResponse
    from poodle_async_full.models.core_group_get_course_groupings_response_inner import CoreGroupGetCourseGroupingsResponseInner
    from poodle_async_full.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner
    from poodle_async_full.models.core_group_get_course_user_groups_response import CoreGroupGetCourseUserGroupsResponse
    from poodle_async_full.models.core_group_get_group_members_response_inner import CoreGroupGetGroupMembersResponseInner
    from poodle_async_full.models.core_group_get_groupings_response_inner import CoreGroupGetGroupingsResponseInner
    from poodle_async_full.models.core_group_get_groupings_response_inner_groups_inner import CoreGroupGetGroupingsResponseInnerGroupsInner
    from poodle_async_full.models.core_group_get_groups_for_selector_response import CoreGroupGetGroupsForSelectorResponse
    from poodle_async_full.models.core_group_get_groups_response_inner import CoreGroupGetGroupsResponseInner
    from poodle_async_full.models.core_group_update_groupings_parameters_groupings_inner import CoreGroupUpdateGroupingsParametersGroupingsInner
    from poodle_async_full.models.core_group_update_groups_parameters_groups_inner import CoreGroupUpdateGroupsParametersGroupsInner
    from poodle_async_full.models.core_h5p_get_trusted_h5p_file_response import CoreH5pGetTrustedH5pFileResponse
    from poodle_async_full.models.core_message_create_contact_request_response import CoreMessageCreateContactRequestResponse
    from poodle_async_full.models.core_message_create_contact_request_response_request import CoreMessageCreateContactRequestResponseRequest
    from poodle_async_full.models.core_message_data_for_messagearea_search_messages_response import CoreMessageDataForMessageareaSearchMessagesResponse
    from poodle_async_full.models.core_message_data_for_messagearea_search_messages_response_contacts_inner import CoreMessageDataForMessageareaSearchMessagesResponseContactsInner
    from poodle_async_full.models.core_message_delete_message_response import CoreMessageDeleteMessageResponse
    from poodle_async_full.models.core_message_get_blocked_users_response import CoreMessageGetBlockedUsersResponse
    from poodle_async_full.models.core_message_get_blocked_users_response_users_inner import CoreMessageGetBlockedUsersResponseUsersInner
    from poodle_async_full.models.core_message_get_contact_requests_response_inner import CoreMessageGetContactRequestsResponseInner
    from poodle_async_full.models.core_message_get_contact_requests_response_inner_contactrequests_inner import CoreMessageGetContactRequestsResponseInnerContactrequestsInner
    from poodle_async_full.models.core_message_get_contact_requests_response_inner_conversations_inner import CoreMessageGetContactRequestsResponseInnerConversationsInner
    from poodle_async_full.models.core_message_get_conversation_between_users_response import CoreMessageGetConversationBetweenUsersResponse
    from poodle_async_full.models.core_message_get_conversation_between_users_response_messages_inner import CoreMessageGetConversationBetweenUsersResponseMessagesInner
    from poodle_async_full.models.core_message_get_conversation_counts_response import CoreMessageGetConversationCountsResponse
    from poodle_async_full.models.core_message_get_conversation_counts_response_types import CoreMessageGetConversationCountsResponseTypes
    from poodle_async_full.models.core_message_get_conversation_messages_response import CoreMessageGetConversationMessagesResponse
    from poodle_async_full.models.core_message_get_conversation_response import CoreMessageGetConversationResponse
    from poodle_async_full.models.core_message_get_conversations_response import CoreMessageGetConversationsResponse
    from poodle_async_full.models.core_message_get_conversations_response_conversations_inner import CoreMessageGetConversationsResponseConversationsInner
    from poodle_async_full.models.core_message_get_message_processor_response import CoreMessageGetMessageProcessorResponse
    from poodle_async_full.models.core_message_get_messages_response import CoreMessageGetMessagesResponse
    from poodle_async_full.models.core_message_get_messages_response_messages_inner import CoreMessageGetMessagesResponseMessagesInner
    from poodle_async_full.models.core_message_get_self_conversation_response import CoreMessageGetSelfConversationResponse
    from poodle_async_full.models.core_message_get_unread_conversation_counts_response import CoreMessageGetUnreadConversationCountsResponse
    from poodle_async_full.models.core_message_get_unread_conversation_counts_response_types import CoreMessageGetUnreadConversationCountsResponseTypes
    from poodle_async_full.models.core_message_get_unsent_message_response import CoreMessageGetUnsentMessageResponse
    from poodle_async_full.models.core_message_get_user_message_preferences_response import CoreMessageGetUserMessagePreferencesResponse
    from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences import CoreMessageGetUserMessagePreferencesResponsePreferences
    from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInner
    from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner_notifications_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInner
    from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner_notifications_inner_processors_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInnerProcessorsInner
    from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_processors_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesProcessorsInner
    from poodle_async_full.models.core_message_get_user_notification_preferences_response import CoreMessageGetUserNotificationPreferencesResponse
    from poodle_async_full.models.core_message_mark_message_read_response import CoreMessageMarkMessageReadResponse
    from poodle_async_full.models.core_message_mark_notification_read_response import CoreMessageMarkNotificationReadResponse
    from poodle_async_full.models.core_message_message_processor_config_form_parameters_formvalues_inner import CoreMessageMessageProcessorConfigFormParametersFormvaluesInner
    from poodle_async_full.models.core_message_message_search_users_response import CoreMessageMessageSearchUsersResponse
    from poodle_async_full.models.core_message_search_contacts_response_inner import CoreMessageSearchContactsResponseInner
    from poodle_async_full.models.core_message_send_instant_messages_parameters_messages_inner import CoreMessageSendInstantMessagesParametersMessagesInner
    from poodle_async_full.models.core_message_send_instant_messages_response_inner import CoreMessageSendInstantMessagesResponseInner
    from poodle_async_full.models.core_message_send_messages_to_conversation_parameters_messages_inner import CoreMessageSendMessagesToConversationParametersMessagesInner
    from poodle_async_full.models.core_message_set_default_notification_response import CoreMessageSetDefaultNotificationResponse
    from poodle_async_full.models.core_moodlenet_auth_check_response import CoreMoodlenetAuthCheckResponse
    from poodle_async_full.models.core_moodlenet_get_share_info_activity_response import CoreMoodlenetGetShareInfoActivityResponse
    from poodle_async_full.models.core_moodlenet_get_shared_course_info_response import CoreMoodlenetGetSharedCourseInfoResponse
    from poodle_async_full.models.core_moodlenet_send_activity_response import CoreMoodlenetSendActivityResponse
    from poodle_async_full.models.core_moodlenet_send_course_response import CoreMoodlenetSendCourseResponse
    from poodle_async_full.models.core_my_view_page_response import CoreMyViewPageResponse
    from poodle_async_full.models.core_notes_create_notes_parameters_notes_inner import CoreNotesCreateNotesParametersNotesInner
    from poodle_async_full.models.core_notes_create_notes_response_inner import CoreNotesCreateNotesResponseInner
    from poodle_async_full.models.core_notes_delete_notes_response_inner import CoreNotesDeleteNotesResponseInner
    from poodle_async_full.models.core_notes_get_course_notes_response import CoreNotesGetCourseNotesResponse
    from poodle_async_full.models.core_notes_get_course_notes_response_coursenotes_inner import CoreNotesGetCourseNotesResponseCoursenotesInner
    from poodle_async_full.models.core_notes_get_notes_response import CoreNotesGetNotesResponse
    from poodle_async_full.models.core_notes_get_notes_response_notes_inner import CoreNotesGetNotesResponseNotesInner
    from poodle_async_full.models.core_notes_update_notes_parameters_notes_inner import CoreNotesUpdateNotesParametersNotesInner
    from poodle_async_full.models.core_notes_view_notes_response import CoreNotesViewNotesResponse
    from poodle_async_full.models.core_output_load_fontawesome_icon_system_map_parameters import CoreOutputLoadFontawesomeIconSystemMapParameters
    from poodle_async_full.models.core_output_load_fontawesome_icon_system_map_response_inner import CoreOutputLoadFontawesomeIconSystemMapResponseInner
    from poodle_async_full.models.core_output_load_template_parameters import CoreOutputLoadTemplateParameters
    from poodle_async_full.models.core_output_load_template_with_dependencies_parameters import CoreOutputLoadTemplateWithDependenciesParameters
    from poodle_async_full.models.core_output_load_template_with_dependencies_response import CoreOutputLoadTemplateWithDependenciesResponse
    from poodle_async_full.models.core_output_load_template_with_dependencies_response_strings_inner import CoreOutputLoadTemplateWithDependenciesResponseStringsInner
    from poodle_async_full.models.core_output_poll_stored_progress_response_inner import CoreOutputPollStoredProgressResponseInner
    from poodle_async_full.models.core_payment_get_available_gateways_response_inner import CorePaymentGetAvailableGatewaysResponseInner
    from poodle_async_full.models.core_question_get_random_question_summaries_response import CoreQuestionGetRandomQuestionSummariesResponse
    from poodle_async_full.models.core_question_get_random_question_summaries_response_questions_inner import CoreQuestionGetRandomQuestionSummariesResponseQuestionsInner
    from poodle_async_full.models.core_question_get_random_question_summaries_response_questions_inner_icon import CoreQuestionGetRandomQuestionSummariesResponseQuestionsInnerIcon
    from poodle_async_full.models.core_question_search_shared_banks_response import CoreQuestionSearchSharedBanksResponse
    from poodle_async_full.models.core_question_search_shared_banks_response_sharedbanks_inner import CoreQuestionSearchSharedBanksResponseSharedbanksInner
    from poodle_async_full.models.core_question_update_flag_response import CoreQuestionUpdateFlagResponse
    from poodle_async_full.models.core_rating_add_rating_response import CoreRatingAddRatingResponse
    from poodle_async_full.models.core_rating_get_item_ratings_response import CoreRatingGetItemRatingsResponse
    from poodle_async_full.models.core_rating_get_item_ratings_response_ratings_inner import CoreRatingGetItemRatingsResponseRatingsInner
    from poodle_async_full.models.core_reportbuilder_can_view_system_report_parameters_parameters_inner import CoreReportbuilderCanViewSystemReportParametersParametersInner
    from poodle_async_full.models.core_reportbuilder_columns_add_response import CoreReportbuilderColumnsAddResponse
    from poodle_async_full.models.core_reportbuilder_columns_add_response_sortablecolumns_inner import CoreReportbuilderColumnsAddResponseSortablecolumnsInner
    from poodle_async_full.models.core_reportbuilder_columns_add_response_sortablecolumns_inner_sorticon import CoreReportbuilderColumnsAddResponseSortablecolumnsInnerSorticon
    from poodle_async_full.models.core_reportbuilder_columns_delete_response import CoreReportbuilderColumnsDeleteResponse
    from poodle_async_full.models.core_reportbuilder_columns_sort_get_response import CoreReportbuilderColumnsSortGetResponse
    from poodle_async_full.models.core_reportbuilder_columns_sort_reorder_response import CoreReportbuilderColumnsSortReorderResponse
    from poodle_async_full.models.core_reportbuilder_columns_sort_toggle_response import CoreReportbuilderColumnsSortToggleResponse
    from poodle_async_full.models.core_reportbuilder_conditions_add_response import CoreReportbuilderConditionsAddResponse
    from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner import CoreReportbuilderConditionsAddResponseAvailableconditionsInner
    from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner_optiongroup import CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroup
    from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner_optiongroup_values_inner import CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroupValuesInner
    from poodle_async_full.models.core_reportbuilder_conditions_delete_response import CoreReportbuilderConditionsDeleteResponse
    from poodle_async_full.models.core_reportbuilder_conditions_reorder_response import CoreReportbuilderConditionsReorderResponse
    from poodle_async_full.models.core_reportbuilder_conditions_reset_response import CoreReportbuilderConditionsResetResponse
    from poodle_async_full.models.core_reportbuilder_filters_add_response import CoreReportbuilderFiltersAddResponse
    from poodle_async_full.models.core_reportbuilder_filters_add_response_activefilters_inner import CoreReportbuilderFiltersAddResponseActivefiltersInner
    from poodle_async_full.models.core_reportbuilder_filters_delete_response import CoreReportbuilderFiltersDeleteResponse
    from poodle_async_full.models.core_reportbuilder_filters_reorder_response import CoreReportbuilderFiltersReorderResponse
    from poodle_async_full.models.core_reportbuilder_list_reports_response import CoreReportbuilderListReportsResponse
    from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner import CoreReportbuilderListReportsResponseReportsInner
    from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner_customfields import CoreReportbuilderListReportsResponseReportsInnerCustomfields
    from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner_customfields_data_inner import CoreReportbuilderListReportsResponseReportsInnerCustomfieldsDataInner
    from poodle_async_full.models.core_reportbuilder_reports_get_response import CoreReportbuilderReportsGetResponse
    from poodle_async_full.models.core_reportbuilder_reports_get_response_attributes_inner import CoreReportbuilderReportsGetResponseAttributesInner
    from poodle_async_full.models.core_reportbuilder_reports_get_response_button import CoreReportbuilderReportsGetResponseButton
    from poodle_async_full.models.core_reportbuilder_reports_get_response_button_attributes_inner import CoreReportbuilderReportsGetResponseButtonAttributesInner
    from poodle_async_full.models.core_reportbuilder_reports_get_response_cardview import CoreReportbuilderReportsGetResponseCardview
    from poodle_async_full.models.core_reportbuilder_reports_get_response_conditions import CoreReportbuilderReportsGetResponseConditions
    from poodle_async_full.models.core_reportbuilder_reports_get_response_filters import CoreReportbuilderReportsGetResponseFilters
    from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards import CoreReportbuilderReportsGetResponseSidebarmenucards
    from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards_menucards_inner import CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInner
    from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards_menucards_inner_items_inner import CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInnerItemsInner
    from poodle_async_full.models.core_reportbuilder_reports_get_response_sorting import CoreReportbuilderReportsGetResponseSorting
    from poodle_async_full.models.core_reportbuilder_retrieve_report_response import CoreReportbuilderRetrieveReportResponse
    from poodle_async_full.models.core_reportbuilder_retrieve_report_response_data import CoreReportbuilderRetrieveReportResponseData
    from poodle_async_full.models.core_reportbuilder_retrieve_report_response_data_rows_inner import CoreReportbuilderRetrieveReportResponseDataRowsInner
    from poodle_async_full.models.core_reportbuilder_retrieve_system_report_response import CoreReportbuilderRetrieveSystemReportResponse
    from poodle_async_full.models.core_reportbuilder_view_report_response import CoreReportbuilderViewReportResponse
    from poodle_async_full.models.core_role_assign_roles_parameters_assignments_inner import CoreRoleAssignRolesParametersAssignmentsInner
    from poodle_async_full.models.core_role_unassign_roles_parameters_unassignments_inner import CoreRoleUnassignRolesParametersUnassignmentsInner
    from poodle_async_full.models.core_search_get_relevant_users_response_inner import CoreSearchGetRelevantUsersResponseInner
    from poodle_async_full.models.core_search_get_results_parameters_filters import CoreSearchGetResultsParametersFilters
    from poodle_async_full.models.core_search_get_results_response import CoreSearchGetResultsResponse
    from poodle_async_full.models.core_search_get_results_response_results_inner import CoreSearchGetResultsResponseResultsInner
    from poodle_async_full.models.core_search_get_search_areas_list_response import CoreSearchGetSearchAreasListResponse
    from poodle_async_full.models.core_search_get_search_areas_list_response_areas_inner import CoreSearchGetSearchAreasListResponseAreasInner
    from poodle_async_full.models.core_search_get_top_results_response import CoreSearchGetTopResultsResponse
    from poodle_async_full.models.core_search_view_results_parameters_filters import CoreSearchViewResultsParametersFilters
    from poodle_async_full.models.core_search_view_results_response import CoreSearchViewResultsResponse
    from poodle_async_full.models.core_session_time_remaining_response import CoreSessionTimeRemainingResponse
    from poodle_async_full.models.core_sms_set_gateway_status_response import CoreSmsSetGatewayStatusResponse
    from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_filters_inner import CoreTableGetDynamicTableContentParametersFiltersInner
    from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_filters_inner_filteroptions_inner import CoreTableGetDynamicTableContentParametersFiltersInnerFilteroptionsInner
    from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_sortdata_inner import CoreTableGetDynamicTableContentParametersSortdataInner
    from poodle_async_full.models.core_table_get_dynamic_table_content_response import CoreTableGetDynamicTableContentResponse
    from poodle_async_full.models.core_tag_get_tag_areas_response import CoreTagGetTagAreasResponse
    from poodle_async_full.models.core_tag_get_tag_areas_response_areas_inner import CoreTagGetTagAreasResponseAreasInner
    from poodle_async_full.models.core_tag_get_tag_cloud_response import CoreTagGetTagCloudResponse
    from poodle_async_full.models.core_tag_get_tag_cloud_response_tags_inner import CoreTagGetTagCloudResponseTagsInner
    from poodle_async_full.models.core_tag_get_tag_collections_response import CoreTagGetTagCollectionsResponse
    from poodle_async_full.models.core_tag_get_tag_collections_response_collections_inner import CoreTagGetTagCollectionsResponseCollectionsInner
    from poodle_async_full.models.core_tag_get_tagindex_parameters_tagindex import CoreTagGetTagindexParametersTagindex
    from poodle_async_full.models.core_tag_get_tagindex_per_area_parameters_tagindex import CoreTagGetTagindexPerAreaParametersTagindex
    from poodle_async_full.models.core_tag_get_tagindex_per_area_response_inner import CoreTagGetTagindexPerAreaResponseInner
    from poodle_async_full.models.core_tag_get_tagindex_response import CoreTagGetTagindexResponse
    from poodle_async_full.models.core_tag_get_tags_parameters_tags_inner import CoreTagGetTagsParametersTagsInner
    from poodle_async_full.models.core_tag_get_tags_response import CoreTagGetTagsResponse
    from poodle_async_full.models.core_tag_get_tags_response_tags_inner import CoreTagGetTagsResponseTagsInner
    from poodle_async_full.models.core_tag_update_tags_parameters_tags_inner import CoreTagUpdateTagsParametersTagsInner
    from poodle_async_full.models.core_tag_update_tags_response import CoreTagUpdateTagsResponse
    from poodle_async_full.models.core_update_inplace_editable_response import CoreUpdateInplaceEditableResponse
    from poodle_async_full.models.core_update_inplace_editable_response_editicon import CoreUpdateInplaceEditableResponseEditicon
    from poodle_async_full.models.core_user_agree_site_policy_response import CoreUserAgreeSitePolicyResponse
    from poodle_async_full.models.core_user_create_users_parameters_users_inner import CoreUserCreateUsersParametersUsersInner
    from poodle_async_full.models.core_user_create_users_parameters_users_inner_customfields_inner import CoreUserCreateUsersParametersUsersInnerCustomfieldsInner
    from poodle_async_full.models.core_user_create_users_parameters_users_inner_preferences_inner import CoreUserCreateUsersParametersUsersInnerPreferencesInner
    from poodle_async_full.models.core_user_create_users_response_inner import CoreUserCreateUsersResponseInner
    from poodle_async_full.models.core_user_get_course_user_profiles_parameters_userlist_inner import CoreUserGetCourseUserProfilesParametersUserlistInner
    from poodle_async_full.models.core_user_get_course_user_profiles_response_inner import CoreUserGetCourseUserProfilesResponseInner
    from poodle_async_full.models.core_user_get_private_files_info_response import CoreUserGetPrivateFilesInfoResponse
    from poodle_async_full.models.core_user_get_user_preferences_response import CoreUserGetUserPreferencesResponse
    from poodle_async_full.models.core_user_get_user_preferences_response_preferences_inner import CoreUserGetUserPreferencesResponsePreferencesInner
    from poodle_async_full.models.core_user_get_users_parameters_criteria_inner import CoreUserGetUsersParametersCriteriaInner
    from poodle_async_full.models.core_user_get_users_response import CoreUserGetUsersResponse
    from poodle_async_full.models.core_user_get_users_response_warnings_inner import CoreUserGetUsersResponseWarningsInner
    from poodle_async_full.models.core_user_prepare_private_files_for_edition_response import CoreUserPreparePrivateFilesForEditionResponse
    from poodle_async_full.models.core_user_remove_user_device_response import CoreUserRemoveUserDeviceResponse
    from poodle_async_full.models.core_user_search_identity_response import CoreUserSearchIdentityResponse
    from poodle_async_full.models.core_user_search_identity_response_list_inner import CoreUserSearchIdentityResponseListInner
    from poodle_async_full.models.core_user_search_identity_response_list_inner_extrafields_inner import CoreUserSearchIdentityResponseListInnerExtrafieldsInner
    from poodle_async_full.models.core_user_set_user_preferences_parameters import CoreUserSetUserPreferencesParameters
    from poodle_async_full.models.core_user_set_user_preferences_parameters_preferences_inner import CoreUserSetUserPreferencesParametersPreferencesInner
    from poodle_async_full.models.core_user_set_user_preferences_response import CoreUserSetUserPreferencesResponse
    from poodle_async_full.models.core_user_set_user_preferences_response_saved_inner import CoreUserSetUserPreferencesResponseSavedInner
    from poodle_async_full.models.core_user_update_picture_response import CoreUserUpdatePictureResponse
    from poodle_async_full.models.core_user_update_private_files_response import CoreUserUpdatePrivateFilesResponse
    from poodle_async_full.models.core_user_update_user_device_public_key_response import CoreUserUpdateUserDevicePublicKeyResponse
    from poodle_async_full.models.core_user_update_user_preferences_parameters_preferences_inner import CoreUserUpdateUserPreferencesParametersPreferencesInner
    from poodle_async_full.models.core_user_update_users_parameters_users_inner import CoreUserUpdateUsersParametersUsersInner
    from poodle_async_full.models.core_user_update_users_response import CoreUserUpdateUsersResponse
    from poodle_async_full.models.core_user_view_user_list_response import CoreUserViewUserListResponse
    from poodle_async_full.models.core_user_view_user_profile_response import CoreUserViewUserProfileResponse
    from poodle_async_full.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse
    from poodle_async_full.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
    from poodle_async_full.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner
    from poodle_async_full.models.customfield_number_recalculate_value_response import CustomfieldNumberRecalculateValueResponse
    from poodle_async_full.models.editor_tiny_get_configuration_response import EditorTinyGetConfigurationResponse
    from poodle_async_full.models.editor_tiny_get_configuration_response_installedlanguages_inner import EditorTinyGetConfigurationResponseInstalledlanguagesInner
    from poodle_async_full.models.editor_tiny_get_configuration_response_plugins_inner import EditorTinyGetConfigurationResponsePluginsInner
    from poodle_async_full.models.editor_tiny_get_configuration_response_plugins_inner_settings_inner import EditorTinyGetConfigurationResponsePluginsInnerSettingsInner
    from poodle_async_full.models.enrol_guest_get_instance_info_response import EnrolGuestGetInstanceInfoResponse
    from poodle_async_full.models.enrol_guest_get_instance_info_response_instanceinfo import EnrolGuestGetInstanceInfoResponseInstanceinfo
    from poodle_async_full.models.enrol_guest_validate_password_response import EnrolGuestValidatePasswordResponse
    from poodle_async_full.models.enrol_manual_enrol_users_parameters_enrolments_inner import EnrolManualEnrolUsersParametersEnrolmentsInner
    from poodle_async_full.models.enrol_manual_unenrol_users_parameters_enrolments_inner import EnrolManualUnenrolUsersParametersEnrolmentsInner
    from poodle_async_full.models.enrol_meta_add_instances_parameters_instances_inner import EnrolMetaAddInstancesParametersInstancesInner
    from poodle_async_full.models.enrol_meta_add_instances_response_inner import EnrolMetaAddInstancesResponseInner
    from poodle_async_full.models.enrol_meta_delete_instances_parameters_instances_inner import EnrolMetaDeleteInstancesParametersInstancesInner
    from poodle_async_full.models.enrol_meta_delete_instances_response_inner import EnrolMetaDeleteInstancesResponseInner
    from poodle_async_full.models.enrol_self_enrol_user_response import EnrolSelfEnrolUserResponse
    from poodle_async_full.models.enrol_self_get_instance_info_response import EnrolSelfGetInstanceInfoResponse
    from poodle_async_full.models.gradereport_grader_get_users_in_report_response import GradereportGraderGetUsersInReportResponse
    from poodle_async_full.models.gradereport_overview_get_course_grades_response import GradereportOverviewGetCourseGradesResponse
    from poodle_async_full.models.gradereport_overview_get_course_grades_response_grades_inner import GradereportOverviewGetCourseGradesResponseGradesInner
    from poodle_async_full.models.gradereport_overview_view_grade_report_response import GradereportOverviewViewGradeReportResponse
    from poodle_async_full.models.gradereport_singleview_get_grade_items_for_search_widget_response import GradereportSingleviewGetGradeItemsForSearchWidgetResponse
    from poodle_async_full.models.gradereport_singleview_get_grade_items_for_search_widget_response_gradeitems_inner import GradereportSingleviewGetGradeItemsForSearchWidgetResponseGradeitemsInner
    from poodle_async_full.models.gradereport_user_get_access_information_response import GradereportUserGetAccessInformationResponse
    from poodle_async_full.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse
    from poodle_async_full.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner
    from poodle_async_full.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
    from poodle_async_full.models.gradereport_user_get_grades_table_response import GradereportUserGetGradesTableResponse
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner import GradereportUserGetGradesTableResponseTablesInner
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner import GradereportUserGetGradesTableResponseTablesInnerTabledataInner
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_average import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_contributiontocoursetotal import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_feedback import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_grade import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_itemname import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_leader import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_lettergrade import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_percentage import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_range import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_rank import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank
    from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_weight import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight
    from poodle_async_full.models.gradereport_user_view_grade_report_response import GradereportUserViewGradeReportResponse
    from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response import GradingformGuideGraderGradingpanelFetchResponse
    from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade import GradingformGuideGraderGradingpanelFetchResponseGrade
    from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade_comments_inner import GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner
    from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade_criterion_inner import GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner
    from poodle_async_full.models.gradingform_guide_grader_gradingpanel_store_response import GradingformGuideGraderGradingpanelStoreResponse
    from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response import GradingformRubricGraderGradingpanelFetchResponse
    from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade import GradingformRubricGraderGradingpanelFetchResponseGrade
    from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade_criteria_inner import GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInner
    from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade_criteria_inner_levels_inner import GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInnerLevelsInner
    from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_store_response import GradingformRubricGraderGradingpanelStoreResponse
    from poodle_async_full.models.login_token200_response import LoginToken200Response
    from poodle_async_full.models.media_videojs_get_language_parameters import MediaVideojsGetLanguageParameters
    from poodle_async_full.models.message_airnotifier_are_notification_preferences_configured_response import MessageAirnotifierAreNotificationPreferencesConfiguredResponse
    from poodle_async_full.models.message_airnotifier_are_notification_preferences_configured_response_users_inner import MessageAirnotifierAreNotificationPreferencesConfiguredResponseUsersInner
    from poodle_async_full.models.message_airnotifier_enable_device_response import MessageAirnotifierEnableDeviceResponse
    from poodle_async_full.models.message_airnotifier_get_user_devices_response import MessageAirnotifierGetUserDevicesResponse
    from poodle_async_full.models.message_airnotifier_get_user_devices_response_devices_inner import MessageAirnotifierGetUserDevicesResponseDevicesInner
    from poodle_async_full.models.message_popup_get_popup_notifications_response import MessagePopupGetPopupNotificationsResponse
    from poodle_async_full.models.message_popup_get_popup_notifications_response_notifications_inner import MessagePopupGetPopupNotificationsResponseNotificationsInner
    from poodle_async_full.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse
    from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner
    from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
    from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
    from poodle_async_full.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner
    from poodle_async_full.models.mod_assign_get_grades_response import ModAssignGetGradesResponse
    from poodle_async_full.models.mod_assign_get_grades_response_assignments_inner import ModAssignGetGradesResponseAssignmentsInner
    from poodle_async_full.models.mod_assign_get_grades_response_assignments_inner_grades_inner import ModAssignGetGradesResponseAssignmentsInnerGradesInner
    from poodle_async_full.models.mod_assign_get_grades_response_warnings_inner import ModAssignGetGradesResponseWarningsInner
    from poodle_async_full.models.mod_assign_get_participant_response import ModAssignGetParticipantResponse
    from poodle_async_full.models.mod_assign_get_submission_status_response import ModAssignGetSubmissionStatusResponse
    from poodle_async_full.models.mod_assign_get_submission_status_response_assignmentdata import ModAssignGetSubmissionStatusResponseAssignmentdata
    from poodle_async_full.models.mod_assign_get_submission_status_response_assignmentdata_attachments import ModAssignGetSubmissionStatusResponseAssignmentdataAttachments
    from poodle_async_full.models.mod_assign_get_submission_status_response_feedback import ModAssignGetSubmissionStatusResponseFeedback
    from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInner
    from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner_editorfields_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerEditorfieldsInner
    from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner_fileareas_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerFileareasInner
    from poodle_async_full.models.mod_assign_get_submission_status_response_gradingsummary import ModAssignGetSubmissionStatusResponseGradingsummary
    from poodle_async_full.models.mod_assign_get_submission_status_response_lastattempt import ModAssignGetSubmissionStatusResponseLastattempt
    from poodle_async_full.models.mod_assign_get_submission_status_response_lastattempt_submission import ModAssignGetSubmissionStatusResponseLastattemptSubmission
    from poodle_async_full.models.mod_assign_get_submission_status_response_previousattempts_inner import ModAssignGetSubmissionStatusResponsePreviousattemptsInner
    from poodle_async_full.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse
    from poodle_async_full.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner
    from poodle_async_full.models.mod_assign_get_user_flags_response import ModAssignGetUserFlagsResponse
    from poodle_async_full.models.mod_assign_get_user_flags_response_assignments_inner import ModAssignGetUserFlagsResponseAssignmentsInner
    from poodle_async_full.models.mod_assign_get_user_flags_response_assignments_inner_userflags_inner import ModAssignGetUserFlagsResponseAssignmentsInnerUserflagsInner
    from poodle_async_full.models.mod_assign_get_user_flags_response_warnings_inner import ModAssignGetUserFlagsResponseWarningsInner
    from poodle_async_full.models.mod_assign_get_user_mappings_response import ModAssignGetUserMappingsResponse
    from poodle_async_full.models.mod_assign_get_user_mappings_response_assignments_inner import ModAssignGetUserMappingsResponseAssignmentsInner
    from poodle_async_full.models.mod_assign_get_user_mappings_response_assignments_inner_mappings_inner import ModAssignGetUserMappingsResponseAssignmentsInnerMappingsInner
    from poodle_async_full.models.mod_assign_get_user_mappings_response_warnings_inner import ModAssignGetUserMappingsResponseWarningsInner
    from poodle_async_full.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner
    from poodle_async_full.models.mod_assign_remove_submission_response import ModAssignRemoveSubmissionResponse
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata import ModAssignSaveGradeParametersAdvancedgradingdata
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide import ModAssignSaveGradeParametersAdvancedgradingdataGuide
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide_criteria_inner import ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInner
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide_criteria_inner_fillings_inner import ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInnerFillingsInner
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric import ModAssignSaveGradeParametersAdvancedgradingdataRubric
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric_criteria_inner import ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInner
    from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric_criteria_inner_fillings_inner import ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInnerFillingsInner
    from poodle_async_full.models.mod_assign_save_grade_parameters_plugindata import ModAssignSaveGradeParametersPlugindata
    from poodle_async_full.models.mod_assign_save_grade_parameters_plugindata_assignfeedbackcomments_editor import ModAssignSaveGradeParametersPlugindataAssignfeedbackcommentsEditor
    from poodle_async_full.models.mod_assign_save_grades_parameters_grades_inner import ModAssignSaveGradesParametersGradesInner
    from poodle_async_full.models.mod_assign_save_submission_parameters_plugindata import ModAssignSaveSubmissionParametersPlugindata
    from poodle_async_full.models.mod_assign_save_submission_parameters_plugindata_onlinetext_editor import ModAssignSaveSubmissionParametersPlugindataOnlinetextEditor
    from poodle_async_full.models.mod_assign_set_user_flags_parameters_userflags_inner import ModAssignSetUserFlagsParametersUserflagsInner
    from poodle_async_full.models.mod_assign_set_user_flags_response_inner import ModAssignSetUserFlagsResponseInner
    from poodle_async_full.models.mod_assign_start_submission_response import ModAssignStartSubmissionResponse
    from poodle_async_full.models.mod_assign_view_assign_response import ModAssignViewAssignResponse
    from poodle_async_full.models.mod_assign_view_grading_table_response import ModAssignViewGradingTableResponse
    from poodle_async_full.models.mod_assign_view_submission_status_response import ModAssignViewSubmissionStatusResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_can_join_response import ModBigbluebuttonbnCanJoinResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_completion_validate_response import ModBigbluebuttonbnCompletionValidateResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_end_meeting_response import ModBigbluebuttonbnEndMeetingResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_get_bigbluebuttonbns_by_courses_response import ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_get_bigbluebuttonbns_by_courses_response_bigbluebuttonbns_inner import ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponseBigbluebuttonbnsInner
    from poodle_async_full.models.mod_bigbluebuttonbn_get_join_url_response import ModBigbluebuttonbnGetJoinUrlResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response import ModBigbluebuttonbnGetRecordingsResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response_tabledata import ModBigbluebuttonbnGetRecordingsResponseTabledata
    from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response_tabledata_columns_inner import ModBigbluebuttonbnGetRecordingsResponseTabledataColumnsInner
    from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_to_import_response import ModBigbluebuttonbnGetRecordingsToImportResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response import ModBigbluebuttonbnMeetingInfoResponse
    from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response_features_inner import ModBigbluebuttonbnMeetingInfoResponseFeaturesInner
    from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response_presentations_inner import ModBigbluebuttonbnMeetingInfoResponsePresentationsInner
    from poodle_async_full.models.mod_bigbluebuttonbn_view_bigbluebuttonbn_response import ModBigbluebuttonbnViewBigbluebuttonbnResponse
    from poodle_async_full.models.mod_book_get_books_by_courses_response import ModBookGetBooksByCoursesResponse
    from poodle_async_full.models.mod_book_get_books_by_courses_response_books_inner import ModBookGetBooksByCoursesResponseBooksInner
    from poodle_async_full.models.mod_book_view_book_response import ModBookViewBookResponse
    from poodle_async_full.models.mod_choice_delete_choice_responses_response import ModChoiceDeleteChoiceResponsesResponse
    from poodle_async_full.models.mod_choice_get_choice_options_response import ModChoiceGetChoiceOptionsResponse
    from poodle_async_full.models.mod_choice_get_choice_options_response_options_inner import ModChoiceGetChoiceOptionsResponseOptionsInner
    from poodle_async_full.models.mod_choice_get_choice_results_response import ModChoiceGetChoiceResultsResponse
    from poodle_async_full.models.mod_choice_get_choice_results_response_options_inner import ModChoiceGetChoiceResultsResponseOptionsInner
    from poodle_async_full.models.mod_choice_get_choice_results_response_options_inner_userresponses_inner import ModChoiceGetChoiceResultsResponseOptionsInnerUserresponsesInner
    from poodle_async_full.models.mod_choice_get_choices_by_courses_response import ModChoiceGetChoicesByCoursesResponse
    from poodle_async_full.models.mod_choice_get_choices_by_courses_response_choices_inner import ModChoiceGetChoicesByCoursesResponseChoicesInner
    from poodle_async_full.models.mod_choice_submit_choice_response_response import ModChoiceSubmitChoiceResponseResponse
    from poodle_async_full.models.mod_choice_submit_choice_response_response_answers_inner import ModChoiceSubmitChoiceResponseResponseAnswersInner
    from poodle_async_full.models.mod_choice_view_choice_response import ModChoiceViewChoiceResponse
    from poodle_async_full.models.mod_data_add_entry_parameters_data_inner import ModDataAddEntryParametersDataInner
    from poodle_async_full.models.mod_data_add_entry_response import ModDataAddEntryResponse
    from poodle_async_full.models.mod_data_add_entry_response_fieldnotifications_inner import ModDataAddEntryResponseFieldnotificationsInner
    from poodle_async_full.models.mod_data_approve_entry_response import ModDataApproveEntryResponse
    from poodle_async_full.models.mod_data_delete_entry_response import ModDataDeleteEntryResponse
    from poodle_async_full.models.mod_data_delete_saved_preset_response import ModDataDeleteSavedPresetResponse
    from poodle_async_full.models.mod_data_get_data_access_information_response import ModDataGetDataAccessInformationResponse
    from poodle_async_full.models.mod_data_get_databases_by_courses_response import ModDataGetDatabasesByCoursesResponse
    from poodle_async_full.models.mod_data_get_databases_by_courses_response_databases_inner import ModDataGetDatabasesByCoursesResponseDatabasesInner
    from poodle_async_full.models.mod_data_get_entries_response import ModDataGetEntriesResponse
    from poodle_async_full.models.mod_data_get_entries_response_entries_inner import ModDataGetEntriesResponseEntriesInner
    from poodle_async_full.models.mod_data_get_entries_response_entries_inner_contents_inner import ModDataGetEntriesResponseEntriesInnerContentsInner
    from poodle_async_full.models.mod_data_get_entry_response import ModDataGetEntryResponse
    from poodle_async_full.models.mod_data_get_entry_response_ratinginfo import ModDataGetEntryResponseRatinginfo
    from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_ratings_inner import ModDataGetEntryResponseRatinginfoRatingsInner
    from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_scales_inner import ModDataGetEntryResponseRatinginfoScalesInner
    from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_scales_inner_items_inner import ModDataGetEntryResponseRatinginfoScalesInnerItemsInner
    from poodle_async_full.models.mod_data_get_fields_response import ModDataGetFieldsResponse
    from poodle_async_full.models.mod_data_get_fields_response_fields_inner import ModDataGetFieldsResponseFieldsInner
    from poodle_async_full.models.mod_data_get_mapping_information_response import ModDataGetMappingInformationResponse
    from poodle_async_full.models.mod_data_get_mapping_information_response_data import ModDataGetMappingInformationResponseData
    from poodle_async_full.models.mod_data_search_entries_parameters_advsearch_inner import ModDataSearchEntriesParametersAdvsearchInner
    from poodle_async_full.models.mod_data_search_entries_response import ModDataSearchEntriesResponse
    from poodle_async_full.models.mod_data_update_entry_parameters_data_inner import ModDataUpdateEntryParametersDataInner
    from poodle_async_full.models.mod_data_update_entry_response import ModDataUpdateEntryResponse
    from poodle_async_full.models.mod_data_view_database_response import ModDataViewDatabaseResponse
    from poodle_async_full.models.mod_feedback_get_analysis_response import ModFeedbackGetAnalysisResponse
    from poodle_async_full.models.mod_feedback_get_analysis_response_itemsdata_inner import ModFeedbackGetAnalysisResponseItemsdataInner
    from poodle_async_full.models.mod_feedback_get_analysis_response_itemsdata_inner_item import ModFeedbackGetAnalysisResponseItemsdataInnerItem
    from poodle_async_full.models.mod_feedback_get_current_completed_tmp_response import ModFeedbackGetCurrentCompletedTmpResponse
    from poodle_async_full.models.mod_feedback_get_current_completed_tmp_response_feedback import ModFeedbackGetCurrentCompletedTmpResponseFeedback
    from poodle_async_full.models.mod_feedback_get_feedback_access_information_response import ModFeedbackGetFeedbackAccessInformationResponse
    from poodle_async_full.models.mod_feedback_get_feedbacks_by_courses_response import ModFeedbackGetFeedbacksByCoursesResponse
    from poodle_async_full.models.mod_feedback_get_feedbacks_by_courses_response_feedbacks_inner import ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner
    from poodle_async_full.models.mod_feedback_get_finished_responses_response import ModFeedbackGetFinishedResponsesResponse
    from poodle_async_full.models.mod_feedback_get_finished_responses_response_responses_inner import ModFeedbackGetFinishedResponsesResponseResponsesInner
    from poodle_async_full.models.mod_feedback_get_items_response import ModFeedbackGetItemsResponse
    from poodle_async_full.models.mod_feedback_get_last_completed_response import ModFeedbackGetLastCompletedResponse
    from poodle_async_full.models.mod_feedback_get_last_completed_response_completed import ModFeedbackGetLastCompletedResponseCompleted
    from poodle_async_full.models.mod_feedback_get_non_respondents_response import ModFeedbackGetNonRespondentsResponse
    from poodle_async_full.models.mod_feedback_get_non_respondents_response_users_inner import ModFeedbackGetNonRespondentsResponseUsersInner
    from poodle_async_full.models.mod_feedback_get_page_items_response import ModFeedbackGetPageItemsResponse
    from poodle_async_full.models.mod_feedback_get_responses_analysis_response import ModFeedbackGetResponsesAnalysisResponse
    from poodle_async_full.models.mod_feedback_get_responses_analysis_response_anonattempts_inner import ModFeedbackGetResponsesAnalysisResponseAnonattemptsInner
    from poodle_async_full.models.mod_feedback_get_responses_analysis_response_anonattempts_inner_responses_inner import ModFeedbackGetResponsesAnalysisResponseAnonattemptsInnerResponsesInner
    from poodle_async_full.models.mod_feedback_get_responses_analysis_response_attempts_inner import ModFeedbackGetResponsesAnalysisResponseAttemptsInner
    from poodle_async_full.models.mod_feedback_get_unfinished_responses_response import ModFeedbackGetUnfinishedResponsesResponse
    from poodle_async_full.models.mod_feedback_get_unfinished_responses_response_responses_inner import ModFeedbackGetUnfinishedResponsesResponseResponsesInner
    from poodle_async_full.models.mod_feedback_launch_feedback_response import ModFeedbackLaunchFeedbackResponse
    from poodle_async_full.models.mod_feedback_process_page_parameters_responses_inner import ModFeedbackProcessPageParametersResponsesInner
    from poodle_async_full.models.mod_feedback_process_page_response import ModFeedbackProcessPageResponse
    from poodle_async_full.models.mod_feedback_view_feedback_response import ModFeedbackViewFeedbackResponse
    from poodle_async_full.models.mod_folder_get_folders_by_courses_response import ModFolderGetFoldersByCoursesResponse
    from poodle_async_full.models.mod_folder_get_folders_by_courses_response_folders_inner import ModFolderGetFoldersByCoursesResponseFoldersInner
    from poodle_async_full.models.mod_folder_view_folder_response import ModFolderViewFolderResponse
    from poodle_async_full.models.mod_forum_add_discussion_parameters_options_inner import ModForumAddDiscussionParametersOptionsInner
    from poodle_async_full.models.mod_forum_add_discussion_post_parameters_options_inner import ModForumAddDiscussionPostParametersOptionsInner
    from poodle_async_full.models.mod_forum_add_discussion_post_response import ModForumAddDiscussionPostResponse
    from poodle_async_full.models.mod_forum_add_discussion_post_response_messages_inner import ModForumAddDiscussionPostResponseMessagesInner
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post import ModForumAddDiscussionPostResponsePost
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner import ModForumAddDiscussionPostResponsePostAttachmentsInner
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner_html import ModForumAddDiscussionPostResponsePostAttachmentsInnerHtml
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner_urls import ModForumAddDiscussionPostResponsePostAttachmentsInnerUrls
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author import ModForumAddDiscussionPostResponsePostAuthor
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_groups_inner import ModForumAddDiscussionPostResponsePostAuthorGroupsInner
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_groups_inner_urls import ModForumAddDiscussionPostResponsePostAuthorGroupsInnerUrls
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_urls import ModForumAddDiscussionPostResponsePostAuthorUrls
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_capabilities import ModForumAddDiscussionPostResponsePostCapabilities
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_html import ModForumAddDiscussionPostResponsePostHtml
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_tags_inner import ModForumAddDiscussionPostResponsePostTagsInner
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_tags_inner_urls import ModForumAddDiscussionPostResponsePostTagsInnerUrls
    from poodle_async_full.models.mod_forum_add_discussion_post_response_post_urls import ModForumAddDiscussionPostResponsePostUrls
    from poodle_async_full.models.mod_forum_add_discussion_response import ModForumAddDiscussionResponse
    from poodle_async_full.models.mod_forum_can_add_discussion_response import ModForumCanAddDiscussionResponse
    from poodle_async_full.models.mod_forum_delete_post_response import ModForumDeletePostResponse
    from poodle_async_full.models.mod_forum_get_discussion_post_response import ModForumGetDiscussionPostResponse
    from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response import ModForumGetDiscussionPostsByUseridResponse
    from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response_discussions_inner import ModForumGetDiscussionPostsByUseridResponseDiscussionsInner
    from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response_discussions_inner_posts import ModForumGetDiscussionPostsByUseridResponseDiscussionsInnerPosts
    from poodle_async_full.models.mod_forum_get_discussion_posts_response import ModForumGetDiscussionPostsResponse
    from poodle_async_full.models.mod_forum_get_forum_access_information_response import ModForumGetForumAccessInformationResponse
    from poodle_async_full.models.mod_forum_get_forum_discussions_response import ModForumGetForumDiscussionsResponse
    from poodle_async_full.models.mod_forum_get_forum_discussions_response_discussions_inner import ModForumGetForumDiscussionsResponseDiscussionsInner
    from poodle_async_full.models.mod_forum_get_forums_by_courses_response_inner import ModForumGetForumsByCoursesResponseInner
    from poodle_async_full.models.mod_forum_prepare_draft_area_for_post_parameters_filestokeep_inner import ModForumPrepareDraftAreaForPostParametersFilestokeepInner
    from poodle_async_full.models.mod_forum_prepare_draft_area_for_post_response import ModForumPrepareDraftAreaForPostResponse
    from poodle_async_full.models.mod_forum_set_lock_state_response import ModForumSetLockStateResponse
    from poodle_async_full.models.mod_forum_set_lock_state_response_times import ModForumSetLockStateResponseTimes
    from poodle_async_full.models.mod_forum_set_pin_state_response import ModForumSetPinStateResponse
    from poodle_async_full.models.mod_forum_set_pin_state_response_capabilities import ModForumSetPinStateResponseCapabilities
    from poodle_async_full.models.mod_forum_set_pin_state_response_group import ModForumSetPinStateResponseGroup
    from poodle_async_full.models.mod_forum_set_pin_state_response_group_urls import ModForumSetPinStateResponseGroupUrls
    from poodle_async_full.models.mod_forum_set_pin_state_response_timed import ModForumSetPinStateResponseTimed
    from poodle_async_full.models.mod_forum_set_pin_state_response_times import ModForumSetPinStateResponseTimes
    from poodle_async_full.models.mod_forum_set_pin_state_response_urls import ModForumSetPinStateResponseUrls
    from poodle_async_full.models.mod_forum_set_pin_state_response_userstate import ModForumSetPinStateResponseUserstate
    from poodle_async_full.models.mod_forum_set_subscription_state_response import ModForumSetSubscriptionStateResponse
    from poodle_async_full.models.mod_forum_toggle_favourite_state_response import ModForumToggleFavouriteStateResponse
    from poodle_async_full.models.mod_forum_update_discussion_post_parameters_options_inner import ModForumUpdateDiscussionPostParametersOptionsInner
    from poodle_async_full.models.mod_forum_update_discussion_post_response import ModForumUpdateDiscussionPostResponse
    from poodle_async_full.models.mod_forum_view_forum_discussion_response import ModForumViewForumDiscussionResponse
    from poodle_async_full.models.mod_forum_view_forum_response import ModForumViewForumResponse
    from poodle_async_full.models.mod_glossary_add_entry_parameters_options_inner import ModGlossaryAddEntryParametersOptionsInner
    from poodle_async_full.models.mod_glossary_add_entry_response import ModGlossaryAddEntryResponse
    from poodle_async_full.models.mod_glossary_delete_entry_response import ModGlossaryDeleteEntryResponse
    from poodle_async_full.models.mod_glossary_get_authors_parameters_options import ModGlossaryGetAuthorsParametersOptions
    from poodle_async_full.models.mod_glossary_get_authors_response import ModGlossaryGetAuthorsResponse
    from poodle_async_full.models.mod_glossary_get_authors_response_authors_inner import ModGlossaryGetAuthorsResponseAuthorsInner
    from poodle_async_full.models.mod_glossary_get_categories_response import ModGlossaryGetCategoriesResponse
    from poodle_async_full.models.mod_glossary_get_categories_response_categories_inner import ModGlossaryGetCategoriesResponseCategoriesInner
    from poodle_async_full.models.mod_glossary_get_entries_by_author_id_parameters_options import ModGlossaryGetEntriesByAuthorIdParametersOptions
    from poodle_async_full.models.mod_glossary_get_entries_by_author_id_response import ModGlossaryGetEntriesByAuthorIdResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_author_id_response_entries_inner import ModGlossaryGetEntriesByAuthorIdResponseEntriesInner
    from poodle_async_full.models.mod_glossary_get_entries_by_author_response import ModGlossaryGetEntriesByAuthorResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_category_response import ModGlossaryGetEntriesByCategoryResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_category_response_entries_inner import ModGlossaryGetEntriesByCategoryResponseEntriesInner
    from poodle_async_full.models.mod_glossary_get_entries_by_date_response import ModGlossaryGetEntriesByDateResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_letter_response import ModGlossaryGetEntriesByLetterResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_search_response import ModGlossaryGetEntriesBySearchResponse
    from poodle_async_full.models.mod_glossary_get_entries_by_term_response import ModGlossaryGetEntriesByTermResponse
    from poodle_async_full.models.mod_glossary_get_entries_to_approve_response import ModGlossaryGetEntriesToApproveResponse
    from poodle_async_full.models.mod_glossary_get_entry_by_id_response import ModGlossaryGetEntryByIdResponse
    from poodle_async_full.models.mod_glossary_get_entry_by_id_response_permissions import ModGlossaryGetEntryByIdResponsePermissions
    from poodle_async_full.models.mod_glossary_get_glossaries_by_courses_response import ModGlossaryGetGlossariesByCoursesResponse
    from poodle_async_full.models.mod_glossary_get_glossaries_by_courses_response_glossaries_inner import ModGlossaryGetGlossariesByCoursesResponseGlossariesInner
    from poodle_async_full.models.mod_glossary_prepare_entry_for_edition_response import ModGlossaryPrepareEntryForEditionResponse
    from poodle_async_full.models.mod_glossary_update_entry_response import ModGlossaryUpdateEntryResponse
    from poodle_async_full.models.mod_glossary_view_entry_response import ModGlossaryViewEntryResponse
    from poodle_async_full.models.mod_glossary_view_glossary_response import ModGlossaryViewGlossaryResponse
    from poodle_async_full.models.mod_h5pactivity_get_attempts_response import ModH5pactivityGetAttemptsResponse
    from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner import ModH5pactivityGetAttemptsResponseUsersattemptsInner
    from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner_attempts_inner import ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner
    from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner_scored import ModH5pactivityGetAttemptsResponseUsersattemptsInnerScored
    from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response import ModH5pactivityGetH5pactivitiesByCoursesResponse
    from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pactivities_inner import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner
    from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pactivities_inner_deployedfile import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile
    from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pglobalsettings import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pglobalsettings
    from poodle_async_full.models.mod_h5pactivity_get_h5pactivity_access_information_response import ModH5pactivityGetH5pactivityAccessInformationResponse
    from poodle_async_full.models.mod_h5pactivity_get_results_response import ModH5pactivityGetResultsResponse
    from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner import ModH5pactivityGetResultsResponseAttemptsInner
    from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner import ModH5pactivityGetResultsResponseAttemptsInnerResultsInner
    from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInner
    from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner_correctanswer import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerCorrectanswer
    from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner_useranswer import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer
    from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response import ModH5pactivityGetUserAttemptsResponse
    from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response_usersattempts_inner import ModH5pactivityGetUserAttemptsResponseUsersattemptsInner
    from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response_usersattempts_inner_scored import ModH5pactivityGetUserAttemptsResponseUsersattemptsInnerScored
    from poodle_async_full.models.mod_h5pactivity_log_report_viewed_response import ModH5pactivityLogReportViewedResponse
    from poodle_async_full.models.mod_h5pactivity_view_h5pactivity_response import ModH5pactivityViewH5pactivityResponse
    from poodle_async_full.models.mod_imscp_get_imscps_by_courses_response import ModImscpGetImscpsByCoursesResponse
    from poodle_async_full.models.mod_imscp_get_imscps_by_courses_response_imscps_inner import ModImscpGetImscpsByCoursesResponseImscpsInner
    from poodle_async_full.models.mod_imscp_view_imscp_response import ModImscpViewImscpResponse
    from poodle_async_full.models.mod_label_get_labels_by_courses_response import ModLabelGetLabelsByCoursesResponse
    from poodle_async_full.models.mod_label_get_labels_by_courses_response_labels_inner import ModLabelGetLabelsByCoursesResponseLabelsInner
    from poodle_async_full.models.mod_lesson_finish_attempt_response import ModLessonFinishAttemptResponse
    from poodle_async_full.models.mod_lesson_finish_attempt_response_data_inner import ModLessonFinishAttemptResponseDataInner
    from poodle_async_full.models.mod_lesson_finish_attempt_response_messages_inner import ModLessonFinishAttemptResponseMessagesInner
    from poodle_async_full.models.mod_lesson_get_attempts_overview_response import ModLessonGetAttemptsOverviewResponse
    from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data import ModLessonGetAttemptsOverviewResponseData
    from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data_students_inner import ModLessonGetAttemptsOverviewResponseDataStudentsInner
    from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data_students_inner_attempts_inner import ModLessonGetAttemptsOverviewResponseDataStudentsInnerAttemptsInner
    from poodle_async_full.models.mod_lesson_get_content_pages_viewed_response import ModLessonGetContentPagesViewedResponse
    from poodle_async_full.models.mod_lesson_get_content_pages_viewed_response_pages_inner import ModLessonGetContentPagesViewedResponsePagesInner
    from poodle_async_full.models.mod_lesson_get_lesson_access_information_response import ModLessonGetLessonAccessInformationResponse
    from poodle_async_full.models.mod_lesson_get_lesson_access_information_response_preventaccessreasons_inner import ModLessonGetLessonAccessInformationResponsePreventaccessreasonsInner
    from poodle_async_full.models.mod_lesson_get_lesson_response import ModLessonGetLessonResponse
    from poodle_async_full.models.mod_lesson_get_lesson_response_lesson import ModLessonGetLessonResponseLesson
    from poodle_async_full.models.mod_lesson_get_lessons_by_courses_response import ModLessonGetLessonsByCoursesResponse
    from poodle_async_full.models.mod_lesson_get_page_data_response import ModLessonGetPageDataResponse
    from poodle_async_full.models.mod_lesson_get_page_data_response_answers_inner import ModLessonGetPageDataResponseAnswersInner
    from poodle_async_full.models.mod_lesson_get_page_data_response_page import ModLessonGetPageDataResponsePage
    from poodle_async_full.models.mod_lesson_get_pages_possible_jumps_response import ModLessonGetPagesPossibleJumpsResponse
    from poodle_async_full.models.mod_lesson_get_pages_possible_jumps_response_jumps_inner import ModLessonGetPagesPossibleJumpsResponseJumpsInner
    from poodle_async_full.models.mod_lesson_get_pages_response import ModLessonGetPagesResponse
    from poodle_async_full.models.mod_lesson_get_pages_response_pages_inner import ModLessonGetPagesResponsePagesInner
    from poodle_async_full.models.mod_lesson_get_questions_attempts_response import ModLessonGetQuestionsAttemptsResponse
    from poodle_async_full.models.mod_lesson_get_questions_attempts_response_attempts_inner import ModLessonGetQuestionsAttemptsResponseAttemptsInner
    from poodle_async_full.models.mod_lesson_get_user_attempt_grade_response import ModLessonGetUserAttemptGradeResponse
    from poodle_async_full.models.mod_lesson_get_user_attempt_grade_response_grade import ModLessonGetUserAttemptGradeResponseGrade
    from poodle_async_full.models.mod_lesson_get_user_attempt_response import ModLessonGetUserAttemptResponse
    from poodle_async_full.models.mod_lesson_get_user_attempt_response_answerpages_inner import ModLessonGetUserAttemptResponseAnswerpagesInner
    from poodle_async_full.models.mod_lesson_get_user_attempt_response_answerpages_inner_answerdata import ModLessonGetUserAttemptResponseAnswerpagesInnerAnswerdata
    from poodle_async_full.models.mod_lesson_get_user_attempt_response_userstats import ModLessonGetUserAttemptResponseUserstats
    from poodle_async_full.models.mod_lesson_get_user_grade_response import ModLessonGetUserGradeResponse
    from poodle_async_full.models.mod_lesson_get_user_timers_response import ModLessonGetUserTimersResponse
    from poodle_async_full.models.mod_lesson_get_user_timers_response_timers_inner import ModLessonGetUserTimersResponseTimersInner
    from poodle_async_full.models.mod_lesson_launch_attempt_response import ModLessonLaunchAttemptResponse
    from poodle_async_full.models.mod_lesson_process_page_parameters_data_inner import ModLessonProcessPageParametersDataInner
    from poodle_async_full.models.mod_lesson_process_page_response import ModLessonProcessPageResponse
    from poodle_async_full.models.mod_lesson_view_lesson_response import ModLessonViewLessonResponse
    from poodle_async_full.models.mod_lti_create_tool_proxy_response import ModLtiCreateToolProxyResponse
    from poodle_async_full.models.mod_lti_create_tool_type_response import ModLtiCreateToolTypeResponse
    from poodle_async_full.models.mod_lti_create_tool_type_response_state import ModLtiCreateToolTypeResponseState
    from poodle_async_full.models.mod_lti_create_tool_type_response_urls import ModLtiCreateToolTypeResponseUrls
    from poodle_async_full.models.mod_lti_delete_tool_proxy_response import ModLtiDeleteToolProxyResponse
    from poodle_async_full.models.mod_lti_delete_tool_type_response import ModLtiDeleteToolTypeResponse
    from poodle_async_full.models.mod_lti_get_ltis_by_courses_response import ModLtiGetLtisByCoursesResponse
    from poodle_async_full.models.mod_lti_get_ltis_by_courses_response_ltis_inner import ModLtiGetLtisByCoursesResponseLtisInner
    from poodle_async_full.models.mod_lti_get_tool_launch_data_response import ModLtiGetToolLaunchDataResponse
    from poodle_async_full.models.mod_lti_get_tool_launch_data_response_parameters_inner import ModLtiGetToolLaunchDataResponseParametersInner
    from poodle_async_full.models.mod_lti_get_tool_proxies_response_inner import ModLtiGetToolProxiesResponseInner
    from poodle_async_full.models.mod_lti_get_tool_proxy_registration_request_response import ModLtiGetToolProxyRegistrationRequestResponse
    from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_count_response import ModLtiGetToolTypesAndProxiesCountResponse
    from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_response import ModLtiGetToolTypesAndProxiesResponse
    from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_response_types_inner import ModLtiGetToolTypesAndProxiesResponseTypesInner
    from poodle_async_full.models.mod_lti_is_cartridge_response import ModLtiIsCartridgeResponse
    from poodle_async_full.models.mod_lti_update_tool_type_response import ModLtiUpdateToolTypeResponse
    from poodle_async_full.models.mod_lti_view_lti_response import ModLtiViewLtiResponse
    from poodle_async_full.models.mod_page_get_pages_by_courses_response import ModPageGetPagesByCoursesResponse
    from poodle_async_full.models.mod_page_get_pages_by_courses_response_pages_inner import ModPageGetPagesByCoursesResponsePagesInner
    from poodle_async_full.models.mod_page_view_page_response import ModPageViewPageResponse
    from poodle_async_full.models.mod_quiz_add_random_questions_response import ModQuizAddRandomQuestionsResponse
    from poodle_async_full.models.mod_quiz_create_grade_items_parameters_quizgradeitems_inner import ModQuizCreateGradeItemsParametersQuizgradeitemsInner
    from poodle_async_full.models.mod_quiz_delete_grade_items_parameters_quizgradeitems_inner import ModQuizDeleteGradeItemsParametersQuizgradeitemsInner
    from poodle_async_full.models.mod_quiz_delete_overrides_parameters_data import ModQuizDeleteOverridesParametersData
    from poodle_async_full.models.mod_quiz_delete_overrides_response import ModQuizDeleteOverridesResponse
    from poodle_async_full.models.mod_quiz_get_attempt_access_information_response import ModQuizGetAttemptAccessInformationResponse
    from poodle_async_full.models.mod_quiz_get_attempt_data_response import ModQuizGetAttemptDataResponse
    from poodle_async_full.models.mod_quiz_get_attempt_data_response_attempt import ModQuizGetAttemptDataResponseAttempt
    from poodle_async_full.models.mod_quiz_get_attempt_data_response_attempt_gradeitemmarks_inner import ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner
    from poodle_async_full.models.mod_quiz_get_attempt_data_response_questions_inner import ModQuizGetAttemptDataResponseQuestionsInner
    from poodle_async_full.models.mod_quiz_get_attempt_data_response_questions_inner_responsefileareas_inner import ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner
    from poodle_async_full.models.mod_quiz_get_attempt_review_response import ModQuizGetAttemptReviewResponse
    from poodle_async_full.models.mod_quiz_get_attempt_review_response_additionaldata_inner import ModQuizGetAttemptReviewResponseAdditionaldataInner
    from poodle_async_full.models.mod_quiz_get_attempt_summary_response import ModQuizGetAttemptSummaryResponse
    from poodle_async_full.models.mod_quiz_get_combined_review_options_response import ModQuizGetCombinedReviewOptionsResponse
    from poodle_async_full.models.mod_quiz_get_combined_review_options_response_alloptions_inner import ModQuizGetCombinedReviewOptionsResponseAlloptionsInner
    from poodle_async_full.models.mod_quiz_get_overrides_response import ModQuizGetOverridesResponse
    from poodle_async_full.models.mod_quiz_get_overrides_response_overrides_inner import ModQuizGetOverridesResponseOverridesInner
    from poodle_async_full.models.mod_quiz_get_quiz_access_information_response import ModQuizGetQuizAccessInformationResponse
    from poodle_async_full.models.mod_quiz_get_quiz_feedback_for_grade_response import ModQuizGetQuizFeedbackForGradeResponse
    from poodle_async_full.models.mod_quiz_get_quiz_required_qtypes_response import ModQuizGetQuizRequiredQtypesResponse
    from poodle_async_full.models.mod_quiz_get_quizzes_by_courses_response import ModQuizGetQuizzesByCoursesResponse
    from poodle_async_full.models.mod_quiz_get_quizzes_by_courses_response_quizzes_inner import ModQuizGetQuizzesByCoursesResponseQuizzesInner
    from poodle_async_full.models.mod_quiz_get_user_attempts_response import ModQuizGetUserAttemptsResponse
    from poodle_async_full.models.mod_quiz_get_user_attempts_response_attempts_inner import ModQuizGetUserAttemptsResponseAttemptsInner
    from poodle_async_full.models.mod_quiz_get_user_best_grade_response import ModQuizGetUserBestGradeResponse
    from poodle_async_full.models.mod_quiz_get_user_quiz_attempts_response import ModQuizGetUserQuizAttemptsResponse
    from poodle_async_full.models.mod_quiz_process_attempt_response import ModQuizProcessAttemptResponse
    from poodle_async_full.models.mod_quiz_save_attempt_response import ModQuizSaveAttemptResponse
    from poodle_async_full.models.mod_quiz_save_overrides_parameters_data import ModQuizSaveOverridesParametersData
    from poodle_async_full.models.mod_quiz_save_overrides_parameters_data_overrides_inner import ModQuizSaveOverridesParametersDataOverridesInner
    from poodle_async_full.models.mod_quiz_save_overrides_response import ModQuizSaveOverridesResponse
    from poodle_async_full.models.mod_quiz_set_question_version_response import ModQuizSetQuestionVersionResponse
    from poodle_async_full.models.mod_quiz_start_attempt_response import ModQuizStartAttemptResponse
    from poodle_async_full.models.mod_quiz_update_filter_condition_response import ModQuizUpdateFilterConditionResponse
    from poodle_async_full.models.mod_quiz_update_grade_items_parameters_quizgradeitems_inner import ModQuizUpdateGradeItemsParametersQuizgradeitemsInner
    from poodle_async_full.models.mod_quiz_update_slots_parameters_slots_inner import ModQuizUpdateSlotsParametersSlotsInner
    from poodle_async_full.models.mod_quiz_view_attempt_response import ModQuizViewAttemptResponse
    from poodle_async_full.models.mod_quiz_view_attempt_review_response import ModQuizViewAttemptReviewResponse
    from poodle_async_full.models.mod_quiz_view_attempt_summary_response import ModQuizViewAttemptSummaryResponse
    from poodle_async_full.models.mod_quiz_view_quiz_response import ModQuizViewQuizResponse
    from poodle_async_full.models.mod_resource_get_resources_by_courses_response import ModResourceGetResourcesByCoursesResponse
    from poodle_async_full.models.mod_resource_get_resources_by_courses_response_resources_inner import ModResourceGetResourcesByCoursesResponseResourcesInner
    from poodle_async_full.models.mod_resource_view_resource_response import ModResourceViewResourceResponse
    from poodle_async_full.models.mod_scorm_get_scorm_access_information_response import ModScormGetScormAccessInformationResponse
    from poodle_async_full.models.mod_scorm_get_scorm_attempt_count_response import ModScormGetScormAttemptCountResponse
    from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response import ModScormGetScormScoTracksResponse
    from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response_data import ModScormGetScormScoTracksResponseData
    from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response_data_tracks_inner import ModScormGetScormScoTracksResponseDataTracksInner
    from poodle_async_full.models.mod_scorm_get_scorm_scoes_response import ModScormGetScormScoesResponse
    from poodle_async_full.models.mod_scorm_get_scorm_scoes_response_scoes_inner import ModScormGetScormScoesResponseScoesInner
    from poodle_async_full.models.mod_scorm_get_scorm_scoes_response_scoes_inner_extradata_inner import ModScormGetScormScoesResponseScoesInnerExtradataInner
    from poodle_async_full.models.mod_scorm_get_scorm_user_data_response import ModScormGetScormUserDataResponse
    from poodle_async_full.models.mod_scorm_get_scorm_user_data_response_data_inner import ModScormGetScormUserDataResponseDataInner
    from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response import ModScormGetScormsByCoursesResponse
    from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response_options_inner import ModScormGetScormsByCoursesResponseOptionsInner
    from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response_scorms_inner import ModScormGetScormsByCoursesResponseScormsInner
    from poodle_async_full.models.mod_scorm_insert_scorm_tracks_response import ModScormInsertScormTracksResponse
    from poodle_async_full.models.mod_scorm_launch_sco_response import ModScormLaunchScoResponse
    from poodle_async_full.models.mod_scorm_view_scorm_response import ModScormViewScormResponse
    from poodle_async_full.models.mod_url_get_urls_by_courses_response import ModUrlGetUrlsByCoursesResponse
    from poodle_async_full.models.mod_url_get_urls_by_courses_response_urls_inner import ModUrlGetUrlsByCoursesResponseUrlsInner
    from poodle_async_full.models.mod_url_view_url_response import ModUrlViewUrlResponse
    from poodle_async_full.models.mod_wiki_edit_page_response import ModWikiEditPageResponse
    from poodle_async_full.models.mod_wiki_get_page_contents_response import ModWikiGetPageContentsResponse
    from poodle_async_full.models.mod_wiki_get_page_contents_response_page import ModWikiGetPageContentsResponsePage
    from poodle_async_full.models.mod_wiki_get_page_for_editing_response import ModWikiGetPageForEditingResponse
    from poodle_async_full.models.mod_wiki_get_page_for_editing_response_pagesection import ModWikiGetPageForEditingResponsePagesection
    from poodle_async_full.models.mod_wiki_get_subwiki_files_response import ModWikiGetSubwikiFilesResponse
    from poodle_async_full.models.mod_wiki_get_subwiki_pages_parameters_options import ModWikiGetSubwikiPagesParametersOptions
    from poodle_async_full.models.mod_wiki_get_subwiki_pages_response import ModWikiGetSubwikiPagesResponse
    from poodle_async_full.models.mod_wiki_get_subwiki_pages_response_pages_inner import ModWikiGetSubwikiPagesResponsePagesInner
    from poodle_async_full.models.mod_wiki_get_subwikis_response import ModWikiGetSubwikisResponse
    from poodle_async_full.models.mod_wiki_get_subwikis_response_subwikis_inner import ModWikiGetSubwikisResponseSubwikisInner
    from poodle_async_full.models.mod_wiki_get_wikis_by_courses_response import ModWikiGetWikisByCoursesResponse
    from poodle_async_full.models.mod_wiki_get_wikis_by_courses_response_wikis_inner import ModWikiGetWikisByCoursesResponseWikisInner
    from poodle_async_full.models.mod_wiki_new_page_response import ModWikiNewPageResponse
    from poodle_async_full.models.mod_wiki_view_page_response import ModWikiViewPageResponse
    from poodle_async_full.models.mod_wiki_view_wiki_response import ModWikiViewWikiResponse
    from poodle_async_full.models.mod_workshop_add_submission_response import ModWorkshopAddSubmissionResponse
    from poodle_async_full.models.mod_workshop_delete_submission_response import ModWorkshopDeleteSubmissionResponse
    from poodle_async_full.models.mod_workshop_evaluate_assessment_response import ModWorkshopEvaluateAssessmentResponse
    from poodle_async_full.models.mod_workshop_evaluate_submission_response import ModWorkshopEvaluateSubmissionResponse
    from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response import ModWorkshopGetAssessmentFormDefinitionResponse
    from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_current_inner import ModWorkshopGetAssessmentFormDefinitionResponseCurrentInner
    from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_dimensionsinfo_inner import ModWorkshopGetAssessmentFormDefinitionResponseDimensionsinfoInner
    from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_fields_inner import ModWorkshopGetAssessmentFormDefinitionResponseFieldsInner
    from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_options_inner import ModWorkshopGetAssessmentFormDefinitionResponseOptionsInner
    from poodle_async_full.models.mod_workshop_get_assessment_response import ModWorkshopGetAssessmentResponse
    from poodle_async_full.models.mod_workshop_get_assessment_response_assessment import ModWorkshopGetAssessmentResponseAssessment
    from poodle_async_full.models.mod_workshop_get_grades_report_response import ModWorkshopGetGradesReportResponse
    from poodle_async_full.models.mod_workshop_get_grades_report_response_report import ModWorkshopGetGradesReportResponseReport
    from poodle_async_full.models.mod_workshop_get_grades_report_response_report_grades_inner import ModWorkshopGetGradesReportResponseReportGradesInner
    from poodle_async_full.models.mod_workshop_get_grades_report_response_report_grades_inner_reviewedby_inner import ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner
    from poodle_async_full.models.mod_workshop_get_grades_response import ModWorkshopGetGradesResponse
    from poodle_async_full.models.mod_workshop_get_reviewer_assessments_response import ModWorkshopGetReviewerAssessmentsResponse
    from poodle_async_full.models.mod_workshop_get_submission_assessments_response import ModWorkshopGetSubmissionAssessmentsResponse
    from poodle_async_full.models.mod_workshop_get_submission_response import ModWorkshopGetSubmissionResponse
    from poodle_async_full.models.mod_workshop_get_submission_response_submission import ModWorkshopGetSubmissionResponseSubmission
    from poodle_async_full.models.mod_workshop_get_submissions_response import ModWorkshopGetSubmissionsResponse
    from poodle_async_full.models.mod_workshop_get_user_plan_response import ModWorkshopGetUserPlanResponse
    from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan import ModWorkshopGetUserPlanResponseUserplan
    from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_examples_inner import ModWorkshopGetUserPlanResponseUserplanExamplesInner
    from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInner
    from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner_actions_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInnerActionsInner
    from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner_tasks_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInnerTasksInner
    from poodle_async_full.models.mod_workshop_get_workshop_access_information_response import ModWorkshopGetWorkshopAccessInformationResponse
    from poodle_async_full.models.mod_workshop_get_workshops_by_courses_response import ModWorkshopGetWorkshopsByCoursesResponse
    from poodle_async_full.models.mod_workshop_get_workshops_by_courses_response_workshops_inner import ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner
    from poodle_async_full.models.mod_workshop_update_assessment_parameters_data_inner import ModWorkshopUpdateAssessmentParametersDataInner
    from poodle_async_full.models.mod_workshop_update_assessment_response import ModWorkshopUpdateAssessmentResponse
    from poodle_async_full.models.mod_workshop_update_submission_response import ModWorkshopUpdateSubmissionResponse
    from poodle_async_full.models.mod_workshop_view_submission_response import ModWorkshopViewSubmissionResponse
    from poodle_async_full.models.mod_workshop_view_workshop_response import ModWorkshopViewWorkshopResponse
    from poodle_async_full.models.paygw_paypal_create_transaction_complete_parameters import PaygwPaypalCreateTransactionCompleteParameters
    from poodle_async_full.models.paygw_paypal_create_transaction_complete_response import PaygwPaypalCreateTransactionCompleteResponse
    from poodle_async_full.models.paygw_paypal_get_config_for_js_response import PaygwPaypalGetConfigForJsResponse
    from poodle_async_full.models.qbank_editquestion_set_status_response import QbankEditquestionSetStatusResponse
    from poodle_async_full.models.qbank_managecategories_move_category_response_inner import QbankManagecategoriesMoveCategoryResponseInner
    from poodle_async_full.models.qbank_managecategories_move_category_response_inner_fields import QbankManagecategoriesMoveCategoryResponseInnerFields
    from poodle_async_full.models.qbank_tagquestion_submit_tags_form_response import QbankTagquestionSubmitTagsFormResponse
    from poodle_async_full.models.quizaccess_seb_validate_quiz_keys_response import QuizaccessSebValidateQuizKeysResponse
    from poodle_async_full.models.report_competency_data_for_report_response import ReportCompetencyDataForReportResponse
    from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner import ReportCompetencyDataForReportResponseUsercompetenciesInner
    from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetency
    from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency_comppath import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppath
    from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency_comppath_ancestors_inner import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppathAncestorsInner
    from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_usercompetencycourse import ReportCompetencyDataForReportResponseUsercompetenciesInnerUsercompetencycourse
    from poodle_async_full.models.report_insights_action_executed_response import ReportInsightsActionExecutedResponse
    from poodle_async_full.models.tiny_autosave_reset_session_parameters import TinyAutosaveResetSessionParameters
    from poodle_async_full.models.tiny_autosave_resume_session_parameters import TinyAutosaveResumeSessionParameters
    from poodle_async_full.models.tiny_autosave_resume_session_response import TinyAutosaveResumeSessionResponse
    from poodle_async_full.models.tiny_autosave_update_session_parameters import TinyAutosaveUpdateSessionParameters
    from poodle_async_full.models.tiny_equation_filter_response import TinyEquationFilterResponse
    from poodle_async_full.models.tiny_media_preview_response import TinyMediaPreviewResponse
    from poodle_async_full.models.tiny_premium_get_api_key_response import TinyPremiumGetApiKeyResponse
    from poodle_async_full.models.tool_analytics_potential_contexts_response_inner import ToolAnalyticsPotentialContextsResponseInner
    from poodle_async_full.models.tool_behat_get_entity_generator_response import ToolBehatGetEntityGeneratorResponse
    from poodle_async_full.models.tool_dataprivacy_approve_data_request_response import ToolDataprivacyApproveDataRequestResponse
    from poodle_async_full.models.tool_dataprivacy_bulk_approve_data_requests_response import ToolDataprivacyBulkApproveDataRequestsResponse
    from poodle_async_full.models.tool_dataprivacy_bulk_deny_data_requests_response import ToolDataprivacyBulkDenyDataRequestsResponse
    from poodle_async_full.models.tool_dataprivacy_cancel_data_request_response import ToolDataprivacyCancelDataRequestResponse
    from poodle_async_full.models.tool_dataprivacy_confirm_contexts_for_deletion_response import ToolDataprivacyConfirmContextsForDeletionResponse
    from poodle_async_full.models.tool_dataprivacy_contact_dpo_response import ToolDataprivacyContactDpoResponse
    from poodle_async_full.models.tool_dataprivacy_create_category_form_response import ToolDataprivacyCreateCategoryFormResponse
    from poodle_async_full.models.tool_dataprivacy_create_category_form_response_category import ToolDataprivacyCreateCategoryFormResponseCategory
    from poodle_async_full.models.tool_dataprivacy_create_data_request_response import ToolDataprivacyCreateDataRequestResponse
    from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response import ToolDataprivacyCreatePurposeFormResponse
    from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response_purpose import ToolDataprivacyCreatePurposeFormResponsePurpose
    from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response_purpose_formattedlawfulbases_inner import ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner
    from poodle_async_full.models.tool_dataprivacy_delete_category_response import ToolDataprivacyDeleteCategoryResponse
    from poodle_async_full.models.tool_dataprivacy_delete_purpose_response import ToolDataprivacyDeletePurposeResponse
    from poodle_async_full.models.tool_dataprivacy_deny_data_request_response import ToolDataprivacyDenyDataRequestResponse
    from poodle_async_full.models.tool_dataprivacy_get_access_information_response import ToolDataprivacyGetAccessInformationResponse
    from poodle_async_full.models.tool_dataprivacy_get_activity_options_response import ToolDataprivacyGetActivityOptionsResponse
    from poodle_async_full.models.tool_dataprivacy_get_activity_options_response_options_inner import ToolDataprivacyGetActivityOptionsResponseOptionsInner
    from poodle_async_full.models.tool_dataprivacy_get_category_options_response import ToolDataprivacyGetCategoryOptionsResponse
    from poodle_async_full.models.tool_dataprivacy_get_category_options_response_options_inner import ToolDataprivacyGetCategoryOptionsResponseOptionsInner
    from poodle_async_full.models.tool_dataprivacy_get_data_request_response import ToolDataprivacyGetDataRequestResponse
    from poodle_async_full.models.tool_dataprivacy_get_data_request_response_result import ToolDataprivacyGetDataRequestResponseResult
    from poodle_async_full.models.tool_dataprivacy_get_data_requests_response import ToolDataprivacyGetDataRequestsResponse
    from poodle_async_full.models.tool_dataprivacy_get_purpose_options_response import ToolDataprivacyGetPurposeOptionsResponse
    from poodle_async_full.models.tool_dataprivacy_get_purpose_options_response_options_inner import ToolDataprivacyGetPurposeOptionsResponseOptionsInner
    from poodle_async_full.models.tool_dataprivacy_mark_complete_response import ToolDataprivacyMarkCompleteResponse
    from poodle_async_full.models.tool_dataprivacy_set_context_defaults_response import ToolDataprivacySetContextDefaultsResponse
    from poodle_async_full.models.tool_dataprivacy_set_context_form_response import ToolDataprivacySetContextFormResponse
    from poodle_async_full.models.tool_dataprivacy_set_contextlevel_form_response import ToolDataprivacySetContextlevelFormResponse
    from poodle_async_full.models.tool_dataprivacy_submit_selected_courses_form_response import ToolDataprivacySubmitSelectedCoursesFormResponse
    from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response import ToolDataprivacyTreeExtraBranchesResponse
    from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response_branches_inner import ToolDataprivacyTreeExtraBranchesResponseBranchesInner
    from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response_branches_inner_branches_inner import ToolDataprivacyTreeExtraBranchesResponseBranchesInnerBranchesInner
    from poodle_async_full.models.tool_lp_data_for_competencies_manage_page_response import ToolLpDataForCompetenciesManagePageResponse
    from poodle_async_full.models.tool_lp_data_for_competency_frameworks_manage_page_response import ToolLpDataForCompetencyFrameworksManagePageResponse
    from poodle_async_full.models.tool_lp_data_for_competency_summary_response import ToolLpDataForCompetencySummaryResponse
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response import ToolLpDataForCourseCompetenciesPageResponse
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInner
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner_coursemodules_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerCoursemodulesInner
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner_ruleoutcomeoptions_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerRuleoutcomeoptionsInner
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_settings import ToolLpDataForCourseCompetenciesPageResponseSettings
    from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_statistics import ToolLpDataForCourseCompetenciesPageResponseStatistics
    from poodle_async_full.models.tool_lp_data_for_plan_page_response import ToolLpDataForPlanPageResponse
    from poodle_async_full.models.tool_lp_data_for_plan_page_response_competencies_inner import ToolLpDataForPlanPageResponseCompetenciesInner
    from poodle_async_full.models.tool_lp_data_for_plans_page_response import ToolLpDataForPlansPageResponse
    from poodle_async_full.models.tool_lp_data_for_related_competencies_section_response import ToolLpDataForRelatedCompetenciesSectionResponse
    from poodle_async_full.models.tool_lp_data_for_template_competencies_page_response import ToolLpDataForTemplateCompetenciesPageResponse
    from poodle_async_full.models.tool_lp_data_for_template_competencies_page_response_statistics import ToolLpDataForTemplateCompetenciesPageResponseStatistics
    from poodle_async_full.models.tool_lp_data_for_templates_manage_page_response import ToolLpDataForTemplatesManagePageResponse
    from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response import ToolLpDataForUserCompetencySummaryInCourseResponse
    from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response_usercompetencysummary import ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummary
    from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response_usercompetencysummary_evidence_inner import ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner
    from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_plan_response import ToolLpDataForUserCompetencySummaryInPlanResponse
    from poodle_async_full.models.tool_lp_data_for_user_competency_summary_response import ToolLpDataForUserCompetencySummaryResponse
    from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response import ToolLpDataForUserEvidenceListPageResponse
    from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response_evidence_inner import ToolLpDataForUserEvidenceListPageResponseEvidenceInner
    from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response_evidence_inner_usercompetencies_inner import ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner
    from poodle_async_full.models.tool_lp_data_for_user_evidence_page_response import ToolLpDataForUserEvidencePageResponse
    from poodle_async_full.models.tool_lp_search_cohorts_response import ToolLpSearchCohortsResponse
    from poodle_async_full.models.tool_lp_search_users_response import ToolLpSearchUsersResponse
    from poodle_async_full.models.tool_mobile_call_external_functions_parameters_requests_inner import ToolMobileCallExternalFunctionsParametersRequestsInner
    from poodle_async_full.models.tool_mobile_call_external_functions_response import ToolMobileCallExternalFunctionsResponse
    from poodle_async_full.models.tool_mobile_call_external_functions_response_responses_inner import ToolMobileCallExternalFunctionsResponseResponsesInner
    from poodle_async_full.models.tool_mobile_get_autologin_key_response import ToolMobileGetAutologinKeyResponse
    from poodle_async_full.models.tool_mobile_get_config_response import ToolMobileGetConfigResponse
    from poodle_async_full.models.tool_mobile_get_config_response_settings_inner import ToolMobileGetConfigResponseSettingsInner
    from poodle_async_full.models.tool_mobile_get_content_parameters_args_inner import ToolMobileGetContentParametersArgsInner
    from poodle_async_full.models.tool_mobile_get_content_response import ToolMobileGetContentResponse
    from poodle_async_full.models.tool_mobile_get_content_response_otherdata_inner import ToolMobileGetContentResponseOtherdataInner
    from poodle_async_full.models.tool_mobile_get_content_response_restrict import ToolMobileGetContentResponseRestrict
    from poodle_async_full.models.tool_mobile_get_content_response_templates_inner import ToolMobileGetContentResponseTemplatesInner
    from poodle_async_full.models.tool_mobile_get_plugins_supporting_mobile_response import ToolMobileGetPluginsSupportingMobileResponse
    from poodle_async_full.models.tool_mobile_get_plugins_supporting_mobile_response_plugins_inner import ToolMobileGetPluginsSupportingMobileResponsePluginsInner
    from poodle_async_full.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse
    from poodle_async_full.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner
    from poodle_async_full.models.tool_mobile_get_tokens_for_qr_login_parameters import ToolMobileGetTokensForQrLoginParameters
    from poodle_async_full.models.tool_mobile_get_tokens_for_qr_login_response import ToolMobileGetTokensForQrLoginResponse
    from poodle_async_full.models.tool_mobile_validate_subscription_key_parameters import ToolMobileValidateSubscriptionKeyParameters
    from poodle_async_full.models.tool_mobile_validate_subscription_key_response import ToolMobileValidateSubscriptionKeyResponse
    from poodle_async_full.models.tool_moodlenet_search_courses_response import ToolMoodlenetSearchCoursesResponse
    from poodle_async_full.models.tool_moodlenet_search_courses_response_courses_inner import ToolMoodlenetSearchCoursesResponseCoursesInner
    from poodle_async_full.models.tool_moodlenet_verify_webfinger_response import ToolMoodlenetVerifyWebfingerResponse
    from poodle_async_full.models.tool_policy_get_policy_version_parameters import ToolPolicyGetPolicyVersionParameters
    from poodle_async_full.models.tool_policy_get_policy_version_response import ToolPolicyGetPolicyVersionResponse
    from poodle_async_full.models.tool_policy_get_policy_version_response_result import ToolPolicyGetPolicyVersionResponseResult
    from poodle_async_full.models.tool_policy_get_policy_version_response_result_policy import ToolPolicyGetPolicyVersionResponseResultPolicy
    from poodle_async_full.models.tool_policy_get_user_acceptances_response import ToolPolicyGetUserAcceptancesResponse
    from poodle_async_full.models.tool_policy_get_user_acceptances_response_policies_inner import ToolPolicyGetUserAcceptancesResponsePoliciesInner
    from poodle_async_full.models.tool_policy_get_user_acceptances_response_policies_inner_acceptance import ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance
    from poodle_async_full.models.tool_policy_set_acceptances_status_parameters_policies_inner import ToolPolicySetAcceptancesStatusParametersPoliciesInner
    from poodle_async_full.models.tool_policy_set_acceptances_status_response import ToolPolicySetAcceptancesStatusResponse
    from poodle_async_full.models.tool_templatelibrary_list_templates_parameters import ToolTemplatelibraryListTemplatesParameters
    from poodle_async_full.models.tool_templatelibrary_load_canonical_template_parameters import ToolTemplatelibraryLoadCanonicalTemplateParameters
    from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response import ToolUsertoursFetchAndStartTourResponse
    from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response_tourconfig import ToolUsertoursFetchAndStartTourResponseTourconfig
    from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response_tourconfig_steps_inner import ToolUsertoursFetchAndStartTourResponseTourconfigStepsInner
    from poodle_async_full.models.tool_usertours_reset_tour_response import ToolUsertoursResetTourResponse
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import models into model package
from poodle_async_full.models.aiplacement_courseassist_explain_text_response import AiplacementCourseassistExplainTextResponse
from poodle_async_full.models.aiplacement_courseassist_summarise_text_response import AiplacementCourseassistSummariseTextResponse
from poodle_async_full.models.aiplacement_editor_generate_image_response import AiplacementEditorGenerateImageResponse
from poodle_async_full.models.aiplacement_editor_generate_text_response import AiplacementEditorGenerateTextResponse
from poodle_async_full.models.auth_email_get_signup_settings_response import AuthEmailGetSignupSettingsResponse
from poodle_async_full.models.auth_email_get_signup_settings_response_profilefields_inner import AuthEmailGetSignupSettingsResponseProfilefieldsInner
from poodle_async_full.models.auth_email_get_signup_settings_response_warnings_inner import AuthEmailGetSignupSettingsResponseWarningsInner
from poodle_async_full.models.auth_email_signup_user_parameters import AuthEmailSignupUserParameters
from poodle_async_full.models.auth_email_signup_user_parameters_customprofilefields_inner import AuthEmailSignupUserParametersCustomprofilefieldsInner
from poodle_async_full.models.auth_email_signup_user_response import AuthEmailSignupUserResponse
from poodle_async_full.models.block_accessreview_get_module_data_response_inner import BlockAccessreviewGetModuleDataResponseInner
from poodle_async_full.models.block_accessreview_get_section_data_response_inner import BlockAccessreviewGetSectionDataResponseInner
from poodle_async_full.models.block_recentlyaccesseditems_get_recent_items_response_inner import BlockRecentlyaccesseditemsGetRecentItemsResponseInner
from poodle_async_full.models.block_starredcourses_get_starred_courses_response_inner import BlockStarredcoursesGetStarredCoursesResponseInner
from poodle_async_full.models.core_ai_delete_provider_instance_response import CoreAiDeleteProviderInstanceResponse
from poodle_async_full.models.core_ai_get_policy_status_response import CoreAiGetPolicyStatusResponse
from poodle_async_full.models.core_ai_set_policy_status_response import CoreAiSetPolicyStatusResponse
from poodle_async_full.models.core_ai_set_provider_status_response import CoreAiSetProviderStatusResponse
from poodle_async_full.models.core_auth_confirm_user_parameters import CoreAuthConfirmUserParameters
from poodle_async_full.models.core_auth_confirm_user_response import CoreAuthConfirmUserResponse
from poodle_async_full.models.core_auth_is_age_digital_consent_verification_enabled_response import CoreAuthIsAgeDigitalConsentVerificationEnabledResponse
from poodle_async_full.models.core_auth_is_minor_parameters import CoreAuthIsMinorParameters
from poodle_async_full.models.core_auth_is_minor_response import CoreAuthIsMinorResponse
from poodle_async_full.models.core_auth_request_password_reset_parameters import CoreAuthRequestPasswordResetParameters
from poodle_async_full.models.core_auth_request_password_reset_response import CoreAuthRequestPasswordResetResponse
from poodle_async_full.models.core_auth_resend_confirmation_email_parameters import CoreAuthResendConfirmationEmailParameters
from poodle_async_full.models.core_auth_resend_confirmation_email_response import CoreAuthResendConfirmationEmailResponse
from poodle_async_full.models.core_backup_get_async_backup_links_backup_response import CoreBackupGetAsyncBackupLinksBackupResponse
from poodle_async_full.models.core_backup_get_async_backup_links_restore_response import CoreBackupGetAsyncBackupLinksRestoreResponse
from poodle_async_full.models.core_backup_get_async_backup_progress_response_inner import CoreBackupGetAsyncBackupProgressResponseInner
from poodle_async_full.models.core_backup_get_copy_progress_parameters_copies_inner import CoreBackupGetCopyProgressParametersCopiesInner
from poodle_async_full.models.core_backup_get_copy_progress_response_inner import CoreBackupGetCopyProgressResponseInner
from poodle_async_full.models.core_badges_disable_badges_response import CoreBadgesDisableBadgesResponse
from poodle_async_full.models.core_badges_enable_badges_response import CoreBadgesEnableBadgesResponse
from poodle_async_full.models.core_badges_enable_badges_response_result_inner import CoreBadgesEnableBadgesResponseResultInner
from poodle_async_full.models.core_badges_get_badge_response import CoreBadgesGetBadgeResponse
from poodle_async_full.models.core_badges_get_badge_response_badge import CoreBadgesGetBadgeResponseBadge
from poodle_async_full.models.core_badges_get_badge_response_badge_alignment_inner import CoreBadgesGetBadgeResponseBadgeAlignmentInner
from poodle_async_full.models.core_badges_get_user_badge_by_hash_response import CoreBadgesGetUserBadgeByHashResponse
from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner import CoreBadgesGetUserBadgeByHashResponseBadgeInner
from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner_endorsement import CoreBadgesGetUserBadgeByHashResponseBadgeInnerEndorsement
from poodle_async_full.models.core_badges_get_user_badge_by_hash_response_badge_inner_relatedbadges_inner import CoreBadgesGetUserBadgeByHashResponseBadgeInnerRelatedbadgesInner
from poodle_async_full.models.core_badges_get_user_badges_response import CoreBadgesGetUserBadgesResponse
from poodle_async_full.models.core_block_fetch_addable_blocks_response_inner import CoreBlockFetchAddableBlocksResponseInner
from poodle_async_full.models.core_block_get_course_blocks_response import CoreBlockGetCourseBlocksResponse
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner import CoreBlockGetCourseBlocksResponseBlocksInner
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_configs_inner import CoreBlockGetCourseBlocksResponseBlocksInnerConfigsInner
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents import CoreBlockGetCourseBlocksResponseBlocksInnerContents
from poodle_async_full.models.core_block_get_course_blocks_response_blocks_inner_contents_files_inner import CoreBlockGetCourseBlocksResponseBlocksInnerContentsFilesInner
from poodle_async_full.models.core_block_get_dashboard_blocks_response import CoreBlockGetDashboardBlocksResponse
from poodle_async_full.models.core_blog_add_entry_parameters_options_inner import CoreBlogAddEntryParametersOptionsInner
from poodle_async_full.models.core_blog_add_entry_response import CoreBlogAddEntryResponse
from poodle_async_full.models.core_blog_delete_entry_response import CoreBlogDeleteEntryResponse
from poodle_async_full.models.core_blog_get_access_information_response import CoreBlogGetAccessInformationResponse
from poodle_async_full.models.core_blog_get_entries_parameters import CoreBlogGetEntriesParameters
from poodle_async_full.models.core_blog_get_entries_parameters_filters_inner import CoreBlogGetEntriesParametersFiltersInner
from poodle_async_full.models.core_blog_get_entries_response import CoreBlogGetEntriesResponse
from poodle_async_full.models.core_blog_get_entries_response_entries_inner import CoreBlogGetEntriesResponseEntriesInner
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_attachmentfiles_inner import CoreBlogGetEntriesResponseEntriesInnerAttachmentfilesInner
from poodle_async_full.models.core_blog_get_entries_response_entries_inner_tags_inner import CoreBlogGetEntriesResponseEntriesInnerTagsInner
from poodle_async_full.models.core_blog_prepare_entry_for_edition_response import CoreBlogPrepareEntryForEditionResponse
from poodle_async_full.models.core_blog_prepare_entry_for_edition_response_areas_inner import CoreBlogPrepareEntryForEditionResponseAreasInner
from poodle_async_full.models.core_blog_prepare_entry_for_edition_response_areas_inner_options_inner import CoreBlogPrepareEntryForEditionResponseAreasInnerOptionsInner
from poodle_async_full.models.core_blog_update_entry_response import CoreBlogUpdateEntryResponse
from poodle_async_full.models.core_blog_view_entries_parameters import CoreBlogViewEntriesParameters
from poodle_async_full.models.core_blog_view_entries_parameters_filters_inner import CoreBlogViewEntriesParametersFiltersInner
from poodle_async_full.models.core_blog_view_entries_response import CoreBlogViewEntriesResponse
from poodle_async_full.models.core_calendar_create_calendar_events_parameters_events_inner import CoreCalendarCreateCalendarEventsParametersEventsInner
from poodle_async_full.models.core_calendar_create_calendar_events_response import CoreCalendarCreateCalendarEventsResponse
from poodle_async_full.models.core_calendar_create_calendar_events_response_events_inner import CoreCalendarCreateCalendarEventsResponseEventsInner
from poodle_async_full.models.core_calendar_delete_calendar_events_parameters_events_inner import CoreCalendarDeleteCalendarEventsParametersEventsInner
from poodle_async_full.models.core_calendar_delete_subscription_response import CoreCalendarDeleteSubscriptionResponse
from poodle_async_full.models.core_calendar_get_action_events_by_course_response import CoreCalendarGetActionEventsByCourseResponse
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner import CoreCalendarGetActionEventsByCourseResponseEventsInner
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_action import CoreCalendarGetActionEventsByCourseResponseEventsInnerAction
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_category import CoreCalendarGetActionEventsByCourseResponseEventsInnerCategory
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_icon import CoreCalendarGetActionEventsByCourseResponseEventsInnerIcon
from poodle_async_full.models.core_calendar_get_action_events_by_course_response_events_inner_subscription import CoreCalendarGetActionEventsByCourseResponseEventsInnerSubscription
from poodle_async_full.models.core_calendar_get_action_events_by_courses_response import CoreCalendarGetActionEventsByCoursesResponse
from poodle_async_full.models.core_calendar_get_action_events_by_courses_response_groupedbycourse_inner import CoreCalendarGetActionEventsByCoursesResponseGroupedbycourseInner
from poodle_async_full.models.core_calendar_get_action_events_by_timesort_response import CoreCalendarGetActionEventsByTimesortResponse
from poodle_async_full.models.core_calendar_get_allowed_event_types_response import CoreCalendarGetAllowedEventTypesResponse
from poodle_async_full.models.core_calendar_get_calendar_access_information_response import CoreCalendarGetCalendarAccessInformationResponse
from poodle_async_full.models.core_calendar_get_calendar_day_view_response import CoreCalendarGetCalendarDayViewResponse
from poodle_async_full.models.core_calendar_get_calendar_day_view_response_date import CoreCalendarGetCalendarDayViewResponseDate
from poodle_async_full.models.core_calendar_get_calendar_day_view_response_events_inner import CoreCalendarGetCalendarDayViewResponseEventsInner
from poodle_async_full.models.core_calendar_get_calendar_event_by_id_response import CoreCalendarGetCalendarEventByIdResponse
from poodle_async_full.models.core_calendar_get_calendar_events_parameters_events import CoreCalendarGetCalendarEventsParametersEvents
from poodle_async_full.models.core_calendar_get_calendar_events_parameters_options import CoreCalendarGetCalendarEventsParametersOptions
from poodle_async_full.models.core_calendar_get_calendar_events_response import CoreCalendarGetCalendarEventsResponse
from poodle_async_full.models.core_calendar_get_calendar_events_response_events_inner import CoreCalendarGetCalendarEventsResponseEventsInner
from poodle_async_full.models.core_calendar_get_calendar_export_token_response import CoreCalendarGetCalendarExportTokenResponse
from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response import CoreCalendarGetCalendarMonthlyViewResponse
from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_daynames_inner import CoreCalendarGetCalendarMonthlyViewResponseDaynamesInner
from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_weeks_inner import CoreCalendarGetCalendarMonthlyViewResponseWeeksInner
from poodle_async_full.models.core_calendar_get_calendar_monthly_view_response_weeks_inner_days_inner import CoreCalendarGetCalendarMonthlyViewResponseWeeksInnerDaysInner
from poodle_async_full.models.core_calendar_get_calendar_upcoming_view_response import CoreCalendarGetCalendarUpcomingViewResponse
from poodle_async_full.models.core_calendar_get_timestamps_parameters_data_inner import CoreCalendarGetTimestampsParametersDataInner
from poodle_async_full.models.core_calendar_get_timestamps_response import CoreCalendarGetTimestampsResponse
from poodle_async_full.models.core_calendar_get_timestamps_response_timestamps_inner import CoreCalendarGetTimestampsResponseTimestampsInner
from poodle_async_full.models.core_calendar_submit_create_update_form_response import CoreCalendarSubmitCreateUpdateFormResponse
from poodle_async_full.models.core_calendar_update_event_start_day_response import CoreCalendarUpdateEventStartDayResponse
from poodle_async_full.models.core_change_editmode_response import CoreChangeEditmodeResponse
from poodle_async_full.models.core_check_get_result_admintree_response import CoreCheckGetResultAdmintreeResponse
from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner import CoreCohortAddCohortMembersParametersMembersInner
from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner_cohorttype import CoreCohortAddCohortMembersParametersMembersInnerCohorttype
from poodle_async_full.models.core_cohort_add_cohort_members_parameters_members_inner_usertype import CoreCohortAddCohortMembersParametersMembersInnerUsertype
from poodle_async_full.models.core_cohort_add_cohort_members_response import CoreCohortAddCohortMembersResponse
from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner import CoreCohortCreateCohortsParametersCohortsInner
from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner_categorytype import CoreCohortCreateCohortsParametersCohortsInnerCategorytype
from poodle_async_full.models.core_cohort_create_cohorts_parameters_cohorts_inner_customfields_inner import CoreCohortCreateCohortsParametersCohortsInnerCustomfieldsInner
from poodle_async_full.models.core_cohort_create_cohorts_response_inner import CoreCohortCreateCohortsResponseInner
from poodle_async_full.models.core_cohort_delete_cohort_members_parameters_members_inner import CoreCohortDeleteCohortMembersParametersMembersInner
from poodle_async_full.models.core_cohort_get_cohort_members_response_inner import CoreCohortGetCohortMembersResponseInner
from poodle_async_full.models.core_cohort_get_cohorts_response_inner import CoreCohortGetCohortsResponseInner
from poodle_async_full.models.core_cohort_get_cohorts_response_inner_customfields_inner import CoreCohortGetCohortsResponseInnerCustomfieldsInner
from poodle_async_full.models.core_cohort_search_cohorts_parameters_context import CoreCohortSearchCohortsParametersContext
from poodle_async_full.models.core_cohort_search_cohorts_response import CoreCohortSearchCohortsResponse
from poodle_async_full.models.core_cohort_update_cohorts_parameters_cohorts_inner import CoreCohortUpdateCohortsParametersCohortsInner
from poodle_async_full.models.core_comment_add_comments_parameters_comments_inner import CoreCommentAddCommentsParametersCommentsInner
from poodle_async_full.models.core_comment_add_comments_response_inner import CoreCommentAddCommentsResponseInner
from poodle_async_full.models.core_comment_get_comments_response import CoreCommentGetCommentsResponse
from poodle_async_full.models.core_competency_count_competencies_parameters_filters_inner import CoreCompetencyCountCompetenciesParametersFiltersInner
from poodle_async_full.models.core_competency_create_competency_framework_parameters_competencyframework import CoreCompetencyCreateCompetencyFrameworkParametersCompetencyframework
from poodle_async_full.models.core_competency_create_competency_framework_response import CoreCompetencyCreateCompetencyFrameworkResponse
from poodle_async_full.models.core_competency_create_competency_parameters_competency import CoreCompetencyCreateCompetencyParametersCompetency
from poodle_async_full.models.core_competency_create_competency_response import CoreCompetencyCreateCompetencyResponse
from poodle_async_full.models.core_competency_create_plan_parameters_plan import CoreCompetencyCreatePlanParametersPlan
from poodle_async_full.models.core_competency_create_plan_response import CoreCompetencyCreatePlanResponse
from poodle_async_full.models.core_competency_create_plan_response_commentarea import CoreCompetencyCreatePlanResponseCommentarea
from poodle_async_full.models.core_competency_create_plan_response_reviewer import CoreCompetencyCreatePlanResponseReviewer
from poodle_async_full.models.core_competency_create_plan_response_template import CoreCompetencyCreatePlanResponseTemplate
from poodle_async_full.models.core_competency_create_template_parameters_template import CoreCompetencyCreateTemplateParametersTemplate
from poodle_async_full.models.core_competency_create_template_response import CoreCompetencyCreateTemplateResponse
from poodle_async_full.models.core_competency_create_user_evidence_competency_response import CoreCompetencyCreateUserEvidenceCompetencyResponse
from poodle_async_full.models.core_competency_duplicate_competency_framework_response import CoreCompetencyDuplicateCompetencyFrameworkResponse
from poodle_async_full.models.core_competency_duplicate_template_response import CoreCompetencyDuplicateTemplateResponse
from poodle_async_full.models.core_competency_get_scale_values_response_inner import CoreCompetencyGetScaleValuesResponseInner
from poodle_async_full.models.core_competency_grade_competency_in_course_response import CoreCompetencyGradeCompetencyInCourseResponse
from poodle_async_full.models.core_competency_grade_competency_in_plan_response import CoreCompetencyGradeCompetencyInPlanResponse
from poodle_async_full.models.core_competency_grade_competency_response import CoreCompetencyGradeCompetencyResponse
from poodle_async_full.models.core_competency_list_competencies_in_template_response_inner import CoreCompetencyListCompetenciesInTemplateResponseInner
from poodle_async_full.models.core_competency_list_competency_frameworks_response_inner import CoreCompetencyListCompetencyFrameworksResponseInner
from poodle_async_full.models.core_competency_list_course_competencies_response_inner import CoreCompetencyListCourseCompetenciesResponseInner
from poodle_async_full.models.core_competency_list_course_competencies_response_inner_coursecompetency import CoreCompetencyListCourseCompetenciesResponseInnerCoursecompetency
from poodle_async_full.models.core_competency_list_course_module_competencies_response_inner import CoreCompetencyListCourseModuleCompetenciesResponseInner
from poodle_async_full.models.core_competency_list_course_module_competencies_response_inner_coursemodulecompetency import CoreCompetencyListCourseModuleCompetenciesResponseInnerCoursemodulecompetency
from poodle_async_full.models.core_competency_list_plan_competencies_response_inner import CoreCompetencyListPlanCompetenciesResponseInner
from poodle_async_full.models.core_competency_list_plan_competencies_response_inner_usercompetency import CoreCompetencyListPlanCompetenciesResponseInnerUsercompetency
from poodle_async_full.models.core_competency_list_plan_competencies_response_inner_usercompetencyplan import CoreCompetencyListPlanCompetenciesResponseInnerUsercompetencyplan
from poodle_async_full.models.core_competency_list_user_plans_response_inner import CoreCompetencyListUserPlansResponseInner
from poodle_async_full.models.core_competency_read_competency_framework_response import CoreCompetencyReadCompetencyFrameworkResponse
from poodle_async_full.models.core_competency_read_competency_response import CoreCompetencyReadCompetencyResponse
from poodle_async_full.models.core_competency_read_plan_response import CoreCompetencyReadPlanResponse
from poodle_async_full.models.core_competency_read_template_response import CoreCompetencyReadTemplateResponse
from poodle_async_full.models.core_competency_read_user_evidence_response import CoreCompetencyReadUserEvidenceResponse
from poodle_async_full.models.core_competency_read_user_evidence_response_files_inner import CoreCompetencyReadUserEvidenceResponseFilesInner
from poodle_async_full.models.core_competency_update_competency_framework_parameters_competencyframework import CoreCompetencyUpdateCompetencyFrameworkParametersCompetencyframework
from poodle_async_full.models.core_competency_update_competency_parameters_competency import CoreCompetencyUpdateCompetencyParametersCompetency
from poodle_async_full.models.core_competency_update_course_competency_settings_parameters_settings import CoreCompetencyUpdateCourseCompetencySettingsParametersSettings
from poodle_async_full.models.core_competency_update_plan_parameters_plan import CoreCompetencyUpdatePlanParametersPlan
from poodle_async_full.models.core_competency_update_plan_response import CoreCompetencyUpdatePlanResponse
from poodle_async_full.models.core_competency_update_template_parameters_template import CoreCompetencyUpdateTemplateParametersTemplate
from poodle_async_full.models.core_completion_get_activities_completion_status_response import CoreCompletionGetActivitiesCompletionStatusResponse
from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInner
from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner_details_inner import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInner
from poodle_async_full.models.core_completion_get_activities_completion_status_response_statuses_inner_details_inner_rulevalue import CoreCompletionGetActivitiesCompletionStatusResponseStatusesInnerDetailsInnerRulevalue
from poodle_async_full.models.core_completion_get_course_completion_status_response import CoreCompletionGetCourseCompletionStatusResponse
from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus import CoreCompletionGetCourseCompletionStatusResponseCompletionstatus
from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus_completions_inner import CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInner
from poodle_async_full.models.core_completion_get_course_completion_status_response_completionstatus_completions_inner_details import CoreCompletionGetCourseCompletionStatusResponseCompletionstatusCompletionsInnerDetails
from poodle_async_full.models.core_completion_mark_course_self_completed_response import CoreCompletionMarkCourseSelfCompletedResponse
from poodle_async_full.models.core_completion_override_activity_completion_status_response import CoreCompletionOverrideActivityCompletionStatusResponse
from poodle_async_full.models.core_completion_update_activity_completion_status_manually_response import CoreCompletionUpdateActivityCompletionStatusManuallyResponse
from poodle_async_full.models.core_contentbank_copy_content_response import CoreContentbankCopyContentResponse
from poodle_async_full.models.core_contentbank_delete_content_response import CoreContentbankDeleteContentResponse
from poodle_async_full.models.core_contentbank_rename_content_response import CoreContentbankRenameContentResponse
from poodle_async_full.models.core_contentbank_set_content_visibility_response import CoreContentbankSetContentVisibilityResponse
from poodle_async_full.models.core_course_add_content_item_to_user_favourites_response import CoreCourseAddContentItemToUserFavouritesResponse
from poodle_async_full.models.core_course_check_updates_parameters_tocheck_inner import CoreCourseCheckUpdatesParametersTocheckInner
from poodle_async_full.models.core_course_check_updates_response import CoreCourseCheckUpdatesResponse
from poodle_async_full.models.core_course_check_updates_response_instances_inner import CoreCourseCheckUpdatesResponseInstancesInner
from poodle_async_full.models.core_course_check_updates_response_instances_inner_updates_inner import CoreCourseCheckUpdatesResponseInstancesInnerUpdatesInner
from poodle_async_full.models.core_course_create_categories_parameters_categories_inner import CoreCourseCreateCategoriesParametersCategoriesInner
from poodle_async_full.models.core_course_create_categories_response_inner import CoreCourseCreateCategoriesResponseInner
from poodle_async_full.models.core_course_create_courses_parameters_courses_inner import CoreCourseCreateCoursesParametersCoursesInner
from poodle_async_full.models.core_course_create_courses_parameters_courses_inner_courseformatoptions_inner import CoreCourseCreateCoursesParametersCoursesInnerCourseformatoptionsInner
from poodle_async_full.models.core_course_create_courses_response_inner import CoreCourseCreateCoursesResponseInner
from poodle_async_full.models.core_course_delete_categories_parameters_categories_inner import CoreCourseDeleteCategoriesParametersCategoriesInner
from poodle_async_full.models.core_course_delete_courses_response import CoreCourseDeleteCoursesResponse
from poodle_async_full.models.core_course_duplicate_course_parameters_options_inner import CoreCourseDuplicateCourseParametersOptionsInner
from poodle_async_full.models.core_course_duplicate_course_response import CoreCourseDuplicateCourseResponse
from poodle_async_full.models.core_course_get_activity_chooser_footer_response import CoreCourseGetActivityChooserFooterResponse
from poodle_async_full.models.core_course_get_categories_parameters_criteria_inner import CoreCourseGetCategoriesParametersCriteriaInner
from poodle_async_full.models.core_course_get_categories_response_inner import CoreCourseGetCategoriesResponseInner
from poodle_async_full.models.core_course_get_contents_parameters_options_inner import CoreCourseGetContentsParametersOptionsInner
from poodle_async_full.models.core_course_get_contents_response_inner import CoreCourseGetContentsResponseInner
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner import CoreCourseGetContentsResponseInnerModulesInner
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge import CoreCourseGetContentsResponseInnerModulesInnerActivitybadge
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOf
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_activitybadge_one_of_badgeextraattributes_inner import CoreCourseGetContentsResponseInnerModulesInnerActivitybadgeOneOfBadgeextraattributesInner
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata import CoreCourseGetContentsResponseInnerModulesInnerCompletiondata
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInner
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_completiondata_details_inner_rulevalue import CoreCourseGetContentsResponseInnerModulesInnerCompletiondataDetailsInnerRulevalue
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_contents_inner import CoreCourseGetContentsResponseInnerModulesInnerContentsInner
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_contentsinfo import CoreCourseGetContentsResponseInnerModulesInnerContentsinfo
from poodle_async_full.models.core_course_get_contents_response_inner_modules_inner_dates_inner import CoreCourseGetContentsResponseInnerModulesInnerDatesInner
from poodle_async_full.models.core_course_get_course_content_items_response import CoreCourseGetCourseContentItemsResponse
from poodle_async_full.models.core_course_get_course_content_items_response_content_items_inner import CoreCourseGetCourseContentItemsResponseContentItemsInner
from poodle_async_full.models.core_course_get_course_module_by_instance_response import CoreCourseGetCourseModuleByInstanceResponse
from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm import CoreCourseGetCourseModuleByInstanceResponseCm
from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm_advancedgrading_inner import CoreCourseGetCourseModuleByInstanceResponseCmAdvancedgradingInner
from poodle_async_full.models.core_course_get_course_module_by_instance_response_cm_outcomes_inner import CoreCourseGetCourseModuleByInstanceResponseCmOutcomesInner
from poodle_async_full.models.core_course_get_course_module_response import CoreCourseGetCourseModuleResponse
from poodle_async_full.models.core_course_get_courses_by_field_response import CoreCourseGetCoursesByFieldResponse
from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner import CoreCourseGetCoursesByFieldResponseCoursesInner
from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_contacts_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerContactsInner
from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_courseformatoptions_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerCourseformatoptionsInner
from poodle_async_full.models.core_course_get_courses_by_field_response_courses_inner_filters_inner import CoreCourseGetCoursesByFieldResponseCoursesInnerFiltersInner
from poodle_async_full.models.core_course_get_courses_parameters_options import CoreCourseGetCoursesParametersOptions
from poodle_async_full.models.core_course_get_courses_response_inner import CoreCourseGetCoursesResponseInner
from poodle_async_full.models.core_course_get_courses_response_inner_customfields_inner import CoreCourseGetCoursesResponseInnerCustomfieldsInner
from poodle_async_full.models.core_course_get_enrolled_courses_by_timeline_classification_response import CoreCourseGetEnrolledCoursesByTimelineClassificationResponse
from poodle_async_full.models.core_course_get_enrolled_courses_with_action_events_by_timeline_classification_response import CoreCourseGetEnrolledCoursesWithActionEventsByTimelineClassificationResponse
from poodle_async_full.models.core_course_get_enrolled_users_by_cmid_response import CoreCourseGetEnrolledUsersByCmidResponse
from poodle_async_full.models.core_course_get_enrolled_users_by_cmid_response_users_inner import CoreCourseGetEnrolledUsersByCmidResponseUsersInner
from poodle_async_full.models.core_course_get_updates_since_response import CoreCourseGetUpdatesSinceResponse
from poodle_async_full.models.core_course_get_user_administration_options_response import CoreCourseGetUserAdministrationOptionsResponse
from poodle_async_full.models.core_course_get_user_administration_options_response_courses_inner import CoreCourseGetUserAdministrationOptionsResponseCoursesInner
from poodle_async_full.models.core_course_get_user_administration_options_response_courses_inner_options_inner import CoreCourseGetUserAdministrationOptionsResponseCoursesInnerOptionsInner
from poodle_async_full.models.core_course_get_user_navigation_options_response import CoreCourseGetUserNavigationOptionsResponse
from poodle_async_full.models.core_course_import_course_parameters_options_inner import CoreCourseImportCourseParametersOptionsInner
from poodle_async_full.models.core_course_remove_content_item_from_user_favourites_response import CoreCourseRemoveContentItemFromUserFavouritesResponse
from poodle_async_full.models.core_course_search_courses_response import CoreCourseSearchCoursesResponse
from poodle_async_full.models.core_course_search_courses_response_courses_inner import CoreCourseSearchCoursesResponseCoursesInner
from poodle_async_full.models.core_course_set_favourite_courses_parameters_courses_inner import CoreCourseSetFavouriteCoursesParametersCoursesInner
from poodle_async_full.models.core_course_set_favourite_courses_response import CoreCourseSetFavouriteCoursesResponse
from poodle_async_full.models.core_course_toggle_activity_recommendation_response import CoreCourseToggleActivityRecommendationResponse
from poodle_async_full.models.core_course_update_categories_parameters_categories_inner import CoreCourseUpdateCategoriesParametersCategoriesInner
from poodle_async_full.models.core_course_update_courses_parameters_courses_inner import CoreCourseUpdateCoursesParametersCoursesInner
from poodle_async_full.models.core_course_update_courses_response import CoreCourseUpdateCoursesResponse
from poodle_async_full.models.core_course_view_course_response import CoreCourseViewCourseResponse
from poodle_async_full.models.core_courseformat_file_handlers_response_inner import CoreCourseformatFileHandlersResponseInner
from poodle_async_full.models.core_customfield_reload_template_response import CoreCustomfieldReloadTemplateResponse
from poodle_async_full.models.core_customfield_reload_template_response_categories_inner import CoreCustomfieldReloadTemplateResponseCategoriesInner
from poodle_async_full.models.core_customfield_reload_template_response_categories_inner_fields_inner import CoreCustomfieldReloadTemplateResponseCategoriesInnerFieldsInner
from poodle_async_full.models.core_dynamic_tabs_get_content_response import CoreDynamicTabsGetContentResponse
from poodle_async_full.models.core_enrol_get_course_enrolment_methods_response_inner import CoreEnrolGetCourseEnrolmentMethodsResponseInner
from poodle_async_full.models.core_enrol_get_enrolled_users_parameters_options_inner import CoreEnrolGetEnrolledUsersParametersOptionsInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner import CoreEnrolGetEnrolledUsersResponseInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_customfields_inner import CoreEnrolGetEnrolledUsersResponseInnerCustomfieldsInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_enrolledcourses_inner import CoreEnrolGetEnrolledUsersResponseInnerEnrolledcoursesInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_groups_inner import CoreEnrolGetEnrolledUsersResponseInnerGroupsInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_preferences_inner import CoreEnrolGetEnrolledUsersResponseInnerPreferencesInner
from poodle_async_full.models.core_enrol_get_enrolled_users_response_inner_roles_inner import CoreEnrolGetEnrolledUsersResponseInnerRolesInner
from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_parameters_coursecapabilities_inner import CoreEnrolGetEnrolledUsersWithCapabilityParametersCoursecapabilitiesInner
from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInner
from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInner
from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner_customfields_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerCustomfieldsInner
from poodle_async_full.models.core_enrol_get_enrolled_users_with_capability_response_inner_users_inner_groups_inner import CoreEnrolGetEnrolledUsersWithCapabilityResponseInnerUsersInnerGroupsInner
from poodle_async_full.models.core_enrol_get_potential_users_response_inner import CoreEnrolGetPotentialUsersResponseInner
from poodle_async_full.models.core_enrol_get_potential_users_response_inner_customfields_inner import CoreEnrolGetPotentialUsersResponseInnerCustomfieldsInner
from poodle_async_full.models.core_enrol_get_potential_users_response_inner_preferences_inner import CoreEnrolGetPotentialUsersResponseInnerPreferencesInner
from poodle_async_full.models.core_enrol_get_users_courses_response_inner import CoreEnrolGetUsersCoursesResponseInner
from poodle_async_full.models.core_enrol_submit_user_enrolment_form_response import CoreEnrolSubmitUserEnrolmentFormResponse
from poodle_async_full.models.core_enrol_unenrol_user_enrolment_response import CoreEnrolUnenrolUserEnrolmentResponse
from poodle_async_full.models.core_enrol_unenrol_user_enrolment_response_errors_inner import CoreEnrolUnenrolUserEnrolmentResponseErrorsInner
from poodle_async_full.models.core_fetch_notifications_parameters import CoreFetchNotificationsParameters
from poodle_async_full.models.core_fetch_notifications_response_inner import CoreFetchNotificationsResponseInner
from poodle_async_full.models.core_fetch_notifications_response_inner_variables import CoreFetchNotificationsResponseInnerVariables
from poodle_async_full.models.core_files_delete_draft_files_parameters_files_inner import CoreFilesDeleteDraftFilesParametersFilesInner
from poodle_async_full.models.core_files_delete_draft_files_response import CoreFilesDeleteDraftFilesResponse
from poodle_async_full.models.core_files_get_files_response import CoreFilesGetFilesResponse
from poodle_async_full.models.core_files_get_files_response_files_inner import CoreFilesGetFilesResponseFilesInner
from poodle_async_full.models.core_files_get_files_response_parents_inner import CoreFilesGetFilesResponseParentsInner
from poodle_async_full.models.core_files_get_unused_draft_itemid_response import CoreFilesGetUnusedDraftItemidResponse
from poodle_async_full.models.core_files_upload_response import CoreFilesUploadResponse
from poodle_async_full.models.core_filters_get_all_states_response import CoreFiltersGetAllStatesResponse
from poodle_async_full.models.core_filters_get_all_states_response_filters_inner import CoreFiltersGetAllStatesResponseFiltersInner
from poodle_async_full.models.core_filters_get_available_in_context_parameters_contexts_inner import CoreFiltersGetAvailableInContextParametersContextsInner
from poodle_async_full.models.core_filters_get_available_in_context_response import CoreFiltersGetAvailableInContextResponse
from poodle_async_full.models.core_filters_get_available_in_context_response_filters_inner import CoreFiltersGetAvailableInContextResponseFiltersInner
from poodle_async_full.models.core_form_dynamic_form_response import CoreFormDynamicFormResponse
from poodle_async_full.models.core_form_get_filetypes_browser_data_parameters import CoreFormGetFiletypesBrowserDataParameters
from poodle_async_full.models.core_form_get_filetypes_browser_data_response import CoreFormGetFiletypesBrowserDataResponse
from poodle_async_full.models.core_form_get_filetypes_browser_data_response_groups_inner import CoreFormGetFiletypesBrowserDataResponseGroupsInner
from poodle_async_full.models.core_form_get_filetypes_browser_data_response_groups_inner_types_inner import CoreFormGetFiletypesBrowserDataResponseGroupsInnerTypesInner
from poodle_async_full.models.core_get_component_strings_parameters import CoreGetComponentStringsParameters
from poodle_async_full.models.core_get_component_strings_response_inner import CoreGetComponentStringsResponseInner
from poodle_async_full.models.core_get_fragment_parameters_args_inner import CoreGetFragmentParametersArgsInner
from poodle_async_full.models.core_get_fragment_response import CoreGetFragmentResponse
from poodle_async_full.models.core_get_string_parameters import CoreGetStringParameters
from poodle_async_full.models.core_get_string_parameters_stringparams_inner import CoreGetStringParametersStringparamsInner
from poodle_async_full.models.core_get_strings_parameters import CoreGetStringsParameters
from poodle_async_full.models.core_get_strings_parameters_strings_inner import CoreGetStringsParametersStringsInner
from poodle_async_full.models.core_get_strings_parameters_strings_inner_stringparams_inner import CoreGetStringsParametersStringsInnerStringparamsInner
from poodle_async_full.models.core_get_strings_response_inner import CoreGetStringsResponseInner
from poodle_async_full.models.core_get_user_dates_parameters_timestamps_inner import CoreGetUserDatesParametersTimestampsInner
from poodle_async_full.models.core_get_user_dates_response import CoreGetUserDatesResponse
from poodle_async_full.models.core_grades_create_gradecategories_parameters_categories_inner import CoreGradesCreateGradecategoriesParametersCategoriesInner
from poodle_async_full.models.core_grades_create_gradecategories_parameters_categories_inner_options import CoreGradesCreateGradecategoriesParametersCategoriesInnerOptions
from poodle_async_full.models.core_grades_create_gradecategories_response import CoreGradesCreateGradecategoriesResponse
from poodle_async_full.models.core_grades_get_enrolled_users_for_selector_response import CoreGradesGetEnrolledUsersForSelectorResponse
from poodle_async_full.models.core_grades_get_feedback_response import CoreGradesGetFeedbackResponse
from poodle_async_full.models.core_grades_get_gradable_users_response import CoreGradesGetGradableUsersResponse
from poodle_async_full.models.core_grades_get_gradeitems_response import CoreGradesGetGradeitemsResponse
from poodle_async_full.models.core_grades_get_gradeitems_response_grade_items_inner import CoreGradesGetGradeitemsResponseGradeItemsInner
from poodle_async_full.models.core_grades_get_groups_for_selector_response import CoreGradesGetGroupsForSelectorResponse
from poodle_async_full.models.core_grades_get_groups_for_selector_response_groups_inner import CoreGradesGetGroupsForSelectorResponseGroupsInner
from poodle_async_full.models.core_grades_grader_gradingpanel_point_fetch_response import CoreGradesGraderGradingpanelPointFetchResponse
from poodle_async_full.models.core_grades_grader_gradingpanel_point_fetch_response_grade import CoreGradesGraderGradingpanelPointFetchResponseGrade
from poodle_async_full.models.core_grades_grader_gradingpanel_point_store_response import CoreGradesGraderGradingpanelPointStoreResponse
from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response import CoreGradesGraderGradingpanelScaleFetchResponse
from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response_grade import CoreGradesGraderGradingpanelScaleFetchResponseGrade
from poodle_async_full.models.core_grades_grader_gradingpanel_scale_fetch_response_grade_options_inner import CoreGradesGraderGradingpanelScaleFetchResponseGradeOptionsInner
from poodle_async_full.models.core_grades_grader_gradingpanel_scale_store_response import CoreGradesGraderGradingpanelScaleStoreResponse
from poodle_async_full.models.core_grades_update_grades_parameters_grades_inner import CoreGradesUpdateGradesParametersGradesInner
from poodle_async_full.models.core_grades_update_grades_parameters_itemdetails import CoreGradesUpdateGradesParametersItemdetails
from poodle_async_full.models.core_grading_get_definitions_response import CoreGradingGetDefinitionsResponse
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner import CoreGradingGetDefinitionsResponseAreasInner
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInner
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuide
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide_guide_comments_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCommentsInner
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_guide_guide_criteria_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerGuideGuideCriteriaInner
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubric
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric_rubric_criteria_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInner
from poodle_async_full.models.core_grading_get_definitions_response_areas_inner_definitions_inner_rubric_rubric_criteria_inner_levels_inner import CoreGradingGetDefinitionsResponseAreasInnerDefinitionsInnerRubricRubricCriteriaInnerLevelsInner
from poodle_async_full.models.core_grading_get_gradingform_instances_response import CoreGradingGetGradingformInstancesResponse
from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner import CoreGradingGetGradingformInstancesResponseInstancesInner
from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_guide import CoreGradingGetGradingformInstancesResponseInstancesInnerGuide
from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_guide_criteria_inner import CoreGradingGetGradingformInstancesResponseInstancesInnerGuideCriteriaInner
from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_rubric import CoreGradingGetGradingformInstancesResponseInstancesInnerRubric
from poodle_async_full.models.core_grading_get_gradingform_instances_response_instances_inner_rubric_criteria_inner import CoreGradingGetGradingformInstancesResponseInstancesInnerRubricCriteriaInner
from poodle_async_full.models.core_group_add_group_members_parameters_members_inner import CoreGroupAddGroupMembersParametersMembersInner
from poodle_async_full.models.core_group_assign_grouping_parameters_assignments_inner import CoreGroupAssignGroupingParametersAssignmentsInner
from poodle_async_full.models.core_group_create_groupings_parameters_groupings_inner import CoreGroupCreateGroupingsParametersGroupingsInner
from poodle_async_full.models.core_group_create_groupings_response_inner import CoreGroupCreateGroupingsResponseInner
from poodle_async_full.models.core_group_create_groups_parameters_groups_inner import CoreGroupCreateGroupsParametersGroupsInner
from poodle_async_full.models.core_group_create_groups_response_inner import CoreGroupCreateGroupsResponseInner
from poodle_async_full.models.core_group_get_activity_allowed_groups_response import CoreGroupGetActivityAllowedGroupsResponse
from poodle_async_full.models.core_group_get_activity_allowed_groups_response_groups_inner import CoreGroupGetActivityAllowedGroupsResponseGroupsInner
from poodle_async_full.models.core_group_get_activity_groupmode_response import CoreGroupGetActivityGroupmodeResponse
from poodle_async_full.models.core_group_get_course_groupings_response_inner import CoreGroupGetCourseGroupingsResponseInner
from poodle_async_full.models.core_group_get_course_groups_response_inner import CoreGroupGetCourseGroupsResponseInner
from poodle_async_full.models.core_group_get_course_user_groups_response import CoreGroupGetCourseUserGroupsResponse
from poodle_async_full.models.core_group_get_group_members_response_inner import CoreGroupGetGroupMembersResponseInner
from poodle_async_full.models.core_group_get_groupings_response_inner import CoreGroupGetGroupingsResponseInner
from poodle_async_full.models.core_group_get_groupings_response_inner_groups_inner import CoreGroupGetGroupingsResponseInnerGroupsInner
from poodle_async_full.models.core_group_get_groups_for_selector_response import CoreGroupGetGroupsForSelectorResponse
from poodle_async_full.models.core_group_get_groups_response_inner import CoreGroupGetGroupsResponseInner
from poodle_async_full.models.core_group_update_groupings_parameters_groupings_inner import CoreGroupUpdateGroupingsParametersGroupingsInner
from poodle_async_full.models.core_group_update_groups_parameters_groups_inner import CoreGroupUpdateGroupsParametersGroupsInner
from poodle_async_full.models.core_h5p_get_trusted_h5p_file_response import CoreH5pGetTrustedH5pFileResponse
from poodle_async_full.models.core_message_create_contact_request_response import CoreMessageCreateContactRequestResponse
from poodle_async_full.models.core_message_create_contact_request_response_request import CoreMessageCreateContactRequestResponseRequest
from poodle_async_full.models.core_message_data_for_messagearea_search_messages_response import CoreMessageDataForMessageareaSearchMessagesResponse
from poodle_async_full.models.core_message_data_for_messagearea_search_messages_response_contacts_inner import CoreMessageDataForMessageareaSearchMessagesResponseContactsInner
from poodle_async_full.models.core_message_delete_message_response import CoreMessageDeleteMessageResponse
from poodle_async_full.models.core_message_get_blocked_users_response import CoreMessageGetBlockedUsersResponse
from poodle_async_full.models.core_message_get_blocked_users_response_users_inner import CoreMessageGetBlockedUsersResponseUsersInner
from poodle_async_full.models.core_message_get_contact_requests_response_inner import CoreMessageGetContactRequestsResponseInner
from poodle_async_full.models.core_message_get_contact_requests_response_inner_contactrequests_inner import CoreMessageGetContactRequestsResponseInnerContactrequestsInner
from poodle_async_full.models.core_message_get_contact_requests_response_inner_conversations_inner import CoreMessageGetContactRequestsResponseInnerConversationsInner
from poodle_async_full.models.core_message_get_conversation_between_users_response import CoreMessageGetConversationBetweenUsersResponse
from poodle_async_full.models.core_message_get_conversation_between_users_response_messages_inner import CoreMessageGetConversationBetweenUsersResponseMessagesInner
from poodle_async_full.models.core_message_get_conversation_counts_response import CoreMessageGetConversationCountsResponse
from poodle_async_full.models.core_message_get_conversation_counts_response_types import CoreMessageGetConversationCountsResponseTypes
from poodle_async_full.models.core_message_get_conversation_messages_response import CoreMessageGetConversationMessagesResponse
from poodle_async_full.models.core_message_get_conversation_response import CoreMessageGetConversationResponse
from poodle_async_full.models.core_message_get_conversations_response import CoreMessageGetConversationsResponse
from poodle_async_full.models.core_message_get_conversations_response_conversations_inner import CoreMessageGetConversationsResponseConversationsInner
from poodle_async_full.models.core_message_get_message_processor_response import CoreMessageGetMessageProcessorResponse
from poodle_async_full.models.core_message_get_messages_response import CoreMessageGetMessagesResponse
from poodle_async_full.models.core_message_get_messages_response_messages_inner import CoreMessageGetMessagesResponseMessagesInner
from poodle_async_full.models.core_message_get_self_conversation_response import CoreMessageGetSelfConversationResponse
from poodle_async_full.models.core_message_get_unread_conversation_counts_response import CoreMessageGetUnreadConversationCountsResponse
from poodle_async_full.models.core_message_get_unread_conversation_counts_response_types import CoreMessageGetUnreadConversationCountsResponseTypes
from poodle_async_full.models.core_message_get_unsent_message_response import CoreMessageGetUnsentMessageResponse
from poodle_async_full.models.core_message_get_user_message_preferences_response import CoreMessageGetUserMessagePreferencesResponse
from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences import CoreMessageGetUserMessagePreferencesResponsePreferences
from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInner
from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner_notifications_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInner
from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_components_inner_notifications_inner_processors_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesComponentsInnerNotificationsInnerProcessorsInner
from poodle_async_full.models.core_message_get_user_message_preferences_response_preferences_processors_inner import CoreMessageGetUserMessagePreferencesResponsePreferencesProcessorsInner
from poodle_async_full.models.core_message_get_user_notification_preferences_response import CoreMessageGetUserNotificationPreferencesResponse
from poodle_async_full.models.core_message_mark_message_read_response import CoreMessageMarkMessageReadResponse
from poodle_async_full.models.core_message_mark_notification_read_response import CoreMessageMarkNotificationReadResponse
from poodle_async_full.models.core_message_message_processor_config_form_parameters_formvalues_inner import CoreMessageMessageProcessorConfigFormParametersFormvaluesInner
from poodle_async_full.models.core_message_message_search_users_response import CoreMessageMessageSearchUsersResponse
from poodle_async_full.models.core_message_search_contacts_response_inner import CoreMessageSearchContactsResponseInner
from poodle_async_full.models.core_message_send_instant_messages_parameters_messages_inner import CoreMessageSendInstantMessagesParametersMessagesInner
from poodle_async_full.models.core_message_send_instant_messages_response_inner import CoreMessageSendInstantMessagesResponseInner
from poodle_async_full.models.core_message_send_messages_to_conversation_parameters_messages_inner import CoreMessageSendMessagesToConversationParametersMessagesInner
from poodle_async_full.models.core_message_set_default_notification_response import CoreMessageSetDefaultNotificationResponse
from poodle_async_full.models.core_moodlenet_auth_check_response import CoreMoodlenetAuthCheckResponse
from poodle_async_full.models.core_moodlenet_get_share_info_activity_response import CoreMoodlenetGetShareInfoActivityResponse
from poodle_async_full.models.core_moodlenet_get_shared_course_info_response import CoreMoodlenetGetSharedCourseInfoResponse
from poodle_async_full.models.core_moodlenet_send_activity_response import CoreMoodlenetSendActivityResponse
from poodle_async_full.models.core_moodlenet_send_course_response import CoreMoodlenetSendCourseResponse
from poodle_async_full.models.core_my_view_page_response import CoreMyViewPageResponse
from poodle_async_full.models.core_notes_create_notes_parameters_notes_inner import CoreNotesCreateNotesParametersNotesInner
from poodle_async_full.models.core_notes_create_notes_response_inner import CoreNotesCreateNotesResponseInner
from poodle_async_full.models.core_notes_delete_notes_response_inner import CoreNotesDeleteNotesResponseInner
from poodle_async_full.models.core_notes_get_course_notes_response import CoreNotesGetCourseNotesResponse
from poodle_async_full.models.core_notes_get_course_notes_response_coursenotes_inner import CoreNotesGetCourseNotesResponseCoursenotesInner
from poodle_async_full.models.core_notes_get_notes_response import CoreNotesGetNotesResponse
from poodle_async_full.models.core_notes_get_notes_response_notes_inner import CoreNotesGetNotesResponseNotesInner
from poodle_async_full.models.core_notes_update_notes_parameters_notes_inner import CoreNotesUpdateNotesParametersNotesInner
from poodle_async_full.models.core_notes_view_notes_response import CoreNotesViewNotesResponse
from poodle_async_full.models.core_output_load_fontawesome_icon_system_map_parameters import CoreOutputLoadFontawesomeIconSystemMapParameters
from poodle_async_full.models.core_output_load_fontawesome_icon_system_map_response_inner import CoreOutputLoadFontawesomeIconSystemMapResponseInner
from poodle_async_full.models.core_output_load_template_parameters import CoreOutputLoadTemplateParameters
from poodle_async_full.models.core_output_load_template_with_dependencies_parameters import CoreOutputLoadTemplateWithDependenciesParameters
from poodle_async_full.models.core_output_load_template_with_dependencies_response import CoreOutputLoadTemplateWithDependenciesResponse
from poodle_async_full.models.core_output_load_template_with_dependencies_response_strings_inner import CoreOutputLoadTemplateWithDependenciesResponseStringsInner
from poodle_async_full.models.core_output_poll_stored_progress_response_inner import CoreOutputPollStoredProgressResponseInner
from poodle_async_full.models.core_payment_get_available_gateways_response_inner import CorePaymentGetAvailableGatewaysResponseInner
from poodle_async_full.models.core_question_get_random_question_summaries_response import CoreQuestionGetRandomQuestionSummariesResponse
from poodle_async_full.models.core_question_get_random_question_summaries_response_questions_inner import CoreQuestionGetRandomQuestionSummariesResponseQuestionsInner
from poodle_async_full.models.core_question_get_random_question_summaries_response_questions_inner_icon import CoreQuestionGetRandomQuestionSummariesResponseQuestionsInnerIcon
from poodle_async_full.models.core_question_search_shared_banks_response import CoreQuestionSearchSharedBanksResponse
from poodle_async_full.models.core_question_search_shared_banks_response_sharedbanks_inner import CoreQuestionSearchSharedBanksResponseSharedbanksInner
from poodle_async_full.models.core_question_update_flag_response import CoreQuestionUpdateFlagResponse
from poodle_async_full.models.core_rating_add_rating_response import CoreRatingAddRatingResponse
from poodle_async_full.models.core_rating_get_item_ratings_response import CoreRatingGetItemRatingsResponse
from poodle_async_full.models.core_rating_get_item_ratings_response_ratings_inner import CoreRatingGetItemRatingsResponseRatingsInner
from poodle_async_full.models.core_reportbuilder_can_view_system_report_parameters_parameters_inner import CoreReportbuilderCanViewSystemReportParametersParametersInner
from poodle_async_full.models.core_reportbuilder_columns_add_response import CoreReportbuilderColumnsAddResponse
from poodle_async_full.models.core_reportbuilder_columns_add_response_sortablecolumns_inner import CoreReportbuilderColumnsAddResponseSortablecolumnsInner
from poodle_async_full.models.core_reportbuilder_columns_add_response_sortablecolumns_inner_sorticon import CoreReportbuilderColumnsAddResponseSortablecolumnsInnerSorticon
from poodle_async_full.models.core_reportbuilder_columns_delete_response import CoreReportbuilderColumnsDeleteResponse
from poodle_async_full.models.core_reportbuilder_columns_sort_get_response import CoreReportbuilderColumnsSortGetResponse
from poodle_async_full.models.core_reportbuilder_columns_sort_reorder_response import CoreReportbuilderColumnsSortReorderResponse
from poodle_async_full.models.core_reportbuilder_columns_sort_toggle_response import CoreReportbuilderColumnsSortToggleResponse
from poodle_async_full.models.core_reportbuilder_conditions_add_response import CoreReportbuilderConditionsAddResponse
from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner import CoreReportbuilderConditionsAddResponseAvailableconditionsInner
from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner_optiongroup import CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroup
from poodle_async_full.models.core_reportbuilder_conditions_add_response_availableconditions_inner_optiongroup_values_inner import CoreReportbuilderConditionsAddResponseAvailableconditionsInnerOptiongroupValuesInner
from poodle_async_full.models.core_reportbuilder_conditions_delete_response import CoreReportbuilderConditionsDeleteResponse
from poodle_async_full.models.core_reportbuilder_conditions_reorder_response import CoreReportbuilderConditionsReorderResponse
from poodle_async_full.models.core_reportbuilder_conditions_reset_response import CoreReportbuilderConditionsResetResponse
from poodle_async_full.models.core_reportbuilder_filters_add_response import CoreReportbuilderFiltersAddResponse
from poodle_async_full.models.core_reportbuilder_filters_add_response_activefilters_inner import CoreReportbuilderFiltersAddResponseActivefiltersInner
from poodle_async_full.models.core_reportbuilder_filters_delete_response import CoreReportbuilderFiltersDeleteResponse
from poodle_async_full.models.core_reportbuilder_filters_reorder_response import CoreReportbuilderFiltersReorderResponse
from poodle_async_full.models.core_reportbuilder_list_reports_response import CoreReportbuilderListReportsResponse
from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner import CoreReportbuilderListReportsResponseReportsInner
from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner_customfields import CoreReportbuilderListReportsResponseReportsInnerCustomfields
from poodle_async_full.models.core_reportbuilder_list_reports_response_reports_inner_customfields_data_inner import CoreReportbuilderListReportsResponseReportsInnerCustomfieldsDataInner
from poodle_async_full.models.core_reportbuilder_reports_get_response import CoreReportbuilderReportsGetResponse
from poodle_async_full.models.core_reportbuilder_reports_get_response_attributes_inner import CoreReportbuilderReportsGetResponseAttributesInner
from poodle_async_full.models.core_reportbuilder_reports_get_response_button import CoreReportbuilderReportsGetResponseButton
from poodle_async_full.models.core_reportbuilder_reports_get_response_button_attributes_inner import CoreReportbuilderReportsGetResponseButtonAttributesInner
from poodle_async_full.models.core_reportbuilder_reports_get_response_cardview import CoreReportbuilderReportsGetResponseCardview
from poodle_async_full.models.core_reportbuilder_reports_get_response_conditions import CoreReportbuilderReportsGetResponseConditions
from poodle_async_full.models.core_reportbuilder_reports_get_response_filters import CoreReportbuilderReportsGetResponseFilters
from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards import CoreReportbuilderReportsGetResponseSidebarmenucards
from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards_menucards_inner import CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInner
from poodle_async_full.models.core_reportbuilder_reports_get_response_sidebarmenucards_menucards_inner_items_inner import CoreReportbuilderReportsGetResponseSidebarmenucardsMenucardsInnerItemsInner
from poodle_async_full.models.core_reportbuilder_reports_get_response_sorting import CoreReportbuilderReportsGetResponseSorting
from poodle_async_full.models.core_reportbuilder_retrieve_report_response import CoreReportbuilderRetrieveReportResponse
from poodle_async_full.models.core_reportbuilder_retrieve_report_response_data import CoreReportbuilderRetrieveReportResponseData
from poodle_async_full.models.core_reportbuilder_retrieve_report_response_data_rows_inner import CoreReportbuilderRetrieveReportResponseDataRowsInner
from poodle_async_full.models.core_reportbuilder_retrieve_system_report_response import CoreReportbuilderRetrieveSystemReportResponse
from poodle_async_full.models.core_reportbuilder_view_report_response import CoreReportbuilderViewReportResponse
from poodle_async_full.models.core_role_assign_roles_parameters_assignments_inner import CoreRoleAssignRolesParametersAssignmentsInner
from poodle_async_full.models.core_role_unassign_roles_parameters_unassignments_inner import CoreRoleUnassignRolesParametersUnassignmentsInner
from poodle_async_full.models.core_search_get_relevant_users_response_inner import CoreSearchGetRelevantUsersResponseInner
from poodle_async_full.models.core_search_get_results_parameters_filters import CoreSearchGetResultsParametersFilters
from poodle_async_full.models.core_search_get_results_response import CoreSearchGetResultsResponse
from poodle_async_full.models.core_search_get_results_response_results_inner import CoreSearchGetResultsResponseResultsInner
from poodle_async_full.models.core_search_get_search_areas_list_response import CoreSearchGetSearchAreasListResponse
from poodle_async_full.models.core_search_get_search_areas_list_response_areas_inner import CoreSearchGetSearchAreasListResponseAreasInner
from poodle_async_full.models.core_search_get_top_results_response import CoreSearchGetTopResultsResponse
from poodle_async_full.models.core_search_view_results_parameters_filters import CoreSearchViewResultsParametersFilters
from poodle_async_full.models.core_search_view_results_response import CoreSearchViewResultsResponse
from poodle_async_full.models.core_session_time_remaining_response import CoreSessionTimeRemainingResponse
from poodle_async_full.models.core_sms_set_gateway_status_response import CoreSmsSetGatewayStatusResponse
from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_filters_inner import CoreTableGetDynamicTableContentParametersFiltersInner
from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_filters_inner_filteroptions_inner import CoreTableGetDynamicTableContentParametersFiltersInnerFilteroptionsInner
from poodle_async_full.models.core_table_get_dynamic_table_content_parameters_sortdata_inner import CoreTableGetDynamicTableContentParametersSortdataInner
from poodle_async_full.models.core_table_get_dynamic_table_content_response import CoreTableGetDynamicTableContentResponse
from poodle_async_full.models.core_tag_get_tag_areas_response import CoreTagGetTagAreasResponse
from poodle_async_full.models.core_tag_get_tag_areas_response_areas_inner import CoreTagGetTagAreasResponseAreasInner
from poodle_async_full.models.core_tag_get_tag_cloud_response import CoreTagGetTagCloudResponse
from poodle_async_full.models.core_tag_get_tag_cloud_response_tags_inner import CoreTagGetTagCloudResponseTagsInner
from poodle_async_full.models.core_tag_get_tag_collections_response import CoreTagGetTagCollectionsResponse
from poodle_async_full.models.core_tag_get_tag_collections_response_collections_inner import CoreTagGetTagCollectionsResponseCollectionsInner
from poodle_async_full.models.core_tag_get_tagindex_parameters_tagindex import CoreTagGetTagindexParametersTagindex
from poodle_async_full.models.core_tag_get_tagindex_per_area_parameters_tagindex import CoreTagGetTagindexPerAreaParametersTagindex
from poodle_async_full.models.core_tag_get_tagindex_per_area_response_inner import CoreTagGetTagindexPerAreaResponseInner
from poodle_async_full.models.core_tag_get_tagindex_response import CoreTagGetTagindexResponse
from poodle_async_full.models.core_tag_get_tags_parameters_tags_inner import CoreTagGetTagsParametersTagsInner
from poodle_async_full.models.core_tag_get_tags_response import CoreTagGetTagsResponse
from poodle_async_full.models.core_tag_get_tags_response_tags_inner import CoreTagGetTagsResponseTagsInner
from poodle_async_full.models.core_tag_update_tags_parameters_tags_inner import CoreTagUpdateTagsParametersTagsInner
from poodle_async_full.models.core_tag_update_tags_response import CoreTagUpdateTagsResponse
from poodle_async_full.models.core_update_inplace_editable_response import CoreUpdateInplaceEditableResponse
from poodle_async_full.models.core_update_inplace_editable_response_editicon import CoreUpdateInplaceEditableResponseEditicon
from poodle_async_full.models.core_user_agree_site_policy_response import CoreUserAgreeSitePolicyResponse
from poodle_async_full.models.core_user_create_users_parameters_users_inner import CoreUserCreateUsersParametersUsersInner
from poodle_async_full.models.core_user_create_users_parameters_users_inner_customfields_inner import CoreUserCreateUsersParametersUsersInnerCustomfieldsInner
from poodle_async_full.models.core_user_create_users_parameters_users_inner_preferences_inner import CoreUserCreateUsersParametersUsersInnerPreferencesInner
from poodle_async_full.models.core_user_create_users_response_inner import CoreUserCreateUsersResponseInner
from poodle_async_full.models.core_user_get_course_user_profiles_parameters_userlist_inner import CoreUserGetCourseUserProfilesParametersUserlistInner
from poodle_async_full.models.core_user_get_course_user_profiles_response_inner import CoreUserGetCourseUserProfilesResponseInner
from poodle_async_full.models.core_user_get_private_files_info_response import CoreUserGetPrivateFilesInfoResponse
from poodle_async_full.models.core_user_get_user_preferences_response import CoreUserGetUserPreferencesResponse
from poodle_async_full.models.core_user_get_user_preferences_response_preferences_inner import CoreUserGetUserPreferencesResponsePreferencesInner
from poodle_async_full.models.core_user_get_users_parameters_criteria_inner import CoreUserGetUsersParametersCriteriaInner
from poodle_async_full.models.core_user_get_users_response import CoreUserGetUsersResponse
from poodle_async_full.models.core_user_get_users_response_warnings_inner import CoreUserGetUsersResponseWarningsInner
from poodle_async_full.models.core_user_prepare_private_files_for_edition_response import CoreUserPreparePrivateFilesForEditionResponse
from poodle_async_full.models.core_user_remove_user_device_response import CoreUserRemoveUserDeviceResponse
from poodle_async_full.models.core_user_search_identity_response import CoreUserSearchIdentityResponse
from poodle_async_full.models.core_user_search_identity_response_list_inner import CoreUserSearchIdentityResponseListInner
from poodle_async_full.models.core_user_search_identity_response_list_inner_extrafields_inner import CoreUserSearchIdentityResponseListInnerExtrafieldsInner
from poodle_async_full.models.core_user_set_user_preferences_parameters import CoreUserSetUserPreferencesParameters
from poodle_async_full.models.core_user_set_user_preferences_parameters_preferences_inner import CoreUserSetUserPreferencesParametersPreferencesInner
from poodle_async_full.models.core_user_set_user_preferences_response import CoreUserSetUserPreferencesResponse
from poodle_async_full.models.core_user_set_user_preferences_response_saved_inner import CoreUserSetUserPreferencesResponseSavedInner
from poodle_async_full.models.core_user_update_picture_response import CoreUserUpdatePictureResponse
from poodle_async_full.models.core_user_update_private_files_response import CoreUserUpdatePrivateFilesResponse
from poodle_async_full.models.core_user_update_user_device_public_key_response import CoreUserUpdateUserDevicePublicKeyResponse
from poodle_async_full.models.core_user_update_user_preferences_parameters_preferences_inner import CoreUserUpdateUserPreferencesParametersPreferencesInner
from poodle_async_full.models.core_user_update_users_parameters_users_inner import CoreUserUpdateUsersParametersUsersInner
from poodle_async_full.models.core_user_update_users_response import CoreUserUpdateUsersResponse
from poodle_async_full.models.core_user_view_user_list_response import CoreUserViewUserListResponse
from poodle_async_full.models.core_user_view_user_profile_response import CoreUserViewUserProfileResponse
from poodle_async_full.models.core_webservice_get_site_info_response import CoreWebserviceGetSiteInfoResponse
from poodle_async_full.models.core_webservice_get_site_info_response_advancedfeatures_inner import CoreWebserviceGetSiteInfoResponseAdvancedfeaturesInner
from poodle_async_full.models.core_webservice_get_site_info_response_functions_inner import CoreWebserviceGetSiteInfoResponseFunctionsInner
from poodle_async_full.models.customfield_number_recalculate_value_response import CustomfieldNumberRecalculateValueResponse
from poodle_async_full.models.editor_tiny_get_configuration_response import EditorTinyGetConfigurationResponse
from poodle_async_full.models.editor_tiny_get_configuration_response_installedlanguages_inner import EditorTinyGetConfigurationResponseInstalledlanguagesInner
from poodle_async_full.models.editor_tiny_get_configuration_response_plugins_inner import EditorTinyGetConfigurationResponsePluginsInner
from poodle_async_full.models.editor_tiny_get_configuration_response_plugins_inner_settings_inner import EditorTinyGetConfigurationResponsePluginsInnerSettingsInner
from poodle_async_full.models.enrol_guest_get_instance_info_response import EnrolGuestGetInstanceInfoResponse
from poodle_async_full.models.enrol_guest_get_instance_info_response_instanceinfo import EnrolGuestGetInstanceInfoResponseInstanceinfo
from poodle_async_full.models.enrol_guest_validate_password_response import EnrolGuestValidatePasswordResponse
from poodle_async_full.models.enrol_manual_enrol_users_parameters_enrolments_inner import EnrolManualEnrolUsersParametersEnrolmentsInner
from poodle_async_full.models.enrol_manual_unenrol_users_parameters_enrolments_inner import EnrolManualUnenrolUsersParametersEnrolmentsInner
from poodle_async_full.models.enrol_meta_add_instances_parameters_instances_inner import EnrolMetaAddInstancesParametersInstancesInner
from poodle_async_full.models.enrol_meta_add_instances_response_inner import EnrolMetaAddInstancesResponseInner
from poodle_async_full.models.enrol_meta_delete_instances_parameters_instances_inner import EnrolMetaDeleteInstancesParametersInstancesInner
from poodle_async_full.models.enrol_meta_delete_instances_response_inner import EnrolMetaDeleteInstancesResponseInner
from poodle_async_full.models.enrol_self_enrol_user_response import EnrolSelfEnrolUserResponse
from poodle_async_full.models.enrol_self_get_instance_info_response import EnrolSelfGetInstanceInfoResponse
from poodle_async_full.models.gradereport_grader_get_users_in_report_response import GradereportGraderGetUsersInReportResponse
from poodle_async_full.models.gradereport_overview_get_course_grades_response import GradereportOverviewGetCourseGradesResponse
from poodle_async_full.models.gradereport_overview_get_course_grades_response_grades_inner import GradereportOverviewGetCourseGradesResponseGradesInner
from poodle_async_full.models.gradereport_overview_view_grade_report_response import GradereportOverviewViewGradeReportResponse
from poodle_async_full.models.gradereport_singleview_get_grade_items_for_search_widget_response import GradereportSingleviewGetGradeItemsForSearchWidgetResponse
from poodle_async_full.models.gradereport_singleview_get_grade_items_for_search_widget_response_gradeitems_inner import GradereportSingleviewGetGradeItemsForSearchWidgetResponseGradeitemsInner
from poodle_async_full.models.gradereport_user_get_access_information_response import GradereportUserGetAccessInformationResponse
from poodle_async_full.models.gradereport_user_get_grade_items_response import GradereportUserGetGradeItemsResponse
from poodle_async_full.models.gradereport_user_get_grade_items_response_usergrades_inner import GradereportUserGetGradeItemsResponseUsergradesInner
from poodle_async_full.models.gradereport_user_get_grade_items_response_usergrades_inner_gradeitems_inner import GradereportUserGetGradeItemsResponseUsergradesInnerGradeitemsInner
from poodle_async_full.models.gradereport_user_get_grades_table_response import GradereportUserGetGradesTableResponse
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner import GradereportUserGetGradesTableResponseTablesInner
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner import GradereportUserGetGradesTableResponseTablesInnerTabledataInner
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_average import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerAverage
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_contributiontocoursetotal import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerContributiontocoursetotal
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_feedback import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerFeedback
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_grade import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerGrade
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_itemname import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerItemname
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_leader import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLeader
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_lettergrade import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerLettergrade
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_percentage import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerPercentage
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_range import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRange
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_rank import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerRank
from poodle_async_full.models.gradereport_user_get_grades_table_response_tables_inner_tabledata_inner_weight import GradereportUserGetGradesTableResponseTablesInnerTabledataInnerWeight
from poodle_async_full.models.gradereport_user_view_grade_report_response import GradereportUserViewGradeReportResponse
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response import GradingformGuideGraderGradingpanelFetchResponse
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade import GradingformGuideGraderGradingpanelFetchResponseGrade
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade_comments_inner import GradingformGuideGraderGradingpanelFetchResponseGradeCommentsInner
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_fetch_response_grade_criterion_inner import GradingformGuideGraderGradingpanelFetchResponseGradeCriterionInner
from poodle_async_full.models.gradingform_guide_grader_gradingpanel_store_response import GradingformGuideGraderGradingpanelStoreResponse
from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response import GradingformRubricGraderGradingpanelFetchResponse
from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade import GradingformRubricGraderGradingpanelFetchResponseGrade
from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade_criteria_inner import GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInner
from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_fetch_response_grade_criteria_inner_levels_inner import GradingformRubricGraderGradingpanelFetchResponseGradeCriteriaInnerLevelsInner
from poodle_async_full.models.gradingform_rubric_grader_gradingpanel_store_response import GradingformRubricGraderGradingpanelStoreResponse
from poodle_async_full.models.login_token200_response import LoginToken200Response
from poodle_async_full.models.media_videojs_get_language_parameters import MediaVideojsGetLanguageParameters
from poodle_async_full.models.message_airnotifier_are_notification_preferences_configured_response import MessageAirnotifierAreNotificationPreferencesConfiguredResponse
from poodle_async_full.models.message_airnotifier_are_notification_preferences_configured_response_users_inner import MessageAirnotifierAreNotificationPreferencesConfiguredResponseUsersInner
from poodle_async_full.models.message_airnotifier_enable_device_response import MessageAirnotifierEnableDeviceResponse
from poodle_async_full.models.message_airnotifier_get_user_devices_response import MessageAirnotifierGetUserDevicesResponse
from poodle_async_full.models.message_airnotifier_get_user_devices_response_devices_inner import MessageAirnotifierGetUserDevicesResponseDevicesInner
from poodle_async_full.models.message_popup_get_popup_notifications_response import MessagePopupGetPopupNotificationsResponse
from poodle_async_full.models.message_popup_get_popup_notifications_response_notifications_inner import MessagePopupGetPopupNotificationsResponseNotificationsInner
from poodle_async_full.models.mod_assign_get_assignments_response import ModAssignGetAssignmentsResponse
from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner import ModAssignGetAssignmentsResponseCoursesInner
from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner_assignments_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInner
from poodle_async_full.models.mod_assign_get_assignments_response_courses_inner_assignments_inner_configs_inner import ModAssignGetAssignmentsResponseCoursesInnerAssignmentsInnerConfigsInner
from poodle_async_full.models.mod_assign_get_assignments_response_warnings_inner import ModAssignGetAssignmentsResponseWarningsInner
from poodle_async_full.models.mod_assign_get_grades_response import ModAssignGetGradesResponse
from poodle_async_full.models.mod_assign_get_grades_response_assignments_inner import ModAssignGetGradesResponseAssignmentsInner
from poodle_async_full.models.mod_assign_get_grades_response_assignments_inner_grades_inner import ModAssignGetGradesResponseAssignmentsInnerGradesInner
from poodle_async_full.models.mod_assign_get_grades_response_warnings_inner import ModAssignGetGradesResponseWarningsInner
from poodle_async_full.models.mod_assign_get_participant_response import ModAssignGetParticipantResponse
from poodle_async_full.models.mod_assign_get_submission_status_response import ModAssignGetSubmissionStatusResponse
from poodle_async_full.models.mod_assign_get_submission_status_response_assignmentdata import ModAssignGetSubmissionStatusResponseAssignmentdata
from poodle_async_full.models.mod_assign_get_submission_status_response_assignmentdata_attachments import ModAssignGetSubmissionStatusResponseAssignmentdataAttachments
from poodle_async_full.models.mod_assign_get_submission_status_response_feedback import ModAssignGetSubmissionStatusResponseFeedback
from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInner
from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner_editorfields_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerEditorfieldsInner
from poodle_async_full.models.mod_assign_get_submission_status_response_feedback_plugins_inner_fileareas_inner import ModAssignGetSubmissionStatusResponseFeedbackPluginsInnerFileareasInner
from poodle_async_full.models.mod_assign_get_submission_status_response_gradingsummary import ModAssignGetSubmissionStatusResponseGradingsummary
from poodle_async_full.models.mod_assign_get_submission_status_response_lastattempt import ModAssignGetSubmissionStatusResponseLastattempt
from poodle_async_full.models.mod_assign_get_submission_status_response_lastattempt_submission import ModAssignGetSubmissionStatusResponseLastattemptSubmission
from poodle_async_full.models.mod_assign_get_submission_status_response_previousattempts_inner import ModAssignGetSubmissionStatusResponsePreviousattemptsInner
from poodle_async_full.models.mod_assign_get_submissions_response import ModAssignGetSubmissionsResponse
from poodle_async_full.models.mod_assign_get_submissions_response_assignments_inner import ModAssignGetSubmissionsResponseAssignmentsInner
from poodle_async_full.models.mod_assign_get_user_flags_response import ModAssignGetUserFlagsResponse
from poodle_async_full.models.mod_assign_get_user_flags_response_assignments_inner import ModAssignGetUserFlagsResponseAssignmentsInner
from poodle_async_full.models.mod_assign_get_user_flags_response_assignments_inner_userflags_inner import ModAssignGetUserFlagsResponseAssignmentsInnerUserflagsInner
from poodle_async_full.models.mod_assign_get_user_flags_response_warnings_inner import ModAssignGetUserFlagsResponseWarningsInner
from poodle_async_full.models.mod_assign_get_user_mappings_response import ModAssignGetUserMappingsResponse
from poodle_async_full.models.mod_assign_get_user_mappings_response_assignments_inner import ModAssignGetUserMappingsResponseAssignmentsInner
from poodle_async_full.models.mod_assign_get_user_mappings_response_assignments_inner_mappings_inner import ModAssignGetUserMappingsResponseAssignmentsInnerMappingsInner
from poodle_async_full.models.mod_assign_get_user_mappings_response_warnings_inner import ModAssignGetUserMappingsResponseWarningsInner
from poodle_async_full.models.mod_assign_list_participants_response_inner import ModAssignListParticipantsResponseInner
from poodle_async_full.models.mod_assign_remove_submission_response import ModAssignRemoveSubmissionResponse
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata import ModAssignSaveGradeParametersAdvancedgradingdata
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide import ModAssignSaveGradeParametersAdvancedgradingdataGuide
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide_criteria_inner import ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInner
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_guide_criteria_inner_fillings_inner import ModAssignSaveGradeParametersAdvancedgradingdataGuideCriteriaInnerFillingsInner
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric import ModAssignSaveGradeParametersAdvancedgradingdataRubric
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric_criteria_inner import ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInner
from poodle_async_full.models.mod_assign_save_grade_parameters_advancedgradingdata_rubric_criteria_inner_fillings_inner import ModAssignSaveGradeParametersAdvancedgradingdataRubricCriteriaInnerFillingsInner
from poodle_async_full.models.mod_assign_save_grade_parameters_plugindata import ModAssignSaveGradeParametersPlugindata
from poodle_async_full.models.mod_assign_save_grade_parameters_plugindata_assignfeedbackcomments_editor import ModAssignSaveGradeParametersPlugindataAssignfeedbackcommentsEditor
from poodle_async_full.models.mod_assign_save_grades_parameters_grades_inner import ModAssignSaveGradesParametersGradesInner
from poodle_async_full.models.mod_assign_save_submission_parameters_plugindata import ModAssignSaveSubmissionParametersPlugindata
from poodle_async_full.models.mod_assign_save_submission_parameters_plugindata_onlinetext_editor import ModAssignSaveSubmissionParametersPlugindataOnlinetextEditor
from poodle_async_full.models.mod_assign_set_user_flags_parameters_userflags_inner import ModAssignSetUserFlagsParametersUserflagsInner
from poodle_async_full.models.mod_assign_set_user_flags_response_inner import ModAssignSetUserFlagsResponseInner
from poodle_async_full.models.mod_assign_start_submission_response import ModAssignStartSubmissionResponse
from poodle_async_full.models.mod_assign_view_assign_response import ModAssignViewAssignResponse
from poodle_async_full.models.mod_assign_view_grading_table_response import ModAssignViewGradingTableResponse
from poodle_async_full.models.mod_assign_view_submission_status_response import ModAssignViewSubmissionStatusResponse
from poodle_async_full.models.mod_bigbluebuttonbn_can_join_response import ModBigbluebuttonbnCanJoinResponse
from poodle_async_full.models.mod_bigbluebuttonbn_completion_validate_response import ModBigbluebuttonbnCompletionValidateResponse
from poodle_async_full.models.mod_bigbluebuttonbn_end_meeting_response import ModBigbluebuttonbnEndMeetingResponse
from poodle_async_full.models.mod_bigbluebuttonbn_get_bigbluebuttonbns_by_courses_response import ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponse
from poodle_async_full.models.mod_bigbluebuttonbn_get_bigbluebuttonbns_by_courses_response_bigbluebuttonbns_inner import ModBigbluebuttonbnGetBigbluebuttonbnsByCoursesResponseBigbluebuttonbnsInner
from poodle_async_full.models.mod_bigbluebuttonbn_get_join_url_response import ModBigbluebuttonbnGetJoinUrlResponse
from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response import ModBigbluebuttonbnGetRecordingsResponse
from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response_tabledata import ModBigbluebuttonbnGetRecordingsResponseTabledata
from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_response_tabledata_columns_inner import ModBigbluebuttonbnGetRecordingsResponseTabledataColumnsInner
from poodle_async_full.models.mod_bigbluebuttonbn_get_recordings_to_import_response import ModBigbluebuttonbnGetRecordingsToImportResponse
from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response import ModBigbluebuttonbnMeetingInfoResponse
from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response_features_inner import ModBigbluebuttonbnMeetingInfoResponseFeaturesInner
from poodle_async_full.models.mod_bigbluebuttonbn_meeting_info_response_presentations_inner import ModBigbluebuttonbnMeetingInfoResponsePresentationsInner
from poodle_async_full.models.mod_bigbluebuttonbn_view_bigbluebuttonbn_response import ModBigbluebuttonbnViewBigbluebuttonbnResponse
from poodle_async_full.models.mod_book_get_books_by_courses_response import ModBookGetBooksByCoursesResponse
from poodle_async_full.models.mod_book_get_books_by_courses_response_books_inner import ModBookGetBooksByCoursesResponseBooksInner
from poodle_async_full.models.mod_book_view_book_response import ModBookViewBookResponse
from poodle_async_full.models.mod_choice_delete_choice_responses_response import ModChoiceDeleteChoiceResponsesResponse
from poodle_async_full.models.mod_choice_get_choice_options_response import ModChoiceGetChoiceOptionsResponse
from poodle_async_full.models.mod_choice_get_choice_options_response_options_inner import ModChoiceGetChoiceOptionsResponseOptionsInner
from poodle_async_full.models.mod_choice_get_choice_results_response import ModChoiceGetChoiceResultsResponse
from poodle_async_full.models.mod_choice_get_choice_results_response_options_inner import ModChoiceGetChoiceResultsResponseOptionsInner
from poodle_async_full.models.mod_choice_get_choice_results_response_options_inner_userresponses_inner import ModChoiceGetChoiceResultsResponseOptionsInnerUserresponsesInner
from poodle_async_full.models.mod_choice_get_choices_by_courses_response import ModChoiceGetChoicesByCoursesResponse
from poodle_async_full.models.mod_choice_get_choices_by_courses_response_choices_inner import ModChoiceGetChoicesByCoursesResponseChoicesInner
from poodle_async_full.models.mod_choice_submit_choice_response_response import ModChoiceSubmitChoiceResponseResponse
from poodle_async_full.models.mod_choice_submit_choice_response_response_answers_inner import ModChoiceSubmitChoiceResponseResponseAnswersInner
from poodle_async_full.models.mod_choice_view_choice_response import ModChoiceViewChoiceResponse
from poodle_async_full.models.mod_data_add_entry_parameters_data_inner import ModDataAddEntryParametersDataInner
from poodle_async_full.models.mod_data_add_entry_response import ModDataAddEntryResponse
from poodle_async_full.models.mod_data_add_entry_response_fieldnotifications_inner import ModDataAddEntryResponseFieldnotificationsInner
from poodle_async_full.models.mod_data_approve_entry_response import ModDataApproveEntryResponse
from poodle_async_full.models.mod_data_delete_entry_response import ModDataDeleteEntryResponse
from poodle_async_full.models.mod_data_delete_saved_preset_response import ModDataDeleteSavedPresetResponse
from poodle_async_full.models.mod_data_get_data_access_information_response import ModDataGetDataAccessInformationResponse
from poodle_async_full.models.mod_data_get_databases_by_courses_response import ModDataGetDatabasesByCoursesResponse
from poodle_async_full.models.mod_data_get_databases_by_courses_response_databases_inner import ModDataGetDatabasesByCoursesResponseDatabasesInner
from poodle_async_full.models.mod_data_get_entries_response import ModDataGetEntriesResponse
from poodle_async_full.models.mod_data_get_entries_response_entries_inner import ModDataGetEntriesResponseEntriesInner
from poodle_async_full.models.mod_data_get_entries_response_entries_inner_contents_inner import ModDataGetEntriesResponseEntriesInnerContentsInner
from poodle_async_full.models.mod_data_get_entry_response import ModDataGetEntryResponse
from poodle_async_full.models.mod_data_get_entry_response_ratinginfo import ModDataGetEntryResponseRatinginfo
from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_ratings_inner import ModDataGetEntryResponseRatinginfoRatingsInner
from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_scales_inner import ModDataGetEntryResponseRatinginfoScalesInner
from poodle_async_full.models.mod_data_get_entry_response_ratinginfo_scales_inner_items_inner import ModDataGetEntryResponseRatinginfoScalesInnerItemsInner
from poodle_async_full.models.mod_data_get_fields_response import ModDataGetFieldsResponse
from poodle_async_full.models.mod_data_get_fields_response_fields_inner import ModDataGetFieldsResponseFieldsInner
from poodle_async_full.models.mod_data_get_mapping_information_response import ModDataGetMappingInformationResponse
from poodle_async_full.models.mod_data_get_mapping_information_response_data import ModDataGetMappingInformationResponseData
from poodle_async_full.models.mod_data_search_entries_parameters_advsearch_inner import ModDataSearchEntriesParametersAdvsearchInner
from poodle_async_full.models.mod_data_search_entries_response import ModDataSearchEntriesResponse
from poodle_async_full.models.mod_data_update_entry_parameters_data_inner import ModDataUpdateEntryParametersDataInner
from poodle_async_full.models.mod_data_update_entry_response import ModDataUpdateEntryResponse
from poodle_async_full.models.mod_data_view_database_response import ModDataViewDatabaseResponse
from poodle_async_full.models.mod_feedback_get_analysis_response import ModFeedbackGetAnalysisResponse
from poodle_async_full.models.mod_feedback_get_analysis_response_itemsdata_inner import ModFeedbackGetAnalysisResponseItemsdataInner
from poodle_async_full.models.mod_feedback_get_analysis_response_itemsdata_inner_item import ModFeedbackGetAnalysisResponseItemsdataInnerItem
from poodle_async_full.models.mod_feedback_get_current_completed_tmp_response import ModFeedbackGetCurrentCompletedTmpResponse
from poodle_async_full.models.mod_feedback_get_current_completed_tmp_response_feedback import ModFeedbackGetCurrentCompletedTmpResponseFeedback
from poodle_async_full.models.mod_feedback_get_feedback_access_information_response import ModFeedbackGetFeedbackAccessInformationResponse
from poodle_async_full.models.mod_feedback_get_feedbacks_by_courses_response import ModFeedbackGetFeedbacksByCoursesResponse
from poodle_async_full.models.mod_feedback_get_feedbacks_by_courses_response_feedbacks_inner import ModFeedbackGetFeedbacksByCoursesResponseFeedbacksInner
from poodle_async_full.models.mod_feedback_get_finished_responses_response import ModFeedbackGetFinishedResponsesResponse
from poodle_async_full.models.mod_feedback_get_finished_responses_response_responses_inner import ModFeedbackGetFinishedResponsesResponseResponsesInner
from poodle_async_full.models.mod_feedback_get_items_response import ModFeedbackGetItemsResponse
from poodle_async_full.models.mod_feedback_get_last_completed_response import ModFeedbackGetLastCompletedResponse
from poodle_async_full.models.mod_feedback_get_last_completed_response_completed import ModFeedbackGetLastCompletedResponseCompleted
from poodle_async_full.models.mod_feedback_get_non_respondents_response import ModFeedbackGetNonRespondentsResponse
from poodle_async_full.models.mod_feedback_get_non_respondents_response_users_inner import ModFeedbackGetNonRespondentsResponseUsersInner
from poodle_async_full.models.mod_feedback_get_page_items_response import ModFeedbackGetPageItemsResponse
from poodle_async_full.models.mod_feedback_get_responses_analysis_response import ModFeedbackGetResponsesAnalysisResponse
from poodle_async_full.models.mod_feedback_get_responses_analysis_response_anonattempts_inner import ModFeedbackGetResponsesAnalysisResponseAnonattemptsInner
from poodle_async_full.models.mod_feedback_get_responses_analysis_response_anonattempts_inner_responses_inner import ModFeedbackGetResponsesAnalysisResponseAnonattemptsInnerResponsesInner
from poodle_async_full.models.mod_feedback_get_responses_analysis_response_attempts_inner import ModFeedbackGetResponsesAnalysisResponseAttemptsInner
from poodle_async_full.models.mod_feedback_get_unfinished_responses_response import ModFeedbackGetUnfinishedResponsesResponse
from poodle_async_full.models.mod_feedback_get_unfinished_responses_response_responses_inner import ModFeedbackGetUnfinishedResponsesResponseResponsesInner
from poodle_async_full.models.mod_feedback_launch_feedback_response import ModFeedbackLaunchFeedbackResponse
from poodle_async_full.models.mod_feedback_process_page_parameters_responses_inner import ModFeedbackProcessPageParametersResponsesInner
from poodle_async_full.models.mod_feedback_process_page_response import ModFeedbackProcessPageResponse
from poodle_async_full.models.mod_feedback_view_feedback_response import ModFeedbackViewFeedbackResponse
from poodle_async_full.models.mod_folder_get_folders_by_courses_response import ModFolderGetFoldersByCoursesResponse
from poodle_async_full.models.mod_folder_get_folders_by_courses_response_folders_inner import ModFolderGetFoldersByCoursesResponseFoldersInner
from poodle_async_full.models.mod_folder_view_folder_response import ModFolderViewFolderResponse
from poodle_async_full.models.mod_forum_add_discussion_parameters_options_inner import ModForumAddDiscussionParametersOptionsInner
from poodle_async_full.models.mod_forum_add_discussion_post_parameters_options_inner import ModForumAddDiscussionPostParametersOptionsInner
from poodle_async_full.models.mod_forum_add_discussion_post_response import ModForumAddDiscussionPostResponse
from poodle_async_full.models.mod_forum_add_discussion_post_response_messages_inner import ModForumAddDiscussionPostResponseMessagesInner
from poodle_async_full.models.mod_forum_add_discussion_post_response_post import ModForumAddDiscussionPostResponsePost
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner import ModForumAddDiscussionPostResponsePostAttachmentsInner
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner_html import ModForumAddDiscussionPostResponsePostAttachmentsInnerHtml
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_attachments_inner_urls import ModForumAddDiscussionPostResponsePostAttachmentsInnerUrls
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author import ModForumAddDiscussionPostResponsePostAuthor
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_groups_inner import ModForumAddDiscussionPostResponsePostAuthorGroupsInner
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_groups_inner_urls import ModForumAddDiscussionPostResponsePostAuthorGroupsInnerUrls
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_author_urls import ModForumAddDiscussionPostResponsePostAuthorUrls
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_capabilities import ModForumAddDiscussionPostResponsePostCapabilities
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_html import ModForumAddDiscussionPostResponsePostHtml
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_tags_inner import ModForumAddDiscussionPostResponsePostTagsInner
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_tags_inner_urls import ModForumAddDiscussionPostResponsePostTagsInnerUrls
from poodle_async_full.models.mod_forum_add_discussion_post_response_post_urls import ModForumAddDiscussionPostResponsePostUrls
from poodle_async_full.models.mod_forum_add_discussion_response import ModForumAddDiscussionResponse
from poodle_async_full.models.mod_forum_can_add_discussion_response import ModForumCanAddDiscussionResponse
from poodle_async_full.models.mod_forum_delete_post_response import ModForumDeletePostResponse
from poodle_async_full.models.mod_forum_get_discussion_post_response import ModForumGetDiscussionPostResponse
from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response import ModForumGetDiscussionPostsByUseridResponse
from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response_discussions_inner import ModForumGetDiscussionPostsByUseridResponseDiscussionsInner
from poodle_async_full.models.mod_forum_get_discussion_posts_by_userid_response_discussions_inner_posts import ModForumGetDiscussionPostsByUseridResponseDiscussionsInnerPosts
from poodle_async_full.models.mod_forum_get_discussion_posts_response import ModForumGetDiscussionPostsResponse
from poodle_async_full.models.mod_forum_get_forum_access_information_response import ModForumGetForumAccessInformationResponse
from poodle_async_full.models.mod_forum_get_forum_discussions_response import ModForumGetForumDiscussionsResponse
from poodle_async_full.models.mod_forum_get_forum_discussions_response_discussions_inner import ModForumGetForumDiscussionsResponseDiscussionsInner
from poodle_async_full.models.mod_forum_get_forums_by_courses_response_inner import ModForumGetForumsByCoursesResponseInner
from poodle_async_full.models.mod_forum_prepare_draft_area_for_post_parameters_filestokeep_inner import ModForumPrepareDraftAreaForPostParametersFilestokeepInner
from poodle_async_full.models.mod_forum_prepare_draft_area_for_post_response import ModForumPrepareDraftAreaForPostResponse
from poodle_async_full.models.mod_forum_set_lock_state_response import ModForumSetLockStateResponse
from poodle_async_full.models.mod_forum_set_lock_state_response_times import ModForumSetLockStateResponseTimes
from poodle_async_full.models.mod_forum_set_pin_state_response import ModForumSetPinStateResponse
from poodle_async_full.models.mod_forum_set_pin_state_response_capabilities import ModForumSetPinStateResponseCapabilities
from poodle_async_full.models.mod_forum_set_pin_state_response_group import ModForumSetPinStateResponseGroup
from poodle_async_full.models.mod_forum_set_pin_state_response_group_urls import ModForumSetPinStateResponseGroupUrls
from poodle_async_full.models.mod_forum_set_pin_state_response_timed import ModForumSetPinStateResponseTimed
from poodle_async_full.models.mod_forum_set_pin_state_response_times import ModForumSetPinStateResponseTimes
from poodle_async_full.models.mod_forum_set_pin_state_response_urls import ModForumSetPinStateResponseUrls
from poodle_async_full.models.mod_forum_set_pin_state_response_userstate import ModForumSetPinStateResponseUserstate
from poodle_async_full.models.mod_forum_set_subscription_state_response import ModForumSetSubscriptionStateResponse
from poodle_async_full.models.mod_forum_toggle_favourite_state_response import ModForumToggleFavouriteStateResponse
from poodle_async_full.models.mod_forum_update_discussion_post_parameters_options_inner import ModForumUpdateDiscussionPostParametersOptionsInner
from poodle_async_full.models.mod_forum_update_discussion_post_response import ModForumUpdateDiscussionPostResponse
from poodle_async_full.models.mod_forum_view_forum_discussion_response import ModForumViewForumDiscussionResponse
from poodle_async_full.models.mod_forum_view_forum_response import ModForumViewForumResponse
from poodle_async_full.models.mod_glossary_add_entry_parameters_options_inner import ModGlossaryAddEntryParametersOptionsInner
from poodle_async_full.models.mod_glossary_add_entry_response import ModGlossaryAddEntryResponse
from poodle_async_full.models.mod_glossary_delete_entry_response import ModGlossaryDeleteEntryResponse
from poodle_async_full.models.mod_glossary_get_authors_parameters_options import ModGlossaryGetAuthorsParametersOptions
from poodle_async_full.models.mod_glossary_get_authors_response import ModGlossaryGetAuthorsResponse
from poodle_async_full.models.mod_glossary_get_authors_response_authors_inner import ModGlossaryGetAuthorsResponseAuthorsInner
from poodle_async_full.models.mod_glossary_get_categories_response import ModGlossaryGetCategoriesResponse
from poodle_async_full.models.mod_glossary_get_categories_response_categories_inner import ModGlossaryGetCategoriesResponseCategoriesInner
from poodle_async_full.models.mod_glossary_get_entries_by_author_id_parameters_options import ModGlossaryGetEntriesByAuthorIdParametersOptions
from poodle_async_full.models.mod_glossary_get_entries_by_author_id_response import ModGlossaryGetEntriesByAuthorIdResponse
from poodle_async_full.models.mod_glossary_get_entries_by_author_id_response_entries_inner import ModGlossaryGetEntriesByAuthorIdResponseEntriesInner
from poodle_async_full.models.mod_glossary_get_entries_by_author_response import ModGlossaryGetEntriesByAuthorResponse
from poodle_async_full.models.mod_glossary_get_entries_by_category_response import ModGlossaryGetEntriesByCategoryResponse
from poodle_async_full.models.mod_glossary_get_entries_by_category_response_entries_inner import ModGlossaryGetEntriesByCategoryResponseEntriesInner
from poodle_async_full.models.mod_glossary_get_entries_by_date_response import ModGlossaryGetEntriesByDateResponse
from poodle_async_full.models.mod_glossary_get_entries_by_letter_response import ModGlossaryGetEntriesByLetterResponse
from poodle_async_full.models.mod_glossary_get_entries_by_search_response import ModGlossaryGetEntriesBySearchResponse
from poodle_async_full.models.mod_glossary_get_entries_by_term_response import ModGlossaryGetEntriesByTermResponse
from poodle_async_full.models.mod_glossary_get_entries_to_approve_response import ModGlossaryGetEntriesToApproveResponse
from poodle_async_full.models.mod_glossary_get_entry_by_id_response import ModGlossaryGetEntryByIdResponse
from poodle_async_full.models.mod_glossary_get_entry_by_id_response_permissions import ModGlossaryGetEntryByIdResponsePermissions
from poodle_async_full.models.mod_glossary_get_glossaries_by_courses_response import ModGlossaryGetGlossariesByCoursesResponse
from poodle_async_full.models.mod_glossary_get_glossaries_by_courses_response_glossaries_inner import ModGlossaryGetGlossariesByCoursesResponseGlossariesInner
from poodle_async_full.models.mod_glossary_prepare_entry_for_edition_response import ModGlossaryPrepareEntryForEditionResponse
from poodle_async_full.models.mod_glossary_update_entry_response import ModGlossaryUpdateEntryResponse
from poodle_async_full.models.mod_glossary_view_entry_response import ModGlossaryViewEntryResponse
from poodle_async_full.models.mod_glossary_view_glossary_response import ModGlossaryViewGlossaryResponse
from poodle_async_full.models.mod_h5pactivity_get_attempts_response import ModH5pactivityGetAttemptsResponse
from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner import ModH5pactivityGetAttemptsResponseUsersattemptsInner
from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner_attempts_inner import ModH5pactivityGetAttemptsResponseUsersattemptsInnerAttemptsInner
from poodle_async_full.models.mod_h5pactivity_get_attempts_response_usersattempts_inner_scored import ModH5pactivityGetAttemptsResponseUsersattemptsInnerScored
from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response import ModH5pactivityGetH5pactivitiesByCoursesResponse
from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pactivities_inner import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInner
from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pactivities_inner_deployedfile import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pactivitiesInnerDeployedfile
from poodle_async_full.models.mod_h5pactivity_get_h5pactivities_by_courses_response_h5pglobalsettings import ModH5pactivityGetH5pactivitiesByCoursesResponseH5pglobalsettings
from poodle_async_full.models.mod_h5pactivity_get_h5pactivity_access_information_response import ModH5pactivityGetH5pactivityAccessInformationResponse
from poodle_async_full.models.mod_h5pactivity_get_results_response import ModH5pactivityGetResultsResponse
from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner import ModH5pactivityGetResultsResponseAttemptsInner
from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner import ModH5pactivityGetResultsResponseAttemptsInnerResultsInner
from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInner
from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner_correctanswer import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerCorrectanswer
from poodle_async_full.models.mod_h5pactivity_get_results_response_attempts_inner_results_inner_options_inner_useranswer import ModH5pactivityGetResultsResponseAttemptsInnerResultsInnerOptionsInnerUseranswer
from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response import ModH5pactivityGetUserAttemptsResponse
from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response_usersattempts_inner import ModH5pactivityGetUserAttemptsResponseUsersattemptsInner
from poodle_async_full.models.mod_h5pactivity_get_user_attempts_response_usersattempts_inner_scored import ModH5pactivityGetUserAttemptsResponseUsersattemptsInnerScored
from poodle_async_full.models.mod_h5pactivity_log_report_viewed_response import ModH5pactivityLogReportViewedResponse
from poodle_async_full.models.mod_h5pactivity_view_h5pactivity_response import ModH5pactivityViewH5pactivityResponse
from poodle_async_full.models.mod_imscp_get_imscps_by_courses_response import ModImscpGetImscpsByCoursesResponse
from poodle_async_full.models.mod_imscp_get_imscps_by_courses_response_imscps_inner import ModImscpGetImscpsByCoursesResponseImscpsInner
from poodle_async_full.models.mod_imscp_view_imscp_response import ModImscpViewImscpResponse
from poodle_async_full.models.mod_label_get_labels_by_courses_response import ModLabelGetLabelsByCoursesResponse
from poodle_async_full.models.mod_label_get_labels_by_courses_response_labels_inner import ModLabelGetLabelsByCoursesResponseLabelsInner
from poodle_async_full.models.mod_lesson_finish_attempt_response import ModLessonFinishAttemptResponse
from poodle_async_full.models.mod_lesson_finish_attempt_response_data_inner import ModLessonFinishAttemptResponseDataInner
from poodle_async_full.models.mod_lesson_finish_attempt_response_messages_inner import ModLessonFinishAttemptResponseMessagesInner
from poodle_async_full.models.mod_lesson_get_attempts_overview_response import ModLessonGetAttemptsOverviewResponse
from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data import ModLessonGetAttemptsOverviewResponseData
from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data_students_inner import ModLessonGetAttemptsOverviewResponseDataStudentsInner
from poodle_async_full.models.mod_lesson_get_attempts_overview_response_data_students_inner_attempts_inner import ModLessonGetAttemptsOverviewResponseDataStudentsInnerAttemptsInner
from poodle_async_full.models.mod_lesson_get_content_pages_viewed_response import ModLessonGetContentPagesViewedResponse
from poodle_async_full.models.mod_lesson_get_content_pages_viewed_response_pages_inner import ModLessonGetContentPagesViewedResponsePagesInner
from poodle_async_full.models.mod_lesson_get_lesson_access_information_response import ModLessonGetLessonAccessInformationResponse
from poodle_async_full.models.mod_lesson_get_lesson_access_information_response_preventaccessreasons_inner import ModLessonGetLessonAccessInformationResponsePreventaccessreasonsInner
from poodle_async_full.models.mod_lesson_get_lesson_response import ModLessonGetLessonResponse
from poodle_async_full.models.mod_lesson_get_lesson_response_lesson import ModLessonGetLessonResponseLesson
from poodle_async_full.models.mod_lesson_get_lessons_by_courses_response import ModLessonGetLessonsByCoursesResponse
from poodle_async_full.models.mod_lesson_get_page_data_response import ModLessonGetPageDataResponse
from poodle_async_full.models.mod_lesson_get_page_data_response_answers_inner import ModLessonGetPageDataResponseAnswersInner
from poodle_async_full.models.mod_lesson_get_page_data_response_page import ModLessonGetPageDataResponsePage
from poodle_async_full.models.mod_lesson_get_pages_possible_jumps_response import ModLessonGetPagesPossibleJumpsResponse
from poodle_async_full.models.mod_lesson_get_pages_possible_jumps_response_jumps_inner import ModLessonGetPagesPossibleJumpsResponseJumpsInner
from poodle_async_full.models.mod_lesson_get_pages_response import ModLessonGetPagesResponse
from poodle_async_full.models.mod_lesson_get_pages_response_pages_inner import ModLessonGetPagesResponsePagesInner
from poodle_async_full.models.mod_lesson_get_questions_attempts_response import ModLessonGetQuestionsAttemptsResponse
from poodle_async_full.models.mod_lesson_get_questions_attempts_response_attempts_inner import ModLessonGetQuestionsAttemptsResponseAttemptsInner
from poodle_async_full.models.mod_lesson_get_user_attempt_grade_response import ModLessonGetUserAttemptGradeResponse
from poodle_async_full.models.mod_lesson_get_user_attempt_grade_response_grade import ModLessonGetUserAttemptGradeResponseGrade
from poodle_async_full.models.mod_lesson_get_user_attempt_response import ModLessonGetUserAttemptResponse
from poodle_async_full.models.mod_lesson_get_user_attempt_response_answerpages_inner import ModLessonGetUserAttemptResponseAnswerpagesInner
from poodle_async_full.models.mod_lesson_get_user_attempt_response_answerpages_inner_answerdata import ModLessonGetUserAttemptResponseAnswerpagesInnerAnswerdata
from poodle_async_full.models.mod_lesson_get_user_attempt_response_userstats import ModLessonGetUserAttemptResponseUserstats
from poodle_async_full.models.mod_lesson_get_user_grade_response import ModLessonGetUserGradeResponse
from poodle_async_full.models.mod_lesson_get_user_timers_response import ModLessonGetUserTimersResponse
from poodle_async_full.models.mod_lesson_get_user_timers_response_timers_inner import ModLessonGetUserTimersResponseTimersInner
from poodle_async_full.models.mod_lesson_launch_attempt_response import ModLessonLaunchAttemptResponse
from poodle_async_full.models.mod_lesson_process_page_parameters_data_inner import ModLessonProcessPageParametersDataInner
from poodle_async_full.models.mod_lesson_process_page_response import ModLessonProcessPageResponse
from poodle_async_full.models.mod_lesson_view_lesson_response import ModLessonViewLessonResponse
from poodle_async_full.models.mod_lti_create_tool_proxy_response import ModLtiCreateToolProxyResponse
from poodle_async_full.models.mod_lti_create_tool_type_response import ModLtiCreateToolTypeResponse
from poodle_async_full.models.mod_lti_create_tool_type_response_state import ModLtiCreateToolTypeResponseState
from poodle_async_full.models.mod_lti_create_tool_type_response_urls import ModLtiCreateToolTypeResponseUrls
from poodle_async_full.models.mod_lti_delete_tool_proxy_response import ModLtiDeleteToolProxyResponse
from poodle_async_full.models.mod_lti_delete_tool_type_response import ModLtiDeleteToolTypeResponse
from poodle_async_full.models.mod_lti_get_ltis_by_courses_response import ModLtiGetLtisByCoursesResponse
from poodle_async_full.models.mod_lti_get_ltis_by_courses_response_ltis_inner import ModLtiGetLtisByCoursesResponseLtisInner
from poodle_async_full.models.mod_lti_get_tool_launch_data_response import ModLtiGetToolLaunchDataResponse
from poodle_async_full.models.mod_lti_get_tool_launch_data_response_parameters_inner import ModLtiGetToolLaunchDataResponseParametersInner
from poodle_async_full.models.mod_lti_get_tool_proxies_response_inner import ModLtiGetToolProxiesResponseInner
from poodle_async_full.models.mod_lti_get_tool_proxy_registration_request_response import ModLtiGetToolProxyRegistrationRequestResponse
from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_count_response import ModLtiGetToolTypesAndProxiesCountResponse
from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_response import ModLtiGetToolTypesAndProxiesResponse
from poodle_async_full.models.mod_lti_get_tool_types_and_proxies_response_types_inner import ModLtiGetToolTypesAndProxiesResponseTypesInner
from poodle_async_full.models.mod_lti_is_cartridge_response import ModLtiIsCartridgeResponse
from poodle_async_full.models.mod_lti_update_tool_type_response import ModLtiUpdateToolTypeResponse
from poodle_async_full.models.mod_lti_view_lti_response import ModLtiViewLtiResponse
from poodle_async_full.models.mod_page_get_pages_by_courses_response import ModPageGetPagesByCoursesResponse
from poodle_async_full.models.mod_page_get_pages_by_courses_response_pages_inner import ModPageGetPagesByCoursesResponsePagesInner
from poodle_async_full.models.mod_page_view_page_response import ModPageViewPageResponse
from poodle_async_full.models.mod_quiz_add_random_questions_response import ModQuizAddRandomQuestionsResponse
from poodle_async_full.models.mod_quiz_create_grade_items_parameters_quizgradeitems_inner import ModQuizCreateGradeItemsParametersQuizgradeitemsInner
from poodle_async_full.models.mod_quiz_delete_grade_items_parameters_quizgradeitems_inner import ModQuizDeleteGradeItemsParametersQuizgradeitemsInner
from poodle_async_full.models.mod_quiz_delete_overrides_parameters_data import ModQuizDeleteOverridesParametersData
from poodle_async_full.models.mod_quiz_delete_overrides_response import ModQuizDeleteOverridesResponse
from poodle_async_full.models.mod_quiz_get_attempt_access_information_response import ModQuizGetAttemptAccessInformationResponse
from poodle_async_full.models.mod_quiz_get_attempt_data_response import ModQuizGetAttemptDataResponse
from poodle_async_full.models.mod_quiz_get_attempt_data_response_attempt import ModQuizGetAttemptDataResponseAttempt
from poodle_async_full.models.mod_quiz_get_attempt_data_response_attempt_gradeitemmarks_inner import ModQuizGetAttemptDataResponseAttemptGradeitemmarksInner
from poodle_async_full.models.mod_quiz_get_attempt_data_response_questions_inner import ModQuizGetAttemptDataResponseQuestionsInner
from poodle_async_full.models.mod_quiz_get_attempt_data_response_questions_inner_responsefileareas_inner import ModQuizGetAttemptDataResponseQuestionsInnerResponsefileareasInner
from poodle_async_full.models.mod_quiz_get_attempt_review_response import ModQuizGetAttemptReviewResponse
from poodle_async_full.models.mod_quiz_get_attempt_review_response_additionaldata_inner import ModQuizGetAttemptReviewResponseAdditionaldataInner
from poodle_async_full.models.mod_quiz_get_attempt_summary_response import ModQuizGetAttemptSummaryResponse
from poodle_async_full.models.mod_quiz_get_combined_review_options_response import ModQuizGetCombinedReviewOptionsResponse
from poodle_async_full.models.mod_quiz_get_combined_review_options_response_alloptions_inner import ModQuizGetCombinedReviewOptionsResponseAlloptionsInner
from poodle_async_full.models.mod_quiz_get_overrides_response import ModQuizGetOverridesResponse
from poodle_async_full.models.mod_quiz_get_overrides_response_overrides_inner import ModQuizGetOverridesResponseOverridesInner
from poodle_async_full.models.mod_quiz_get_quiz_access_information_response import ModQuizGetQuizAccessInformationResponse
from poodle_async_full.models.mod_quiz_get_quiz_feedback_for_grade_response import ModQuizGetQuizFeedbackForGradeResponse
from poodle_async_full.models.mod_quiz_get_quiz_required_qtypes_response import ModQuizGetQuizRequiredQtypesResponse
from poodle_async_full.models.mod_quiz_get_quizzes_by_courses_response import ModQuizGetQuizzesByCoursesResponse
from poodle_async_full.models.mod_quiz_get_quizzes_by_courses_response_quizzes_inner import ModQuizGetQuizzesByCoursesResponseQuizzesInner
from poodle_async_full.models.mod_quiz_get_user_attempts_response import ModQuizGetUserAttemptsResponse
from poodle_async_full.models.mod_quiz_get_user_attempts_response_attempts_inner import ModQuizGetUserAttemptsResponseAttemptsInner
from poodle_async_full.models.mod_quiz_get_user_best_grade_response import ModQuizGetUserBestGradeResponse
from poodle_async_full.models.mod_quiz_get_user_quiz_attempts_response import ModQuizGetUserQuizAttemptsResponse
from poodle_async_full.models.mod_quiz_process_attempt_response import ModQuizProcessAttemptResponse
from poodle_async_full.models.mod_quiz_save_attempt_response import ModQuizSaveAttemptResponse
from poodle_async_full.models.mod_quiz_save_overrides_parameters_data import ModQuizSaveOverridesParametersData
from poodle_async_full.models.mod_quiz_save_overrides_parameters_data_overrides_inner import ModQuizSaveOverridesParametersDataOverridesInner
from poodle_async_full.models.mod_quiz_save_overrides_response import ModQuizSaveOverridesResponse
from poodle_async_full.models.mod_quiz_set_question_version_response import ModQuizSetQuestionVersionResponse
from poodle_async_full.models.mod_quiz_start_attempt_response import ModQuizStartAttemptResponse
from poodle_async_full.models.mod_quiz_update_filter_condition_response import ModQuizUpdateFilterConditionResponse
from poodle_async_full.models.mod_quiz_update_grade_items_parameters_quizgradeitems_inner import ModQuizUpdateGradeItemsParametersQuizgradeitemsInner
from poodle_async_full.models.mod_quiz_update_slots_parameters_slots_inner import ModQuizUpdateSlotsParametersSlotsInner
from poodle_async_full.models.mod_quiz_view_attempt_response import ModQuizViewAttemptResponse
from poodle_async_full.models.mod_quiz_view_attempt_review_response import ModQuizViewAttemptReviewResponse
from poodle_async_full.models.mod_quiz_view_attempt_summary_response import ModQuizViewAttemptSummaryResponse
from poodle_async_full.models.mod_quiz_view_quiz_response import ModQuizViewQuizResponse
from poodle_async_full.models.mod_resource_get_resources_by_courses_response import ModResourceGetResourcesByCoursesResponse
from poodle_async_full.models.mod_resource_get_resources_by_courses_response_resources_inner import ModResourceGetResourcesByCoursesResponseResourcesInner
from poodle_async_full.models.mod_resource_view_resource_response import ModResourceViewResourceResponse
from poodle_async_full.models.mod_scorm_get_scorm_access_information_response import ModScormGetScormAccessInformationResponse
from poodle_async_full.models.mod_scorm_get_scorm_attempt_count_response import ModScormGetScormAttemptCountResponse
from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response import ModScormGetScormScoTracksResponse
from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response_data import ModScormGetScormScoTracksResponseData
from poodle_async_full.models.mod_scorm_get_scorm_sco_tracks_response_data_tracks_inner import ModScormGetScormScoTracksResponseDataTracksInner
from poodle_async_full.models.mod_scorm_get_scorm_scoes_response import ModScormGetScormScoesResponse
from poodle_async_full.models.mod_scorm_get_scorm_scoes_response_scoes_inner import ModScormGetScormScoesResponseScoesInner
from poodle_async_full.models.mod_scorm_get_scorm_scoes_response_scoes_inner_extradata_inner import ModScormGetScormScoesResponseScoesInnerExtradataInner
from poodle_async_full.models.mod_scorm_get_scorm_user_data_response import ModScormGetScormUserDataResponse
from poodle_async_full.models.mod_scorm_get_scorm_user_data_response_data_inner import ModScormGetScormUserDataResponseDataInner
from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response import ModScormGetScormsByCoursesResponse
from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response_options_inner import ModScormGetScormsByCoursesResponseOptionsInner
from poodle_async_full.models.mod_scorm_get_scorms_by_courses_response_scorms_inner import ModScormGetScormsByCoursesResponseScormsInner
from poodle_async_full.models.mod_scorm_insert_scorm_tracks_response import ModScormInsertScormTracksResponse
from poodle_async_full.models.mod_scorm_launch_sco_response import ModScormLaunchScoResponse
from poodle_async_full.models.mod_scorm_view_scorm_response import ModScormViewScormResponse
from poodle_async_full.models.mod_url_get_urls_by_courses_response import ModUrlGetUrlsByCoursesResponse
from poodle_async_full.models.mod_url_get_urls_by_courses_response_urls_inner import ModUrlGetUrlsByCoursesResponseUrlsInner
from poodle_async_full.models.mod_url_view_url_response import ModUrlViewUrlResponse
from poodle_async_full.models.mod_wiki_edit_page_response import ModWikiEditPageResponse
from poodle_async_full.models.mod_wiki_get_page_contents_response import ModWikiGetPageContentsResponse
from poodle_async_full.models.mod_wiki_get_page_contents_response_page import ModWikiGetPageContentsResponsePage
from poodle_async_full.models.mod_wiki_get_page_for_editing_response import ModWikiGetPageForEditingResponse
from poodle_async_full.models.mod_wiki_get_page_for_editing_response_pagesection import ModWikiGetPageForEditingResponsePagesection
from poodle_async_full.models.mod_wiki_get_subwiki_files_response import ModWikiGetSubwikiFilesResponse
from poodle_async_full.models.mod_wiki_get_subwiki_pages_parameters_options import ModWikiGetSubwikiPagesParametersOptions
from poodle_async_full.models.mod_wiki_get_subwiki_pages_response import ModWikiGetSubwikiPagesResponse
from poodle_async_full.models.mod_wiki_get_subwiki_pages_response_pages_inner import ModWikiGetSubwikiPagesResponsePagesInner
from poodle_async_full.models.mod_wiki_get_subwikis_response import ModWikiGetSubwikisResponse
from poodle_async_full.models.mod_wiki_get_subwikis_response_subwikis_inner import ModWikiGetSubwikisResponseSubwikisInner
from poodle_async_full.models.mod_wiki_get_wikis_by_courses_response import ModWikiGetWikisByCoursesResponse
from poodle_async_full.models.mod_wiki_get_wikis_by_courses_response_wikis_inner import ModWikiGetWikisByCoursesResponseWikisInner
from poodle_async_full.models.mod_wiki_new_page_response import ModWikiNewPageResponse
from poodle_async_full.models.mod_wiki_view_page_response import ModWikiViewPageResponse
from poodle_async_full.models.mod_wiki_view_wiki_response import ModWikiViewWikiResponse
from poodle_async_full.models.mod_workshop_add_submission_response import ModWorkshopAddSubmissionResponse
from poodle_async_full.models.mod_workshop_delete_submission_response import ModWorkshopDeleteSubmissionResponse
from poodle_async_full.models.mod_workshop_evaluate_assessment_response import ModWorkshopEvaluateAssessmentResponse
from poodle_async_full.models.mod_workshop_evaluate_submission_response import ModWorkshopEvaluateSubmissionResponse
from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response import ModWorkshopGetAssessmentFormDefinitionResponse
from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_current_inner import ModWorkshopGetAssessmentFormDefinitionResponseCurrentInner
from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_dimensionsinfo_inner import ModWorkshopGetAssessmentFormDefinitionResponseDimensionsinfoInner
from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_fields_inner import ModWorkshopGetAssessmentFormDefinitionResponseFieldsInner
from poodle_async_full.models.mod_workshop_get_assessment_form_definition_response_options_inner import ModWorkshopGetAssessmentFormDefinitionResponseOptionsInner
from poodle_async_full.models.mod_workshop_get_assessment_response import ModWorkshopGetAssessmentResponse
from poodle_async_full.models.mod_workshop_get_assessment_response_assessment import ModWorkshopGetAssessmentResponseAssessment
from poodle_async_full.models.mod_workshop_get_grades_report_response import ModWorkshopGetGradesReportResponse
from poodle_async_full.models.mod_workshop_get_grades_report_response_report import ModWorkshopGetGradesReportResponseReport
from poodle_async_full.models.mod_workshop_get_grades_report_response_report_grades_inner import ModWorkshopGetGradesReportResponseReportGradesInner
from poodle_async_full.models.mod_workshop_get_grades_report_response_report_grades_inner_reviewedby_inner import ModWorkshopGetGradesReportResponseReportGradesInnerReviewedbyInner
from poodle_async_full.models.mod_workshop_get_grades_response import ModWorkshopGetGradesResponse
from poodle_async_full.models.mod_workshop_get_reviewer_assessments_response import ModWorkshopGetReviewerAssessmentsResponse
from poodle_async_full.models.mod_workshop_get_submission_assessments_response import ModWorkshopGetSubmissionAssessmentsResponse
from poodle_async_full.models.mod_workshop_get_submission_response import ModWorkshopGetSubmissionResponse
from poodle_async_full.models.mod_workshop_get_submission_response_submission import ModWorkshopGetSubmissionResponseSubmission
from poodle_async_full.models.mod_workshop_get_submissions_response import ModWorkshopGetSubmissionsResponse
from poodle_async_full.models.mod_workshop_get_user_plan_response import ModWorkshopGetUserPlanResponse
from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan import ModWorkshopGetUserPlanResponseUserplan
from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_examples_inner import ModWorkshopGetUserPlanResponseUserplanExamplesInner
from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInner
from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner_actions_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInnerActionsInner
from poodle_async_full.models.mod_workshop_get_user_plan_response_userplan_phases_inner_tasks_inner import ModWorkshopGetUserPlanResponseUserplanPhasesInnerTasksInner
from poodle_async_full.models.mod_workshop_get_workshop_access_information_response import ModWorkshopGetWorkshopAccessInformationResponse
from poodle_async_full.models.mod_workshop_get_workshops_by_courses_response import ModWorkshopGetWorkshopsByCoursesResponse
from poodle_async_full.models.mod_workshop_get_workshops_by_courses_response_workshops_inner import ModWorkshopGetWorkshopsByCoursesResponseWorkshopsInner
from poodle_async_full.models.mod_workshop_update_assessment_parameters_data_inner import ModWorkshopUpdateAssessmentParametersDataInner
from poodle_async_full.models.mod_workshop_update_assessment_response import ModWorkshopUpdateAssessmentResponse
from poodle_async_full.models.mod_workshop_update_submission_response import ModWorkshopUpdateSubmissionResponse
from poodle_async_full.models.mod_workshop_view_submission_response import ModWorkshopViewSubmissionResponse
from poodle_async_full.models.mod_workshop_view_workshop_response import ModWorkshopViewWorkshopResponse
from poodle_async_full.models.paygw_paypal_create_transaction_complete_parameters import PaygwPaypalCreateTransactionCompleteParameters
from poodle_async_full.models.paygw_paypal_create_transaction_complete_response import PaygwPaypalCreateTransactionCompleteResponse
from poodle_async_full.models.paygw_paypal_get_config_for_js_response import PaygwPaypalGetConfigForJsResponse
from poodle_async_full.models.qbank_editquestion_set_status_response import QbankEditquestionSetStatusResponse
from poodle_async_full.models.qbank_managecategories_move_category_response_inner import QbankManagecategoriesMoveCategoryResponseInner
from poodle_async_full.models.qbank_managecategories_move_category_response_inner_fields import QbankManagecategoriesMoveCategoryResponseInnerFields
from poodle_async_full.models.qbank_tagquestion_submit_tags_form_response import QbankTagquestionSubmitTagsFormResponse
from poodle_async_full.models.quizaccess_seb_validate_quiz_keys_response import QuizaccessSebValidateQuizKeysResponse
from poodle_async_full.models.report_competency_data_for_report_response import ReportCompetencyDataForReportResponse
from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner import ReportCompetencyDataForReportResponseUsercompetenciesInner
from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetency
from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency_comppath import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppath
from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_competency_comppath_ancestors_inner import ReportCompetencyDataForReportResponseUsercompetenciesInnerCompetencyComppathAncestorsInner
from poodle_async_full.models.report_competency_data_for_report_response_usercompetencies_inner_usercompetencycourse import ReportCompetencyDataForReportResponseUsercompetenciesInnerUsercompetencycourse
from poodle_async_full.models.report_insights_action_executed_response import ReportInsightsActionExecutedResponse
from poodle_async_full.models.tiny_autosave_reset_session_parameters import TinyAutosaveResetSessionParameters
from poodle_async_full.models.tiny_autosave_resume_session_parameters import TinyAutosaveResumeSessionParameters
from poodle_async_full.models.tiny_autosave_resume_session_response import TinyAutosaveResumeSessionResponse
from poodle_async_full.models.tiny_autosave_update_session_parameters import TinyAutosaveUpdateSessionParameters
from poodle_async_full.models.tiny_equation_filter_response import TinyEquationFilterResponse
from poodle_async_full.models.tiny_media_preview_response import TinyMediaPreviewResponse
from poodle_async_full.models.tiny_premium_get_api_key_response import TinyPremiumGetApiKeyResponse
from poodle_async_full.models.tool_analytics_potential_contexts_response_inner import ToolAnalyticsPotentialContextsResponseInner
from poodle_async_full.models.tool_behat_get_entity_generator_response import ToolBehatGetEntityGeneratorResponse
from poodle_async_full.models.tool_dataprivacy_approve_data_request_response import ToolDataprivacyApproveDataRequestResponse
from poodle_async_full.models.tool_dataprivacy_bulk_approve_data_requests_response import ToolDataprivacyBulkApproveDataRequestsResponse
from poodle_async_full.models.tool_dataprivacy_bulk_deny_data_requests_response import ToolDataprivacyBulkDenyDataRequestsResponse
from poodle_async_full.models.tool_dataprivacy_cancel_data_request_response import ToolDataprivacyCancelDataRequestResponse
from poodle_async_full.models.tool_dataprivacy_confirm_contexts_for_deletion_response import ToolDataprivacyConfirmContextsForDeletionResponse
from poodle_async_full.models.tool_dataprivacy_contact_dpo_response import ToolDataprivacyContactDpoResponse
from poodle_async_full.models.tool_dataprivacy_create_category_form_response import ToolDataprivacyCreateCategoryFormResponse
from poodle_async_full.models.tool_dataprivacy_create_category_form_response_category import ToolDataprivacyCreateCategoryFormResponseCategory
from poodle_async_full.models.tool_dataprivacy_create_data_request_response import ToolDataprivacyCreateDataRequestResponse
from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response import ToolDataprivacyCreatePurposeFormResponse
from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response_purpose import ToolDataprivacyCreatePurposeFormResponsePurpose
from poodle_async_full.models.tool_dataprivacy_create_purpose_form_response_purpose_formattedlawfulbases_inner import ToolDataprivacyCreatePurposeFormResponsePurposeFormattedlawfulbasesInner
from poodle_async_full.models.tool_dataprivacy_delete_category_response import ToolDataprivacyDeleteCategoryResponse
from poodle_async_full.models.tool_dataprivacy_delete_purpose_response import ToolDataprivacyDeletePurposeResponse
from poodle_async_full.models.tool_dataprivacy_deny_data_request_response import ToolDataprivacyDenyDataRequestResponse
from poodle_async_full.models.tool_dataprivacy_get_access_information_response import ToolDataprivacyGetAccessInformationResponse
from poodle_async_full.models.tool_dataprivacy_get_activity_options_response import ToolDataprivacyGetActivityOptionsResponse
from poodle_async_full.models.tool_dataprivacy_get_activity_options_response_options_inner import ToolDataprivacyGetActivityOptionsResponseOptionsInner
from poodle_async_full.models.tool_dataprivacy_get_category_options_response import ToolDataprivacyGetCategoryOptionsResponse
from poodle_async_full.models.tool_dataprivacy_get_category_options_response_options_inner import ToolDataprivacyGetCategoryOptionsResponseOptionsInner
from poodle_async_full.models.tool_dataprivacy_get_data_request_response import ToolDataprivacyGetDataRequestResponse
from poodle_async_full.models.tool_dataprivacy_get_data_request_response_result import ToolDataprivacyGetDataRequestResponseResult
from poodle_async_full.models.tool_dataprivacy_get_data_requests_response import ToolDataprivacyGetDataRequestsResponse
from poodle_async_full.models.tool_dataprivacy_get_purpose_options_response import ToolDataprivacyGetPurposeOptionsResponse
from poodle_async_full.models.tool_dataprivacy_get_purpose_options_response_options_inner import ToolDataprivacyGetPurposeOptionsResponseOptionsInner
from poodle_async_full.models.tool_dataprivacy_mark_complete_response import ToolDataprivacyMarkCompleteResponse
from poodle_async_full.models.tool_dataprivacy_set_context_defaults_response import ToolDataprivacySetContextDefaultsResponse
from poodle_async_full.models.tool_dataprivacy_set_context_form_response import ToolDataprivacySetContextFormResponse
from poodle_async_full.models.tool_dataprivacy_set_contextlevel_form_response import ToolDataprivacySetContextlevelFormResponse
from poodle_async_full.models.tool_dataprivacy_submit_selected_courses_form_response import ToolDataprivacySubmitSelectedCoursesFormResponse
from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response import ToolDataprivacyTreeExtraBranchesResponse
from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response_branches_inner import ToolDataprivacyTreeExtraBranchesResponseBranchesInner
from poodle_async_full.models.tool_dataprivacy_tree_extra_branches_response_branches_inner_branches_inner import ToolDataprivacyTreeExtraBranchesResponseBranchesInnerBranchesInner
from poodle_async_full.models.tool_lp_data_for_competencies_manage_page_response import ToolLpDataForCompetenciesManagePageResponse
from poodle_async_full.models.tool_lp_data_for_competency_frameworks_manage_page_response import ToolLpDataForCompetencyFrameworksManagePageResponse
from poodle_async_full.models.tool_lp_data_for_competency_summary_response import ToolLpDataForCompetencySummaryResponse
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response import ToolLpDataForCourseCompetenciesPageResponse
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInner
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner_coursemodules_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerCoursemodulesInner
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_competencies_inner_ruleoutcomeoptions_inner import ToolLpDataForCourseCompetenciesPageResponseCompetenciesInnerRuleoutcomeoptionsInner
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_settings import ToolLpDataForCourseCompetenciesPageResponseSettings
from poodle_async_full.models.tool_lp_data_for_course_competencies_page_response_statistics import ToolLpDataForCourseCompetenciesPageResponseStatistics
from poodle_async_full.models.tool_lp_data_for_plan_page_response import ToolLpDataForPlanPageResponse
from poodle_async_full.models.tool_lp_data_for_plan_page_response_competencies_inner import ToolLpDataForPlanPageResponseCompetenciesInner
from poodle_async_full.models.tool_lp_data_for_plans_page_response import ToolLpDataForPlansPageResponse
from poodle_async_full.models.tool_lp_data_for_related_competencies_section_response import ToolLpDataForRelatedCompetenciesSectionResponse
from poodle_async_full.models.tool_lp_data_for_template_competencies_page_response import ToolLpDataForTemplateCompetenciesPageResponse
from poodle_async_full.models.tool_lp_data_for_template_competencies_page_response_statistics import ToolLpDataForTemplateCompetenciesPageResponseStatistics
from poodle_async_full.models.tool_lp_data_for_templates_manage_page_response import ToolLpDataForTemplatesManagePageResponse
from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response import ToolLpDataForUserCompetencySummaryInCourseResponse
from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response_usercompetencysummary import ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummary
from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_course_response_usercompetencysummary_evidence_inner import ToolLpDataForUserCompetencySummaryInCourseResponseUsercompetencysummaryEvidenceInner
from poodle_async_full.models.tool_lp_data_for_user_competency_summary_in_plan_response import ToolLpDataForUserCompetencySummaryInPlanResponse
from poodle_async_full.models.tool_lp_data_for_user_competency_summary_response import ToolLpDataForUserCompetencySummaryResponse
from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response import ToolLpDataForUserEvidenceListPageResponse
from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response_evidence_inner import ToolLpDataForUserEvidenceListPageResponseEvidenceInner
from poodle_async_full.models.tool_lp_data_for_user_evidence_list_page_response_evidence_inner_usercompetencies_inner import ToolLpDataForUserEvidenceListPageResponseEvidenceInnerUsercompetenciesInner
from poodle_async_full.models.tool_lp_data_for_user_evidence_page_response import ToolLpDataForUserEvidencePageResponse
from poodle_async_full.models.tool_lp_search_cohorts_response import ToolLpSearchCohortsResponse
from poodle_async_full.models.tool_lp_search_users_response import ToolLpSearchUsersResponse
from poodle_async_full.models.tool_mobile_call_external_functions_parameters_requests_inner import ToolMobileCallExternalFunctionsParametersRequestsInner
from poodle_async_full.models.tool_mobile_call_external_functions_response import ToolMobileCallExternalFunctionsResponse
from poodle_async_full.models.tool_mobile_call_external_functions_response_responses_inner import ToolMobileCallExternalFunctionsResponseResponsesInner
from poodle_async_full.models.tool_mobile_get_autologin_key_response import ToolMobileGetAutologinKeyResponse
from poodle_async_full.models.tool_mobile_get_config_response import ToolMobileGetConfigResponse
from poodle_async_full.models.tool_mobile_get_config_response_settings_inner import ToolMobileGetConfigResponseSettingsInner
from poodle_async_full.models.tool_mobile_get_content_parameters_args_inner import ToolMobileGetContentParametersArgsInner
from poodle_async_full.models.tool_mobile_get_content_response import ToolMobileGetContentResponse
from poodle_async_full.models.tool_mobile_get_content_response_otherdata_inner import ToolMobileGetContentResponseOtherdataInner
from poodle_async_full.models.tool_mobile_get_content_response_restrict import ToolMobileGetContentResponseRestrict
from poodle_async_full.models.tool_mobile_get_content_response_templates_inner import ToolMobileGetContentResponseTemplatesInner
from poodle_async_full.models.tool_mobile_get_plugins_supporting_mobile_response import ToolMobileGetPluginsSupportingMobileResponse
from poodle_async_full.models.tool_mobile_get_plugins_supporting_mobile_response_plugins_inner import ToolMobileGetPluginsSupportingMobileResponsePluginsInner
from poodle_async_full.models.tool_mobile_get_public_config_response import ToolMobileGetPublicConfigResponse
from poodle_async_full.models.tool_mobile_get_public_config_response_identityproviders_inner import ToolMobileGetPublicConfigResponseIdentityprovidersInner
from poodle_async_full.models.tool_mobile_get_tokens_for_qr_login_parameters import ToolMobileGetTokensForQrLoginParameters
from poodle_async_full.models.tool_mobile_get_tokens_for_qr_login_response import ToolMobileGetTokensForQrLoginResponse
from poodle_async_full.models.tool_mobile_validate_subscription_key_parameters import ToolMobileValidateSubscriptionKeyParameters
from poodle_async_full.models.tool_mobile_validate_subscription_key_response import ToolMobileValidateSubscriptionKeyResponse
from poodle_async_full.models.tool_moodlenet_search_courses_response import ToolMoodlenetSearchCoursesResponse
from poodle_async_full.models.tool_moodlenet_search_courses_response_courses_inner import ToolMoodlenetSearchCoursesResponseCoursesInner
from poodle_async_full.models.tool_moodlenet_verify_webfinger_response import ToolMoodlenetVerifyWebfingerResponse
from poodle_async_full.models.tool_policy_get_policy_version_parameters import ToolPolicyGetPolicyVersionParameters
from poodle_async_full.models.tool_policy_get_policy_version_response import ToolPolicyGetPolicyVersionResponse
from poodle_async_full.models.tool_policy_get_policy_version_response_result import ToolPolicyGetPolicyVersionResponseResult
from poodle_async_full.models.tool_policy_get_policy_version_response_result_policy import ToolPolicyGetPolicyVersionResponseResultPolicy
from poodle_async_full.models.tool_policy_get_user_acceptances_response import ToolPolicyGetUserAcceptancesResponse
from poodle_async_full.models.tool_policy_get_user_acceptances_response_policies_inner import ToolPolicyGetUserAcceptancesResponsePoliciesInner
from poodle_async_full.models.tool_policy_get_user_acceptances_response_policies_inner_acceptance import ToolPolicyGetUserAcceptancesResponsePoliciesInnerAcceptance
from poodle_async_full.models.tool_policy_set_acceptances_status_parameters_policies_inner import ToolPolicySetAcceptancesStatusParametersPoliciesInner
from poodle_async_full.models.tool_policy_set_acceptances_status_response import ToolPolicySetAcceptancesStatusResponse
from poodle_async_full.models.tool_templatelibrary_list_templates_parameters import ToolTemplatelibraryListTemplatesParameters
from poodle_async_full.models.tool_templatelibrary_load_canonical_template_parameters import ToolTemplatelibraryLoadCanonicalTemplateParameters
from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response import ToolUsertoursFetchAndStartTourResponse
from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response_tourconfig import ToolUsertoursFetchAndStartTourResponseTourconfig
from poodle_async_full.models.tool_usertours_fetch_and_start_tour_response_tourconfig_steps_inner import ToolUsertoursFetchAndStartTourResponseTourconfigStepsInner
from poodle_async_full.models.tool_usertours_reset_tour_response import ToolUsertoursResetTourResponse

""",
            name=__name__,
            doc=__doc__,
        )
    )
